<?php

if ( ! class_exists('RWMB_Loader') ) return;


class Reuss_Metaboxes
{
    public function __construct()
    {
        // Team Fields Metaboxes
        add_filter( 'rwmb_meta_boxes', [ $this, 'team_meta_boxes' ] );

        // Portfolio Fields Metaboxes
        add_filter( 'rwmb_meta_boxes', [ $this, 'portfolio_meta_boxes' ] );
        add_filter( 'rwmb_meta_boxes', [ $this, 'portfolio_post_settings_meta_boxes' ] );
        add_filter( 'rwmb_meta_boxes', [ $this, 'portfolio_related_meta_boxes' ] );

        // Blog Fields Metaboxes
        add_filter( 'rwmb_meta_boxes', [ $this, 'blog_settings_meta_boxes' ] );
        add_filter( 'rwmb_meta_boxes', [ $this, 'blog_meta_boxes' ] );
        add_filter( 'rwmb_meta_boxes', [ $this, 'blog_related_meta_boxes' ]);

        // Page Fields Metaboxes
        add_filter( 'rwmb_meta_boxes', [ $this, 'page_layout_meta_boxes' ] );
        // Colors Fields Metaboxes
        add_filter( 'rwmb_meta_boxes', [ $this, 'page_color_meta_boxes' ] );
        // Header Builder Fields Metaboxes
        add_filter( 'rwmb_meta_boxes', [ $this, 'page_header_meta_boxes' ] );
        // Title Fields Metaboxes
        add_filter( 'rwmb_meta_boxes', [ $this, 'page_title_meta_boxes' ] );
        // Side Panel Fields Metaboxes
        add_filter( 'rwmb_meta_boxes', [ $this, 'page_side_panel_meta_boxes' ] );

        // Footer Fields Metaboxes
        add_filter( 'rwmb_meta_boxes', [ $this, 'page_footer_meta_boxes' ] );
        // Copyright Fields Metaboxes
        add_filter( 'rwmb_meta_boxes', [ $this, 'page_copyright_meta_boxes' ] );

    }

    public function team_meta_boxes($meta_boxes)
    {
        $meta_boxes[] = [
            'title' => esc_html__('Team Options', 'reuss'),
            'post_types' => [ 'team' ],
            'context' => 'advanced',
            'fields' => [
                [
                    'name' => esc_html__('Highlighted Info', 'reuss'),
                    'id' => 'department',
                    'type' => 'text',
                    'class' => 'field-inputs'
                ],
                [
                    'name' => esc_html__('Member Info', 'reuss'),
                    'id' => 'info_items',
                    'type' => 'social',
                    'clone' => true,
                    'sort_clone' => true,
                    'options' => [
                        'name' => [
                            'name' => esc_html__('Name', 'reuss'),
                            'type_input' => 'text'
                        ],
                        'description' => [
                            'name' => esc_html__('Description', 'reuss'),
                            'type_input' => 'text'
                        ],
                        'link' => [
                            'name' => esc_html__('Link', 'reuss'),
                            'type_input' => 'text'
                        ],
                    ],
                ],
                [
                    'name' => esc_html__('Social Icons', 'reuss'),
                    'id' => 'soc_icon',
                    'type' => 'select_icon',
                    'options' => Wgl_Admin_Icon()->get_icons_name(),
                    'clone' => true,
                    'sort_clone' => true,
                    'placeholder' => esc_html__('Select an icon', 'reuss'),
                    'multiple' => false,
                    'std' => 'default',
                ],
                [
                    'name' => esc_html__('Info Background Image', 'reuss'),
                    'id' => 'mb_info_bg',
                    'type' => 'file_advanced',
                    'max_file_uploads' => 1,
                    'mime_type' => 'image',
                ],
            ],
        ];
        return $meta_boxes;
    }

    public function portfolio_meta_boxes($meta_boxes)
    {
        $meta_boxes[] = [
            'title' => esc_html__('Portfolio Options', 'reuss'),
            'post_types' => [ 'portfolio' ],
            'context' => 'advanced',
            'fields' => [
                [
                    'name' => esc_html__('Featured Image', 'reuss'),
                    'id' => 'mb_portfolio_featured_image_conditional',
                    'type' => 'button_group',
                    'options' => [
                        'default' => esc_html__('Default', 'reuss'),
                        'custom' => esc_html__('Custom', 'reuss'),
                    ],
                    'multiple' => false,
                    'std' => 'default',
                ],
                [
                    'name' => esc_html__('Featured Image Settings', 'reuss'),
                    'id' => 'mb_portfolio_featured_image_type',
                    'type' => 'button_group',
                    'options' => [
                        'off' => esc_html__('Off', 'reuss'),
                        'replace' => esc_html__('Replace', 'reuss'),
                    ],
                    'multiple' => false,
                    'std' => 'off',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                                [ 'mb_portfolio_featured_image_conditional', '=', 'custom' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Featured Image Replace', 'reuss'),
                    'id' => 'mb_portfolio_featured_image_replace',
                    'type' => 'image_advanced',
                    'max_file_uploads' => 1,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_portfolio_featured_image_conditional', '=', 'custom' ],
                            [ 'mb_portfolio_featured_image_type', '=', 'replace' ],
                        ] ],
                    ],
                ],
                [
                    'id' => 'mb_portfolio_title',
                    'name' => esc_html__('Show Title on single', 'reuss'),
                    'type' => 'switch',
                    'std' => 'true',
                ],
                [
                    'id' => 'mb_portfolio_link',
                    'name' => esc_html__('Add Custom Link for Portfolio Grid', 'reuss'),
                    'type' => 'switch',
                ],
                [
                    'name' => esc_html__('Custom Url for Portfolio Grid', 'reuss'),
                    'id' => 'portfolio_custom_url',
                    'type' => 'text',
                    'class' => 'field-inputs',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_portfolio_link', '=', '1' ]
                        ], ],
                    ],
                ],
                [
                    'id' => 'portfolio_custom_url_target',
                    'name' => esc_html__('Open Custom Url in New Window', 'reuss'),
                    'type' => 'switch',
                    'std' => 'true',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_portfolio_link', '=', '1' ]
                        ], ],
                    ],
                ],
                [
                    'name' => esc_html__('Info', 'reuss'),
                    'id' => 'mb_portfolio_info_items',
                    'type' => 'social',
                    'clone' => true,
                    'sort_clone' => true,
                    'desc' => esc_html__('Description', 'reuss'),
                    'options' => [
                        'name' => [
                            'name' => esc_html__('Name', 'reuss'),
                            'type_input' => 'text'
                        ],
                        'description' => [
                            'name' => esc_html__('Description', 'reuss'),
                            'type_input' => 'text'
                        ],
                        'link' => [
                            'name' => esc_html__('Url', 'reuss'),
                            'type_input' => 'text'
                        ],
                    ],
                ],
                [
                    'name' => esc_html__('Info Background Image', 'reuss'),
                    'id' => 'mb_portfolio_info_bg',
                    'type' => 'image_advanced',
                    'max_file_uploads' => 1,
                ],
                [
                    'name' => esc_html__('Categories', 'reuss'),
                    'id' => 'mb_portfolio_single_meta_categories',
                    'type' => 'button_group',
                    'options' => [
                        'default' => esc_html__('Default', 'reuss'),
                        'yes' => esc_html__('Use', 'reuss'),
                        'no' => esc_html__('Hide', 'reuss'),
                    ],
                    'multiple' => false,
                    'std' => 'default',
                ],
                [
                    'name' => esc_html__('Date', 'reuss'),
                    'id' => 'mb_portfolio_single_meta_date',
                    'type' => 'button_group',
                    'options' => [
                        'default' => esc_html__('Default', 'reuss'),
                        'yes' => esc_html__('Use', 'reuss'),
                        'no' => esc_html__('Hide', 'reuss'),
                    ],
                    'multiple' => false,
                    'std' => 'default',
                ],
                [
                    'name' => esc_html__('Tags', 'reuss'),
                    'id' => 'mb_portfolio_above_content_cats',
                    'type' => 'button_group',
                    'options' => [
                        'default' => esc_html__('Default', 'reuss'),
                        'yes' => esc_html__('Use', 'reuss'),
                        'no' => esc_html__('Hide', 'reuss'),
                    ],
                    'multiple' => false,
                    'std' => 'default',
                ],
                [
                    'name' => esc_html__('Share Links', 'reuss'),
                    'id' => 'mb_portfolio_above_content_share',
                    'type' => 'button_group',
                    'options' => [
                        'default' => esc_html__('Default', 'reuss'),
                        'yes' => esc_html__('Use', 'reuss'),
                        'no' => esc_html__('Hide', 'reuss'),
                    ],
                    'multiple' => false,
                    'std' => 'default',
                ],
            ],
        ];
        return $meta_boxes;
    }

    public function portfolio_post_settings_meta_boxes($meta_boxes)
    {
        $meta_boxes[] = [
            'title' => esc_html__('Portfolio Post Settings', 'reuss'),
            'post_types' => [ 'portfolio' ],
            'context' => 'advanced',
            'fields' => [
                [
                    'name' => esc_html__('Post Layout', 'reuss'),
                    'id' => 'mb_portfolio_post_conditional',
                    'type' => 'button_group',
                    'options' => [
                        'default' => esc_html__('Default', 'reuss'),
                        'custom' => esc_html__('Custom', 'reuss'),
                    ],
                    'multiple' => false,
                    'std' => 'default',
                ],
                [
                    'name' => esc_html__('Post Layout Settings', 'reuss'),
                    'type' => 'wgl_heading',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_portfolio_post_conditional', '=', 'custom' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Alignment', 'reuss'),
                    'id' => 'mb_portfolio_single_align',
                    'type' => 'button_group',
                    'options' => [
                        'left' => esc_html__('Left', 'reuss'),
                        'center' => esc_html__('Center', 'reuss'),
                        'right' => esc_html__('Right', 'reuss'),
                    ],
                    'multiple' => false,
                    'std' => 'left',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_portfolio_post_conditional', '=', 'custom' ]
                        ], ],
                    ],
                ],
            ],
        ];
        return $meta_boxes;
    }

    public function portfolio_related_meta_boxes($meta_boxes)
    {
        $meta_boxes[] = [
            'title' => esc_html__('Related Portfolio', 'reuss'),
            'post_types' => [ 'portfolio' ],
            'context' => 'advanced',
            'fields' => [
                [
                    'id' => 'mb_portfolio_related_switch',
                    'name' => esc_html__('Portfolio Related', 'reuss'),
                    'type' => 'button_group',
                    'options' => [
                        'default' => esc_html__('Default', 'reuss'),
                        'on' => esc_html__('On', 'reuss'),
                        'off' => esc_html__('Off', 'reuss'),
                    ],
                    'inline' => true,
                    'multiple' => false,
                    'std' => 'default'
                ],
                [
                    'name' => esc_html__('Portfolio Related Settings', 'reuss'),
                    'type' => 'wgl_heading',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_portfolio_related_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'id' => 'mb_pf_carousel_r',
                    'name' => esc_html__('Display items carousel for this portfolio post', 'reuss'),
                    'type' => 'switch',
                    'std' => 1,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_portfolio_related_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Title', 'reuss'),
                    'id' => 'mb_pf_title_r',
                    'type' => 'text',
                    'std' => esc_html__('Related Portfolio', 'reuss'),
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_portfolio_related_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Categories', 'reuss'),
                    'id' => 'mb_pf_cat_r',
                    'multiple' => true,
                    'type' => 'taxonomy_advanced',
                    'taxonomy' => 'portfolio-category',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_portfolio_related_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Columns', 'reuss'),
                    'id' => 'mb_pf_column_r',
                    'type' => 'button_group',
                    'options' => [
                        '2' => esc_html__('2', 'reuss'),
                        '3' => esc_html__('3', 'reuss'),
                        '4' => esc_html__('4', 'reuss'),
                    ],
                    'multiple' => false,
                    'std' => '3',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_portfolio_related_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Number of Related Items', 'reuss'),
                    'id' => 'mb_pf_number_r',
                    'type' => 'number',
                    'min' => 0,
                    'step' => 1,
                    'std' => 3,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_portfolio_related_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
            ],
        ];
        return $meta_boxes;
    }

    public function blog_settings_meta_boxes($meta_boxes)
    {
        $meta_boxes[] = [
            'title' => esc_html__('Post Settings', 'reuss'),
            'post_types' => [ 'post' ],
            'context' => 'advanced',
            'fields' => [
                [
                    'name' => esc_html__('Post Layout Settings', 'reuss'),
                    'type' => 'wgl_heading',
                ],
                [
                    'name' => esc_html__('Post Layout', 'reuss'),
                    'id' => 'mb_post_layout_conditional',
                    'type' => 'button_group',
                    'options' => [
                        'default' => esc_html__('Default', 'reuss'),
                        'custom' => esc_html__('Custom', 'reuss'),
                    ],
                    'multiple' => false,
                    'std' => 'default',
                ],
                [
                    'name' => esc_html__('Post Layout Type', 'reuss'),
                    'id' => 'mb_single_type_layout',
                    'type' => 'button_group',
                    'options' => [
                        '1' => esc_html__('Title First', 'reuss'),
                        '2' => esc_html__('Image First', 'reuss'),
                        '3' => esc_html__('Overlay Image', 'reuss'),
                    ],
                    'multiple' => false,
                    'std' => '1',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_post_layout_conditional', '=', 'custom' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Padding Top/Bottom', 'reuss'),
                    'id' => 'mb_single_padding_layout_3',
                    'type' => 'wgl_offset',
                    'options' => [
                        'mode' => 'padding',
                        'top' => true,
                        'right' => false,
                        'bottom' => true,
                        'left' => false,
                    ],
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_post_layout_conditional', '=', 'custom' ],
                            [ 'mb_single_type_layout', '=', '3' ],
                        ] ],
                    ],
                    'std' => [
                        'padding-top' => '340',
                        'padding-bottom' => '90',
                    ]
                ],
                [
                    'id' => 'mb_single_apply_animation',
                    'name' => esc_html__('Apply Animation', 'reuss'),
                    'type' => 'switch',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_post_layout_conditional', '=', 'custom' ],
                            [ 'mb_single_type_layout', '=', '3' ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Featured Image Settings', 'reuss'),
                    'type' => 'wgl_heading',
                ],
                [
                    'name' => esc_html__('Featured Image', 'reuss'),
                    'id' => 'mb_featured_image_conditional',
                    'type' => 'button_group',
                    'options' => [
                        'default' => esc_html__('Default', 'reuss'),
                        'custom' => esc_html__('Custom', 'reuss'),
                    ],
                    'multiple' => false,
                    'std' => 'default',
                ],
                [
                    'name' => esc_html__('Featured Image Settings', 'reuss'),
                    'id' => 'mb_featured_image_type',
                    'type' => 'button_group',
                    'options' => [
                        'off' => esc_html__('Off', 'reuss'),
                        'replace' => esc_html__('Replace', 'reuss'),
                    ],
                    'multiple' => false,
                    'std' => 'off',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_featured_image_conditional', '=', 'custom' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Featured Image Replace', 'reuss'),
                    'id' => 'mb_featured_image_replace',
                    'type' => 'image_advanced',
                    'max_file_uploads' => 1,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_featured_image_conditional', '=', 'custom' ],
                            [ 'mb_featured_image_type', '=', 'replace' ],
                        ] ],
                    ],
                ],
            ],
        ];
        return $meta_boxes;
    }

    public function blog_meta_boxes($meta_boxes)
    {
        $meta_boxes[] = [
            'title' => esc_html__('Post Format Layout', 'reuss'),
            'post_types' => [ 'post' ],
            'context' => 'advanced',
            'fields' => [
                // Standard Post Format
                [
                    'name' => esc_html__('Standard Post( Enabled only Featured Image for this post format)', 'reuss'),
                    'id' => 'post_format_standard',
                    'type' => 'static-text',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'formatdiv', '=', '0' ]
                        ] ],
                    ],
                ],
                // Gallery Post Format
                [
                    'name' => esc_html__('Gallery Settings', 'reuss'),
                    'type' => 'wgl_heading',
                ],
                [
                    'name' => esc_html__('Add Images', 'reuss'),
                    'id' => 'post_format_gallery',
                    'type' => 'image_advanced',
                    'max_file_uploads' => '',
                ],
                // Video Post Format
                [
                    'name' => esc_html__('Video Settings', 'reuss'),
                    'type' => 'wgl_heading',
                ],
                [
                    'name' => esc_html__('Video Style', 'reuss'),
                    'id' => 'post_format_video_style',
                    'type' => 'select',
                    'options' => [
                        'bg_video' => esc_html__('Background Video', 'reuss'),
                        'popup' => esc_html__('Popup', 'reuss'),
                    ],
                    'multiple' => false,
                    'std' => 'bg_video',
                ],
                [
                    'name' => esc_html__('Start Video', 'reuss'),
                    'id' => 'start_video',
                    'type' => 'number',
                    'std' => '0',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'post_format_video_style', '=', 'bg_video' ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('End Video', 'reuss'),
                    'id' => 'end_video',
                    'type' => 'number',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'post_format_video_style', '=', 'bg_video' ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('oEmbed URL', 'reuss'),
                    'id' => 'post_format_video_url',
                    'type' => 'oembed',
                ],
                // Quote Post Format
                [
                    'name' => esc_html__('Quote Settings', 'reuss'),
                    'type' => 'wgl_heading',
                ],
                [
                    'name' => esc_html__('Quote Text', 'reuss'),
                    'id' => 'post_format_qoute_text',
                    'type' => 'textarea',
                ],
                [
                    'name' => esc_html__('Author Name', 'reuss'),
                    'id' => 'post_format_qoute_name',
                    'type' => 'text',
                ],
                [
                    'name' => esc_html__('Author Position', 'reuss'),
                    'id' => 'post_format_qoute_position',
                    'type' => 'text',
                ],
                [
                    'name' => esc_html__('Author Avatar', 'reuss'),
                    'id' => 'post_format_qoute_avatar',
                    'type' => 'image_advanced',
                    'max_file_uploads' => 1,
                ],
                // Audio Post Format
                [
                    'name' => esc_html__('Audio Settings', 'reuss'),
                    'type' => 'wgl_heading',
                ],
                [
                    'name' => esc_html__('oEmbed URL', 'reuss'),
                    'id' => 'post_format_audio_url',
                    'type' => 'oembed',
                ],
                // Link Post Format
                [
                    'name' => esc_html__('Link Settings', 'reuss'),
                    'type' => 'wgl_heading',
                ],
                [
                    'name' => esc_html__('URL', 'reuss'),
                    'id' => 'post_format_link_url',
                    'type' => 'url',
                ],
                [
                    'name' => esc_html__('Text', 'reuss'),
                    'id' => 'post_format_link_text',
                    'type' => 'text',
                ],
            ]
        ];
        return $meta_boxes;
    }

    public function blog_related_meta_boxes($meta_boxes)
    {
        $meta_boxes[] = [
            'title' => esc_html__('Related Blog Post', 'reuss'),
            'post_types' => [ 'post' ],
            'context' => 'advanced',
            'fields' => [

                [
                    'name' => esc_html__('Related Options', 'reuss'),
                    'id' => 'mb_blog_show_r',
                    'type' => 'button_group',
                    'options' => [
                        'default' => esc_html__('Default', 'reuss'),
                        'custom' => esc_html__('Custom', 'reuss'),
                        'off'  	  => esc_html__('Off', 'reuss'),
                    ],
                    'multiple' => false,
                    'std' => 'default',
                ],
                [
                    'name' => esc_html__('Related Settings', 'reuss'),
                    'type' => 'wgl_heading',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_blog_show_r', '=', 'custom' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Title', 'reuss'),
                    'id' => 'mb_blog_title_r',
                    'type' => 'text',
                    'std' => esc_html__('Related Posts', 'reuss'),
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_blog_show_r', '=', 'custom' ]
                        ], ],
                    ],
                ],
                [
                    'name' => esc_html__('Categories', 'reuss'),
                    'id' => 'mb_blog_cat_r',
                    'multiple' => true,
                    'type' => 'taxonomy_advanced',
                    'taxonomy' => 'category',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_blog_show_r', '=', 'custom' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Columns', 'reuss'),
                    'id' => 'mb_blog_column_r',
                    'type' => 'button_group',
                    'options' => [
                        '12' => esc_html__('1', 'reuss'),
                        '6' => esc_html__('2', 'reuss'),
                        '4' => esc_html__('3', 'reuss'),
                        '3' => esc_html__('4', 'reuss'),
                    ],
                    'multiple' => false,
                    'std' => '6',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_blog_show_r', '=', 'custom' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Number of Related Items', 'reuss'),
                    'id' => 'mb_blog_number_r',
                    'type' => 'number',
                    'min' => 0,
                    'step' => 1,
                    'std' => 2,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_blog_show_r', '=', 'custom' ]
                        ] ],
                    ],
                ],
                [
                    'id' => 'mb_blog_carousel_r',
                    'name' => esc_html__('Display items carousel for this blog post', 'reuss'),
                    'type' => 'switch',
                    'std' => 1,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_blog_show_r', '=', 'custom' ]
                        ] ],
                    ],
                ],
            ],
        ];
        return $meta_boxes;
    }

    public function page_layout_meta_boxes($meta_boxes)
    {

        $meta_boxes[] = [
            'title' => esc_html__('Page Layout', 'reuss'),
            'post_types' => [ 'page' , 'post', 'team', 'practice', 'portfolio', 'product' ],
            'context' => 'advanced',
            'fields' => [
                [
                    'name' => esc_html__('Page Sidebar Layout', 'reuss'),
                    'id' => 'mb_page_sidebar_layout',
                    'type' => 'wgl_image_select',
                    'options' => [
                        'default' => get_template_directory_uri() . '/core/admin/img/options/1c.png',
                        'none' => get_template_directory_uri() . '/core/admin/img/options/none.png',
                        'left' => get_template_directory_uri() . '/core/admin/img/options/2cl.png',
                        'right' => get_template_directory_uri() . '/core/admin/img/options/2cr.png',
                    ],
                    'std' => 'default',
                ],
                [
                    'name' => esc_html__('Sidebar Settings', 'reuss'),
                    'type' => 'wgl_heading',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_sidebar_layout', '!=', 'default' ],
                            [ 'mb_page_sidebar_layout', '!=', 'none' ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Page Sidebar', 'reuss'),
                    'id' => 'mb_page_sidebar_def',
                    'type' => 'select',
                    'placeholder' => 'Select a Sidebar',
                    'options' => reuss_get_all_sidebar(),
                    'multiple' => false,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_sidebar_layout', '!=', 'default' ],
                            [ 'mb_page_sidebar_layout', '!=', 'none' ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Page Sidebar Width', 'reuss'),
                    'id' => 'mb_page_sidebar_def_width',
                    'type' => 'button_group',
                    'options' => [
                        '9' => esc_html( '25%' ),
                        '8' => esc_html( '33%' ),
                    ],
                    'std' => '9',
                    'multiple' => false,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_sidebar_layout', '!=', 'default' ],
                            [ 'mb_page_sidebar_layout', '!=', 'none' ],
                        ] ],
                    ],
                ],
                [
                    'id' => 'mb_sticky_sidebar',
                    'name' => esc_html__('Sticky Sidebar On?', 'reuss'),
                    'type' => 'switch',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_sidebar_layout', '!=', 'default' ],
                            [ 'mb_page_sidebar_layout', '!=', 'none' ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Sidebar Side Gap', 'reuss'),
                    'id' => 'mb_sidebar_gap',
                    'type' => 'select',
                    'options' => [
                        'def' => 'Default',
                        '0' => '0',
                        '15' => '15',
                        '20' => '20',
                        '25' => '25',
                        '30' => '30',
                        '35' => '35',
                        '40' => '40',
                        '45' => '45',
                        '50' => '50',
                    ],
                    'std' => 'def',
                    'multiple' => false,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_sidebar_layout', '!=', 'default' ],
                            [ 'mb_page_sidebar_layout', '!=', 'none' ],
                        ] ],
                    ],
                ],
            ]
        ];
        return $meta_boxes;
    }

    public function page_color_meta_boxes($meta_boxes)
    {

        $meta_boxes[] = [
            'title' => esc_html__('Page Colors', 'reuss'),
            'post_types' => [ 'page' , 'post', 'team', 'practice', 'portfolio' ],
            'context' => 'advanced',
            'fields' => [
                [
                    'name' => esc_html__('Page Colors', 'reuss'),
                    'id' => 'mb_page_colors_switch',
                    'type' => 'button_group',
                    'options' => [
                        'default' => esc_html__('Default', 'reuss'),
                        'custom' => esc_html__('Custom', 'reuss'),
                    ],
                    'inline' => true,
                    'multiple' => false,
                    'std' => 'default',
                ],
                [
                    'name' => esc_html__('Colors Settings', 'reuss'),
                    'type' => 'wgl_heading',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_colors_switch', '=', 'custom' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('General Theme Color', 'reuss'),
                    'id' => 'mb_page_theme_color',
                    'type' => 'color',
                    'std' => '#ff7268',
                    'js_options' => [ 'defaultColor' => '#ff7268' ],
                    'validate' => 'color',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_colors_switch', '=', 'custom' ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Secondary Theme Color', 'reuss'),
                    'id' => 'mb_page_secondary_color',
                    'type' => 'color',
                    'std' => '#8e6de2',
                    'js_options' => [ 'defaultColor' => '#8e6de2' ],
                    'validate' => 'color',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_colors_switch', '=', 'custom' ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Tertiary Theme Color', 'reuss'),
                    'id' => 'mb_page_tertiary_color',
                    'type' => 'color',
                    'std' => '#1fe8f5',
                    'js_options' => [ 'defaultColor' => '#1fe8f5' ],
                    'validate' => 'color',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_colors_switch', '=', 'custom' ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Body Background Color', 'reuss'),
                    'id' => 'mb_body_background_color',
                    'type' => 'color',
                    'std' => '#ffffff',
                    'js_options' => [ 'defaultColor' => '#ffffff' ],
                    'validate' => 'color',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_colors_switch', '=', 'custom' ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Gradient Settings', 'reuss'),
                    'type' => 'wgl_heading',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_colors_switch', '=', 'custom' ]
                        ] ],
                    ],
                ],
				[
					'id'   => 'mb_use-gradient',
					'name' => esc_html__( 'Use Theme Gradient?', 'reuss' ),
					'type' => 'switch',
					'attributes' => [
					    'data-conditional-logic'  => [ [
							['mb_page_colors_switch','=','custom']
                        ] ],
                    ],
                ],
				[
					'name'     	=> esc_html__( 'Theme Gradient From', 'reuss' ),
	                'id'        => 'mb_theme-gradient-from',
	                'type'      => 'color',
	                'std'         => '#ff7268',
					'js_options' => [
						'defaultColor' => '#ff7268',
                    ],
	                'validate'  => 'color',
					'attributes' => [
					    'data-conditional-logic'  => [ [
							['mb_use-gradient','=','1'],
							['mb_page_colors_switch','=','custom']
                        ] ],
                    ],
                ],
				[
					'name'     	=> esc_html__( 'Theme Gradient To', 'reuss' ),
	                'id'        => 'mb_theme-gradient-to',
	                'type'      => 'color',
	                'std'         => '#ffb06c',
					'js_options' => [
						'defaultColor' => '#ffb06c',
                    ],
	                'validate'  => 'color',
					'attributes' => [
					    'data-conditional-logic'  => [ [
							['mb_use-gradient','=','1'],
							['mb_page_colors_switch','=','custom']
                        ] ],
                    ],
                ],
				[
					'name'     	=> esc_html__( 'Second Gradient From', 'reuss' ),
	                'id'        => 'mb_second-gradient-from',
	                'type'      => 'color',
	                'std'         => '#643cb5',
					'js_options' => [
						'defaultColor' => '#643cb5',
                    ],
	                'validate'  => 'color',
					'attributes' => [
					    'data-conditional-logic'  => [ [
							['mb_use-gradient','=','1'],
							['mb_page_colors_switch','=','custom']
                        ] ],
                    ],
                ],
				[
					'name'     	=> esc_html__( 'Second Gradient To', 'reuss' ),
	                'id'        => 'mb_second-gradient-to',
	                'type'      => 'color',
	                'std'         => '#c670ea',
					'js_options' => [
						'defaultColor' => '#c670ea',
                    ],
	                'validate'  => 'color',
					'attributes' => [
					    'data-conditional-logic'  => [ [
							['mb_use-gradient','=','1'],
							['mb_page_colors_switch','=','custom']
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Gradient Settings', 'reuss'),
                    'type' => 'wgl_heading',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_colors_switch', '=', 'custom' ]
                        ] ],
                    ],
                ],
				[
					'id'   => 'mb_use-button-gradient',
					'name' => esc_html__( 'Use Buttons Color/Gradient?', 'reuss' ),
                    'type' => 'switch',
                    'std' => true,
					'attributes' => [
					    'data-conditional-logic'  => [ [
							['mb_page_colors_switch','=','custom']
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Buttons Idle Color', 'reuss'),
                    'id' => 'mb_button_color',
                    'type' => 'color',
                    'std' => '#ff7268',
                    'js_options' => [ 'defaultColor' => '#ff7268' ],
                    'validate' => 'color',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_colors_switch', '=', 'custom' ],
                            [ 'mb_use-button-gradient', '!=', '1' ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Buttons Hover Color', 'reuss'),
                    'id' => 'mb_button_hover_color',
                    'type' => 'color',
                    'std' => '#8e6de2',
                    'js_options' => [ 'defaultColor' => '#8e6de2' ],
                    'validate' => 'color',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_colors_switch', '=', 'custom' ],
                            [ 'mb_use-button-gradient', '!=', '1' ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Buttons Secondary Idle Color', 'reuss'),
                    'id' => 'mb_button_secondary_color',
                    'type' => 'color',
                    'std' => '#ff7268',
                    'js_options' => [ 'defaultColor' => '#643cb5' ],
                    'validate' => 'color',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_colors_switch', '=', 'custom' ],
                            [ 'mb_use-button-gradient', '!=', '1' ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Buttons Secondary Hover Color', 'reuss'),
                    'id' => 'mb_button_hover_color',
                    'type' => 'color',
                    'std' => '#8e6de2',
                    'js_options' => [ 'defaultColor' => '#c670ea' ],
                    'validate' => 'color',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_colors_switch', '=', 'custom' ],
                            [ 'mb_use-button-gradient', '!=', '1' ],
                        ] ],
                    ],
                ],
				[
					'name'     	=> esc_html__( 'Buttons GradientFrom', 'reuss' ),
	                'id'        => 'mb_button-gradient-from',
	                'type'      => 'color',
	                'std'         => '#ff7268',
					'js_options' => [
						'defaultColor' => '#ff7268',
                    ],
	                'validate'  => 'color',
					'attributes' => [
					    'data-conditional-logic'  => [ [
                            [ 'mb_page_colors_switch', '=', 'custom' ],
                            [ 'mb_use-button-gradient', '=', '1' ],
                        ] ],
                    ],
                ],
				[
					'name'     	=> esc_html__( 'Buttons GradientTo', 'reuss' ),
	                'id'        => 'mb_button-gradient-to',
	                'type'      => 'color',
	                'std'         => '#ffb06c',
					'js_options' => [
						'defaultColor' => '#ffb06c',
                    ],
	                'validate'  => 'color',
					'attributes' => [
					    'data-conditional-logic'  => [ [
                            [ 'mb_page_colors_switch', '=', 'custom' ],
                            [ 'mb_use-button-gradient', '=', '1' ],
                        ] ],
                    ],
                ],
				[
					'name'     	=> esc_html__( 'Buttons Secondary GradientFrom', 'reuss' ),
	                'id'        => 'mb_button-gradient-from',
	                'type'      => 'color',
	                'std'         => '#643cb5',
					'js_options' => [
						'defaultColor' => '#643cb5',
                    ],
	                'validate'  => 'color',
					'attributes' => [
					    'data-conditional-logic'  => [ [
                            [ 'mb_page_colors_switch', '=', 'custom' ],
                            [ 'mb_use-button-gradient', '=', '1' ],
                        ] ],
                    ],
                ],
				[
					'name'     	=> esc_html__( 'Buttons Secondary GradientTo', 'reuss' ),
	                'id'        => 'mb_button-gradient-to',
	                'type'      => 'color',
	                'std'         => '#c670ea',
					'js_options' => [
						'defaultColor' => '#c670ea',
                    ],
	                'validate'  => 'color',
					'attributes' => [
					    'data-conditional-logic'  => [ [
                            [ 'mb_page_colors_switch', '=', 'custom' ],
                            [ 'mb_use-button-gradient', '=', '1' ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Scroll Up Settings', 'reuss'),
                    'type' => 'wgl_heading',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_colors_switch', '=', 'custom' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Button Arrow Color', 'reuss'),
                    'id' => 'mb_scroll_up_arrow_color',
                    'type' => 'color',
                    'std' => '#ffffff',
                    'js_options' => [ 'defaultColor' => '#ffffff' ],
                    'validate' => 'color',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_colors_switch', '=', 'custom' ],
                        ] ],
                    ],
                ],
				[
					'id'   => 'mb_scroll_up_gradient_switch',
					'name' => esc_html__( 'Use Theme Gradient?', 'reuss' ),
					'type' => 'switch',
					'attributes' => [
					    'data-conditional-logic'  => [ [
							['mb_page_colors_switch','=','custom']
                        ] ],
                    ],
                ],
				[
					'name'     	=> esc_html__( 'Button Gradient From', 'reuss' ),
	                'id'        => 'mb_scroll_up_bg_gradient_from',
	                'type'      => 'color',
	                'std'         => '#ff7268',
					'js_options' => [
						'defaultColor' => '#ff7268',
                    ],
	                'validate'  => 'color',
					'attributes' => [
					    'data-conditional-logic'  => [ [
							['mb_scroll_up_gradient_switch','=','1'],
							['mb_page_colors_switch','=','custom']
                        ] ],
                    ],
                ],
				[
					'name'     	=> esc_html__( 'Button Gradient To', 'reuss' ),
	                'id'        => 'mb_scroll_up_bg_gradient_to',
	                'type'      => 'color',
	                'std'         => '#ffb06c',
					'js_options' => [
						'defaultColor' => '#ffb06c',
                    ],
	                'validate'  => 'color',
					'attributes' => [
					    'data-conditional-logic'  => [ [
							['mb_scroll_up_gradient_switch','=','1'],
							['mb_page_colors_switch','=','custom']
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Button Background Color', 'reuss'),
                    'id' => 'mb_scroll_up_bg_color',
                    'type' => 'color',
                    'std' => '#ff9e21',
                    'js_options' => [ 'defaultColor' => '#ff9e21' ],
                    'validate' => 'color',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_scroll_up_gradient_switch', '!=', '1' ],
							['mb_page_colors_switch','=','custom']
                        ] ],
                    ],
                ],
            ]
        ];
        return $meta_boxes;
    }

    public function page_header_meta_boxes($meta_boxes)
    {
        $meta_boxes[] = [
            'title' => esc_html__( 'Header', 'reuss' ),
            'post_types' => [ 'page', 'post', 'portfolio', 'product' ],
            'context' => 'advanced',
            'fields' => [
                [
                    'name' => esc_html__( 'Header Settings', 'reuss' ),
                    'id' => 'mb_customize_header_layout',
                    'type' => 'button_group',
                    'options' => [
                        'default' => esc_html__( 'default', 'reuss' ),
                        'custom' => esc_html__( 'custom', 'reuss' ),
                        'hide' => esc_html__( 'hide', 'reuss' ),
                    ],
                    'multiple' => false,
                    'std' => 'default',
                ],
                [
                    'name' => esc_html__( 'Header Template', 'reuss' ),
                    'id' => 'mb_header_content_type',
                    'type' => 'button_group',
                    'options' => [
                        'default' => esc_html__( 'Default', 'reuss' ),
                        'custom' => esc_html__( 'Custom', 'reuss' )
                    ],
                    'multiple' => false,
                    'std' => 'default',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            ['mb_customize_header_layout', '=', 'custom']
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__( 'Template', 'reuss' ),
                    'id' => 'mb_customize_header',
                    'type' => 'post',
                    'post_type' => 'header',
                    'query_args' => [
                        'post_status' => 'publish',
                        'posts_per_page' => - 1,
                    ],
                    'multiple' => false,
                    'std' => 'default',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            ['mb_customize_header_layout', '=', 'custom'],
                            ['mb_header_content_type', '=', 'custom'],
                        ] ],
                    ],
                ],
                [
                    'id' => 'mb_header_sticky',
                    'name' => esc_html__( 'Sticky Header', 'reuss' ),
                    'type' => 'switch',
                    'std' => 1,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            ['mb_customize_header_layout', '=', 'custom']
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__( 'Sticky Header Template', 'reuss' ),
                    'id' => 'mb_sticky_header_content_type',
                    'type' => 'button_group',
                    'options' => [
                        'default' => esc_html__( 'Default', 'reuss' ),
                        'custom' => esc_html__( 'Custom', 'reuss' )
                    ],
                    'multiple' => false,
                    'std' => 'default',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            ['mb_customize_header_layout', '=', 'custom'],
                            ['mb_header_sticky','=','1'],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__( 'Template', 'reuss' ),
                    'id' => 'mb_customize_sticky_header',
                    'type' => 'post',
                    'post_type' => 'header',
                    'query_args' => [
                        'post_status' => 'publish',
                        'posts_per_page' => - 1,
                    ],
                    'multiple' => false,
                    'std' => 'default',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            ['mb_customize_header_layout', '=', 'custom'],
                            ['mb_sticky_header_content_type', '=', 'custom'],
                            ['mb_header_sticky','=','1'],
                        ] ],
                    ],
                ],
                // It is works 
				[
					'id'   => 'mb_mobile_menu_header',
					'name' => esc_html__( 'Mobile Menu ', 'reuss' ),
					'type' => 'select',
					'options'     => reuss_get_custom_menu(),
					'multiple'    => false,
					'std'         => 'default',
					'attributes' => [
					    'data-conditional-logic'  =>  [ [
							['mb_customize_header_layout','=','custom']
                        ] ],
                    ],
                ],
            ]
        ];
        return $meta_boxes;
    }

    public function page_title_meta_boxes($meta_boxes)
    {
        $meta_boxes[] = [
            'title' => esc_html__('Page Title', 'reuss'),
            'post_types' => [ 'page', 'post', 'team', 'practice', 'portfolio', 'product' ],
            'context' => 'advanced',
            'fields' => [
                [
                    'id' => 'mb_page_title_switch',
                    'name' => esc_html__('Page Title', 'reuss'),
                    'type' => 'button_group',
                    'options' => [
                        'default' => esc_html__('Default', 'reuss'),
                        'on' => esc_html__('On', 'reuss'),
                        'off' => esc_html__('Off', 'reuss'),
                    ],
                    'std' => 'default',
                    'inline' => true,
                    'multiple' => false
                ],
                [
                    'name' => esc_html__('Page Title Settings', 'reuss'),
                    'type' => 'wgl_heading',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'id' => 'mb_page_title_bg_switch',
                    'name' => esc_html__('Use Background?', 'reuss'),
                    'type' => 'switch',
                    'std' => true,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=' , 'on' ]
                        ] ],
                    ],
                ],
                [
                    'id' => 'mb_page_title_bg',
                    'name' => esc_html__('Background', 'reuss'),
                    'type' => 'wgl_background',
                    'image' => '',
                    'position' => 'center bottom',
                    'attachment' => 'scroll',
                    'size' => 'cover',
                    'repeat' => 'no-repeat',
                    'color' => '#2f057b',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ],
                            [ 'mb_page_title_bg_switch', '=', true ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Height', 'reuss'),
                    'id' => 'mb_page_title_height',
                    'type' => 'number',
                    'std' => 300,
                    'min' => 0,
                    'step' => 1,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ],
                            [ 'mb_page_title_bg_switch', '=', true ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Title Alignment', 'reuss'),
                    'id' => 'mb_page_title_align',
                    'type' => 'button_group',
                    'options' => [
                        'left' => esc_html__('left', 'reuss'),
                        'center' => esc_html__('center', 'reuss'),
                        'right' => esc_html__('right', 'reuss'),
                    ],
                    'std' => 'center',
                    'multiple' => false,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=' , 'on' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Paddings Top/Bottom', 'reuss'),
                    'id' => 'mb_page_title_padding',
                    'type' => 'wgl_offset',
                    'options' => [
                        'mode' => 'padding',
                        'top' => true,
                        'right' => false,
                        'bottom' => true,
                        'left' => false,
                    ],
                    'std' => [
                        'padding-top' => '60',
                        'padding-bottom' => '60',
                    ],
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=' , 'on' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Margin Bottom', 'reuss'),
                    'id' => 'mb_page_title_margin',
                    'type' => 'wgl_offset',
                    'options' => [
                        'mode' => 'margin',
                        'top' => false,
                        'right' => false,
                        'bottom' => true,
                        'left' => false,
                    ],
                    'std' => [ 'margin-bottom' => '50' ],
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'id' => 'mb_page_title_border_switch',
                    'name' => esc_html__('Border Top Switch', 'reuss'),
                    'type' => 'switch',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Border Top Color', 'reuss'),
                    'id' => 'mb_page_title_border_color',
                    'type' => 'color',
                    'std' => '#e5e5e5',
                    'js_options' => [ 'defaultColor' => '#e5e5e5' ],
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_border_switch', '=',true]
                        ] ],
                    ],
                ],
                [
                    'id' => 'mb_page_title_parallax',
                    'name' => esc_html__('Parallax Switch', 'reuss'),
                    'type' => 'switch',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Prallax Speed', 'reuss'),
                    'id' => 'mb_page_title_parallax_speed',
                    'type' => 'number',
                    'std' => 0.3,
                    'step' => 0.1,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_parallax', '=',true ],
                            [ 'mb_page_title_switch', '=', 'on' ],
                        ] ],
                    ],
                ],
                [
                    'id' => 'mb_page_change_tile_switch',
                    'name' => esc_html__('Custom Page Title', 'reuss'),
                    'type' => 'switch',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Page Title', 'reuss'),
                    'id' => 'mb_page_change_tile',
                    'type' => 'text',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_change_tile_switch', '=', '1' ],
                            [ 'mb_page_title_switch', '=', 'on' ],
                        ] ],
                    ],
                ],
                [
                    'id' => 'mb_page_title_breadcrumbs_switch',
                    'name' => esc_html__('Show Breadcrumbs', 'reuss'),
                    'type' => 'switch',
                    'std' => 1,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Breadcrumbs Alignment', 'reuss'),
                    'id' => 'mb_page_title_breadcrumbs_align',
                    'type' => 'button_group',
                    'options' => [
                        'left' => esc_html__('left', 'reuss'),
                        'center' => esc_html__('center', 'reuss'),
                        'right' => esc_html__('right', 'reuss'),
                    ],
                    'std' => 'center',
                    'multiple' => false,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ],
                            [ 'mb_page_title_breadcrumbs_switch', '=', '1' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Breadcrumbs Full Width', 'reuss'),
                    'id' => 'mb_page_title_breadcrumbs_block_switch',
                    'type' => 'switch',
                    'std' => true,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ],
                            [ 'mb_page_title_breadcrumbs_switch', '=', '1' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Page Title Typography', 'reuss'),
                    'type' => 'wgl_heading',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Page Title Font', 'reuss'),
                    'id' => 'mb_page_title_font',
                    'type' => 'wgl_font',
                    'options' => [
                        'font-size' => true,
                        'line-height' => true,
                        'font-weight' => false,
                        'color' => true,
                    ],
                    'std' => [
                        'font-size' => '40',
                        'line-height' => '52',
                        'color' => '#ffffff',
                    ],
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Page Title Breadcrumbs Font', 'reuss'),
                    'id' => 'mb_page_title_breadcrumbs_font',
                    'type' => 'wgl_font',
                    'options' => [
                        'font-size' => true,
                        'line-height' => true,
                        'font-weight' => false,
                        'color' => true,
                    ],
                    'std' => [
                        'font-size' => '14',
                        'line-height' => '24',
                        'color' => '#fefeff',
                    ],
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Responsive Layout', 'reuss'),
                    'type' => 'wgl_heading',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'id' => 'mb_page_title_resp_switch',
                    'name' => esc_html__('Responsive Layout On/Off', 'reuss'),
                    'type' => 'switch',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Screen breakpoint', 'reuss'),
                    'id' => 'mb_page_title_resp_resolution',
                    'type' => 'number',
                    'std' => 768,
                    'min' => 1,
                    'step' => 1,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ],
                            [ 'mb_page_title_resp_switch', '=', '1' ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Height', 'reuss'),
                    'id' => 'mb_page_title_resp_height',
                    'type' => 'number',
                    'std' => 180,
                    'min' => 0,
                    'step' => 1,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ],
                            [ 'mb_page_title_resp_switch', '=', '1' ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Padding Top/Bottom', 'reuss'),
                    'id' => 'mb_page_title_resp_padding',
                    'type' => 'wgl_offset',
                    'options' => [
                        'mode' => 'padding',
                        'top' => true,
                        'right' => false,
                        'bottom' => true,
                        'left' => false,
                    ],
                    'std' => [
                        'padding-top' => '15',
                        'padding-bottom' => '15',
                    ],
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ],
                            [ 'mb_page_title_resp_switch', '=', '1' ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Page Title Font', 'reuss'),
                    'id' => 'mb_page_title_resp_font',
                    'type' => 'wgl_font',
                    'options' => [
                        'font-size' => true,
                        'line-height' => true,
                        'font-weight' => false,
                        'color' => true,
                    ],
                    'std' => [
                        'font-size' => '42',
                        'line-height' => '48',
                        'color' => '#ffffff',
                    ],
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ],
                            [ 'mb_page_title_resp_switch', '=', '1' ],
                        ] ],
                    ],
                ],
                [
                    'id' => 'mb_page_title_resp_breadcrumbs_switch',
                    'name' => esc_html__('Show Breadcrumbs', 'reuss'),
                    'type' => 'switch',
                    'std' => 1,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ],
                            [ 'mb_page_title_resp_switch', '=', '1' ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Page Title Breadcrumbs Font', 'reuss'),
                    'id' => 'mb_page_title_resp_breadcrumbs_font',
                    'type' => 'wgl_font',
                    'options' => [
                        'font-size' => true,
                        'line-height' => true,
                        'font-weight' => false,
                        'color' => true,
                    ],
                    'std' => [
                        'font-size' => '16',
                        'line-height' => '24',
                        'color' => '#fefeff',
                    ],
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_page_title_switch', '=', 'on' ],
                            [ 'mb_page_title_resp_switch', '=', '1' ],
                            [ 'mb_page_title_resp_breadcrumbs_switch', '=', '1' ],
                        ] ],
                    ],
                ],
            ],
        ];
        return $meta_boxes;
    }

    public function page_side_panel_meta_boxes($meta_boxes)
    {
        $meta_boxes[] = [
            'title' => esc_html__('Side Panel', 'reuss'),
            'post_types' => [ 'page' ],
            'context' => 'advanced',
            'fields' => [
                [
                    'name' => esc_html__('Side Panel', 'reuss'),
                    'id' => 'mb_customize_side_panel',
                    'type' => 'button_group',
                    'options' => [
                        'default' => esc_html__('Default', 'reuss'),
                        'custom' => esc_html__('Custom', 'reuss'),
                    ],
                    'multiple' => false,
                    'inline' => true,
                    'std' => 'default',
                ],
                [
                    'name' => esc_html__('Side Panel Settings', 'reuss'),
                    'type' => 'wgl_heading',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_customize_side_panel', '=', 'custom' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Content Type', 'reuss'),
                    'id' => 'mb_side_panel_content_type',
                    'type' => 'button_group',
                    'options' => [
                        'widgets' => esc_html__('Widgets', 'reuss'),
                        'pages' => esc_html__('Page', 'reuss')
                    ],
                    'multiple' => false,
                    'std' => 'widgets',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_customize_side_panel', '=', 'custom' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Select a page', 'reuss'),
                    'id' => 'mb_side_panel_page_select',
                    'type' => 'post',
                    'post_type' => 'side_panel',
                    'field_type' => 'select_advanced',
                    'placeholder' => 'Select a page',
                    'query_args' => [
                        'post_status' => 'publish',
                        'posts_per_page' => - 1,
                    ],
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_customize_side_panel', '=', 'custom' ],
                            [ 'mb_side_panel_content_type', '=', 'pages' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Paddings', 'reuss'),
                    'id' => 'mb_side_panel_spacing',
                    'type' => 'wgl_offset',
                    'options' => [
                        'mode' => 'padding',
                        'top' => true,
                        'right' => true,
                        'bottom' => true,
                        'left' => true,
                    ],
                    'std' => [
                        'padding-top' => '105',
                        'padding-right' => '90',
                        'padding-bottom' => '105',
                        'padding-left' => '90'
                    ],
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_customize_side_panel', '=', 'custom' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Title Color', 'reuss'),
                    'id' => 'mb_side_panel_title_color',
                    'type' => 'color',
                    'std' => '#ffffff',
                    'js_options' => [ 'defaultColor' => '#ffffff' ],
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_customize_side_panel', '=', 'custom' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Text Color', 'reuss'),
                    'id' => 'mb_side_panel_text_color',
                    'type' => 'color',
                    'std' => '#313538',
                    'js_options' => [ 'defaultColor' => '#313538' ],
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_customize_side_panel', '=', 'custom' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Background Color', 'reuss'),
                    'id' => 'mb_side_panel_bg',
                    'type' => 'color',
                    'std' => '#ffffff',
                    'alpha_channel' => true,
                    'js_options' => [ 'defaultColor' => '#ffffff' ],
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_customize_side_panel', '=', 'custom' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Text Align', 'reuss'),
                    'id' => 'mb_side_panel_text_alignment',
                    'type' => 'button_group',
                    'options' => [
                        'left' => esc_html__('Left', 'reuss'),
                        'center' => esc_html__('Center', 'reuss'),
                        'right' => esc_html__('Right', 'reuss'),
                    ],
                    'multiple' => false,
                    'std' => 'center',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_customize_side_panel', '=', 'custom' ]
                        ], ],
                    ],
                ],
                [
                    'name' => esc_html__('Width', 'reuss'),
                    'id' => 'mb_side_panel_width',
                    'type' => 'number',
                    'min' => 0,
                    'step' => 1,
                    'std' => 480,
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_customize_side_panel', '=', 'custom' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Position', 'reuss'),
                    'id' => 'mb_side_panel_position',
                    'type' => 'button_group',
                    'options' => [
                        'left' => esc_html__('Left', 'reuss'),
                        'right' => esc_html__('Right', 'reuss'),
                    ],
                    'multiple' => false,
                    'std' => 'right',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                                [ 'mb_customize_side_panel', '=', 'custom' ]
                        ] ],
                    ],
                ],
            ]
        ];
        return $meta_boxes;
    }

    public function page_footer_meta_boxes($meta_boxes)
    {
        $meta_boxes[] = [
            'title' => esc_html__('Footer', 'reuss'),
            'post_types' => [ 'page' ],
            'context' => 'advanced',
            'fields' => [
                [
                    'name' => esc_html__('Footer', 'reuss'),
                    'id' => 'mb_footer_switch',
                    'type' => 'button_group',
                    'options' => [
                        'default' => esc_html__('Default', 'reuss'),
                        'on' => esc_html__('On', 'reuss'),
                        'off' => esc_html__('Off', 'reuss'),
                    ],
                    'multiple' => false,
                    'std' => 'default',
                ],
                [
                    'name' => esc_html__('Footer Settings', 'reuss'),
                    'type' => 'wgl_heading',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_footer_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Content Type', 'reuss'),
                    'id' => 'mb_footer_content_type',
                    'type' => 'button_group',
                    'options' => [
                        'widgets' => esc_html__('Widgets', 'reuss'),
                        'pages' => esc_html__('Page', 'reuss')
                    ],
                    'multiple' => false,
                    'std' => 'pages',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_footer_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Select a page', 'reuss'),
                    'id' => 'mb_footer_page_select',
                    'type' => 'post',
                    'post_type' => 'footer',
                    'field_type' => 'select_advanced',
                    'placeholder' => 'Select a page',
                    'query_args' => [
                        'post_status' => 'publish',
                        'posts_per_page' => - 1,
                    ],
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_footer_switch', '=', 'on' ],
                            [ 'mb_footer_content_type', '=', 'pages' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Paddings', 'reuss'),
                    'id' => 'mb_footer_spacing',
                    'type' => 'wgl_offset',
                    'options' => [
                        'mode' => 'padding',
                        'top' => true,
                        'right' => true,
                        'bottom' => true,
                        'left' => true,
                    ],
                    'std' => [
                        'padding-top' => '0',
                        'padding-right' => '0',
                        'padding-bottom' => '0',
                        'padding-left' => '0'
                    ],
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_footer_switch', '=', 'on' ],
                            [ 'mb_footer_content_type', '=', 'widgets' ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Background', 'reuss'),
                    'id' => 'mb_footer_bg',
                    'type' => 'wgl_background',
                    'image' => '',
                    'position' => 'center center',
                    'attachment' => 'scroll',
                    'size' => 'cover',
                    'repeat' => 'no-repeat',
                    'color' => '#ffffff',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_footer_switch', '=', 'on' ],
                            [ 'mb_footer_content_type', '=', 'widgets' ],
                        ] ],
                    ],
                ],
                [
                    'id' => 'mb_footer_add_border',
                    'name' => esc_html__('Add Border Top', 'reuss'),
                    'type' => 'switch',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_footer_switch', '=', 'on' ],
                            [ 'mb_footer_content_type', '=', 'widgets' ],
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Border Color', 'reuss'),
                    'id' => 'mb_footer_border_color',
                    'type' => 'color',
                    'std' => '#e5e5e5',
                    'alpha_channel' => true,
                    'js_options' => [
                        'defaultColor' => '#e5e5e5',
                    ],
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_footer_switch', '=', 'on' ],
                            [ 'mb_footer_add_border', '=', '1' ],
                        ] ],
                    ],
                ],
            ],
        ];
        return $meta_boxes;
    }

    public function page_copyright_meta_boxes($meta_boxes)
    {
        $meta_boxes[] = [
            'title' => esc_html__('Copyright', 'reuss'),
            'post_types' => [ 'page' ],
            'context' => 'advanced',
            'fields' => [
                [
                    'name' => esc_html__('Copyright', 'reuss'),
                    'id' => 'mb_copyright_switch',
                    'type' => 'button_group',
                    'options' => [
                        'default' => esc_html__('Default', 'reuss'),
                        'on' => esc_html__('On', 'reuss'),
                        'off' => esc_html__('Off', 'reuss'),
                    ],
                    'multiple' => false,
                    'std' => 'default',
                ],
                [
                    'name' => esc_html__('Copyright Settings', 'reuss'),
                    'type' => 'wgl_heading',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_copyright_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Editor', 'reuss'),
                    'id' => 'mb_copyright_editor',
                    'type' => 'textarea',
                    'cols' => 20,
                    'rows' => 3,
                    'std' => 'Copyright © 2020 Reuss by WebGeniusLab. All Rights Reserved',
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_copyright_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Text Color', 'reuss'),
                    'id' => 'mb_copyright_text_color',
                    'type' => 'color',
                    'std' => '#838383',
                    'js_options' => [
                        'defaultColor' => '#838383',
                    ],
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_copyright_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Background Color', 'reuss'),
                    'id' => 'mb_copyright_bg_color',
                    'type' => 'color',
                    'std' => '#171a1e',
                    'js_options' => [
                        'defaultColor' => '#171a1e',
                    ],
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_copyright_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
                [
                    'name' => esc_html__('Paddings', 'reuss'),
                    'id' => 'mb_copyright_spacing',
                    'type' => 'wgl_offset',
                    'options' => [
                        'mode' => 'padding',
                        'top' => true,
                        'right' => false,
                        'bottom' => true,
                        'left' => false,
                    ],
                    'std' => [
                        'padding-top' => '10',
                        'padding-bottom' => '10',
                    ],
                    'attributes' => [
                        'data-conditional-logic' => [ [
                            [ 'mb_copyright_switch', '=', 'on' ]
                        ] ],
                    ],
                ],
            ],
        ];
        return $meta_boxes;
    }
}

new Reuss_Metaboxes();
