<?php

namespace WglAddons\Widgets;

defined('ABSPATH') || exit; // Abort, If called directly.

use WglAddons\Includes\Wgl_Icons;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Utils;


class Wgl_Header_Search extends Widget_Base
{

    public function get_name()
    {
        return 'wgl-header-search';
    }

    public function get_title()
    {
        return esc_html__('WGL Search', 'reuss-core');
    }

    public function get_icon()
    {
        return 'wgl-header-search';
    }

    public function get_categories()
    {
        return ['wgl-header-modules'];
    }

    public function get_script_depends()
    {
        return [ 'wgl-elementor-extensions-widgets' ];
    }

    protected function _register_controls()
    {
        $primary_color = esc_attr(\Reuss_Theme_Helper::get_option('theme-primary-color'));
        $h_font_color = esc_attr(\Reuss_Theme_Helper::get_option('header-font')['color']);


        /*-----------------------------------------------------------------------------------*/
        /*  CONTENT -> GENERAL
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'section_content_general',
            ['label' => esc_html__('General', 'reuss-core')]
        );

        $this->add_control(
            'search_height',
            [
                'label' => esc_html__('Search Height', 'reuss-core'),
                'type' => Controls_Manager::NUMBER,
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .header_search' => 'height: {{VALUE}}px;',
                ],
            ]
        );

        $this->add_control(
            'search_alignment',
            [
                'label' => esc_html__('Alignment', 'reuss-core'),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'flex-start' => [
                        'title' => esc_html__('Left', 'reuss-core'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'reuss-core'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'flex-end' => [
                        'title' => esc_html__('Right', 'reuss-core'),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'label_block' => false,
                'default' => 'center',
                'toggle' => true,
                'selectors' => [
                    '{{WRAPPER}} .wgl-search' => 'justify-content: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  STYLE -> SEARCH
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'section_style_search',
            [
                'label' => esc_html__('Search', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'icon_color',
            [
                'label' => esc_html__('Icon Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .header_search-button-wrapper' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'search_padding',
            [
                'label' => esc_html__('Padding', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'separator' => 'before',
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .header_search' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

    public function render()
    {
        $description = esc_html__('Type To Search', 'reuss-core');
        $search_style = \Reuss_Theme_Helper::get_option('search_style') ?? 'standard';
        $search_counter = null;

        if (class_exists('\Reuss_Get_Header')) {
            $search_counter = \Reuss_Get_Header::$search_form_counter ?? null;
        }

        $search_class = ' search_' . \Reuss_Theme_Helper::get_option('search_style');

        $render_search = true;
        if ($search_style === 'alt') {
            // the only search form in Default and Sticky headers is allowed
            $render_search = $search_counter > 0 ? false : true;

            if (isset($search_counter)) \Reuss_Get_Header::$search_form_counter++;
        }

        $this->add_render_attribute('search', 'class', ['wgl-search elementor-search header_search-button-wrapper']);
        $this->add_render_attribute('search', 'role', 'button');

        echo '<div class="header_search' . esc_attr($search_class) . '">';

        echo '<div ', $this->get_render_attribute_string('search'), '>',
            '<div class="header_search-button flaticon-find"></div>',
            '<div class="header_search-close"></div>',
            '</div>';

        if ($render_search) {
            echo '<div class="header_search-field">';
            if ($search_style === 'alt') {
                echo '<div class="header_search-wrap">',
                    '<div class="reuss_module_double_headings aleft">',
                    '<h3 class="header_search-heading_description heading_title">',
                        apply_filters('reuss_desc_search', $description),
                    '</h3>',
                    '</div>',
                    '<div class="header_search-close"></div>',
                '</div>';
            }
            echo get_search_form(false);
            echo '</div>'; // header_search-field
        }

        echo '</div>'; // header_search
    }
}
