<?php

namespace WglAddons\Includes;

use Elementor\Plugin;

defined( 'ABSPATH' ) || exit;

/**
* Wgl Elementor Helper Settings
*
*
* @class Wgl_Elementor_Helper
* @version 1.0
* @category Class
* @author WebGeniusLab
*/

if (!class_exists('Wgl_Elementor_Helper')) {

    class Wgl_Elementor_Helper
    {

        private static $instance = null;
        public static function get_instance() {
            
            if ( null == self::$instance ) {
                self::$instance = new self();
            }

            return self::$instance;
        }

        public function get_wgl_icons() {
            return [
                'find',
                'arrow',
                'arrow-point-to-right',
                'arrowhead-thin-outline-to-the-left',
                'navigate-up-arrow',
                'behance',
                'ball',
                'vector',
                'design',
                'vector-1',
                'paint',
                'calendar',
                'mail',
                'send',
                'phone',
                'phone-1',
                'behance-1',
                'pen',
                'design-1',
                'app',
                'ui',
                'camera',
                'model',
                'ui-1',
                'heart',
                'share',
                'network',
                'camera-retro',
                'pixel',
                'lightbulb',
                'gps',
                'avatar',
                'arrows',
                'emergency',
                'diamond',
                'close',
                'launch',
                'solution',
                'design-2',
                'pipette',
                'sharing',
                'prototype',
                'inspiration',
                'filter',
                'filter-1',
                'shopping-cart',
                'menu',
                'supermarket',
                'pin',
                'placeholder',
                'pie-chart',
                'rocket',
                'growth',
                'dashboard',
                'play',
                'left-quote',
                'heart-outline',
                'text',
                'comment-white-oval-bubble',
                'edit-tools',
                'link',
                'link-1',
                'report',
                'chart',
                'bullhorn',
                'return',
                'credit-card',
                'chain',
                'rocket-2',
                'gear',
                'coding',
                'search',
                'plus',
                'accept-circular-button-outline',
                'information',
                'close-cross-in-circular-outlined-interface-button',
                'close-1',
                'tree',
                'watering-can',
                'lawn-mower',
                'watering-can-1',
                'star-of-favorites-outline',
                'attach',
                'asterisk',
                'less',
                'crayon',
                'add',
                'home',
                'tag',
                'universal-interface',
                'three-dots',
                'time',
                'speech-bubble',
                'float',
                'tools-and-utensils',
                'folded-corner',
                'unlock',
            ];
        }

        public static function enqueue_css($style) {
            if (! (bool) Plugin::$instance->editor->is_edit_mode()) {
                if (! empty($style)) {
                    ob_start();             
                        echo $style;
                    $css = ob_get_clean();
                    $css = apply_filters( 'reuss_enqueue_shortcode_css', $css, $style );   

                    return $css;
                }
            } else {
                echo '<style>'.esc_attr($style).'</style>';
            }
        }

        public function get_elementor_templates() {
            
            $options = [];

            $_templates = get_posts( array(
                'post_type' => 'elementor_library',
                'posts_per_page' => -1,
            ));
            
            if ( ! empty( $_templates ) && ! is_wp_error( $_templates ) ) {
                
                foreach ( $_templates as $_template ) {
                    $options[ $_template->ID ] = $_template->post_title;
                }
                
                update_option( 'temp_count', $options );
                
                return $options;
            }
        }
        
        public static function image_ratio($aspect_ratio, $size, $custom_size, $image_full_size)
        {

            $custom_width = $custom_size['width'] ?? '';
            $custom_height = $custom_size['height'] ?? '';
            $aspect_ratio_arr = explode(':', $aspect_ratio);
            $size_arr = explode('x', $size);
            $size_arr[1] = !empty($size_arr[1]) ? $size_arr[1] : $size_arr[0];

            switch ($size) {
                case 'full':
                    if (!empty($aspect_ratio)) {
                        $ratio = $aspect_ratio_arr[0] / $aspect_ratio_arr[1];
                        $new_width = $image_full_size[1];
                        $new_height = round((int) $image_full_size[1] / $ratio);
                    } else {
                        $new_width = $image_full_size[1];
                        $new_height = $image_full_size[2];
                    }
                    break;
                case '':
                    $new_width = $image_full_size[1];
                    $new_height = $image_full_size[2];
                    break;
                default:
                    if (empty((int) $custom_width) && $size == 'custom') {
                        echo '<h6>' . esc_html__('Please enter custom image width!', 'reuss-core') . '</h6>';
                        return null;
                    } else if ((int) $custom_width >= 5000 || (int) $custom_height >= 5000) {
                        echo '<h6>' . esc_html__('Please enter smaller image size!', 'reuss-core') . '</h6>';
                        return null;
                    }
                    if (!empty($aspect_ratio)) {
                        $ratio = $aspect_ratio_arr[0] / $aspect_ratio_arr[1];
                        $size = $size == 'custom' ? (int) $custom_width : $size;
                        $new_width = $size;
                        $new_height = round((int) $size / $ratio);
                    } else {
                        if ($size == 'custom') {
                            $new_width = (int) $custom_width;
                            $new_height = (int) $custom_height;
                        } else {
                            $new_width = (int) $size_arr[0];
                            $new_height = (int) $size_arr[1];
                        }
                    }
                    break;
            }

            $out = [
                'width' => $new_width,
                'height' => $new_height
            ];

            return $out;
        }
    }
    new Wgl_Elementor_Helper;
}
?>