<?php

namespace WglAddons\Templates;

defined('ABSPATH') || exit; // Abort, if called directly.

use Elementor\Plugin;
use Elementor\Frontend;
use WglAddons\Includes\Wgl_Icons;
use Elementor\Icons_Manager;

/**
 * WGL Elementor Info Boxes Template
 *
 *
 * @class        WglInfoBoxes
 * @version      1.0
 * @category     Class
 * @author       WebGeniusLab
 */

class WglInfoBoxes
{

    private static $instance = null;
    public static function get_instance()
    {
        if (null == self::$instance) {
            self::$instance = new self();
        }

        return self::$instance;
    }

    public function render($self, $atts)
    {
        extract($atts);

        $primary_color = esc_attr(\Reuss_Theme_Helper::get_option('theme-primary-color'));
        $h_font_color = esc_attr(\Reuss_Theme_Helper::get_option('header-font')['color']);

        $ib_media = $infobox_content = $ib_button = $module_link_html = '';

        // Wrapper classes
        $wrapper_classes = $layout ? ' wgl-layout-' . $layout : '';

        // Allowed HTML tags
        $allowed_html = [
            'a' => [
                'href' => true, 'title' => true,
                'class' => true, 'style' => true,
                'rel' => true, 'target' => true
            ],
            'br' => [ 'class' => true, 'style' => true ],
            'em' => [ 'class' => true, 'style' => true ],
            'strong' => [ 'class' => true, 'style' => true ],
            'span' => [ 'class' => true, 'style' => true ],
            'p' => [ 'class' => true, 'style' => true ],
        ];

        // Title
        $infobox_title = '<div class="wgl-infobox-title_wrapper">';
        $infobox_title .= !empty($ib_subtitle) ? '<div class="wgl-infobox_subtitle">' . wp_kses($ib_subtitle, $allowed_html) . '</div>' : '';
        $infobox_title .= !empty($ib_title) ? '<' . esc_attr($title_tag) . ' class="wgl-infobox_title">' . wp_kses($ib_title, $allowed_html) . '</' . esc_attr($title_tag) . '>' : '';
        $infobox_title .= '</div>';

        // Content
        if (!empty($ib_content)) {
            $infobox_content = '<' . esc_attr($content_tag) . ' class="wgl-infobox_content">';
            $infobox_content .= wp_kses($ib_content, $allowed_html);
            $infobox_content .= '</' . esc_attr($content_tag) . '>';
        }

        // Media
        if (!empty($icon_type)) {
            $media = new Wgl_Icons;
            $ib_media .= $media->build($self, $atts, []);
        }

        // Link
        if (!empty($link['url'])) {
            $self->add_link_attributes('link', $link);
        }

        // Read more button
        if ($add_read_more) {
            if ($read_more_type == 'standard'){
                $self->add_render_attribute('btn', 'class', 'wgl-infobox_button button-read-more');

                $ib_button = '<div class="wgl-infobox-button_wrapper">';
                $ib_button .= sprintf('<%s %s %s>',
                    $module_link ? 'div' : 'a',
                    $module_link ? '' : $self->get_render_attribute_string('link'),
                    $self->get_render_attribute_string('btn')
                );
                $ib_button .= $read_more_text ? '<span>' . esc_html($read_more_text) . '</span>' : '';
                $ib_button .= $module_link ? '</div>' : '</a>';
                $ib_button .= '</div>';
            } else{
                // Button
                $button_options = [
                    'icon_type' => '',
                    'text' => $read_more_text,
                    'link' => $link,
                    'size' => 'xl',
                    'button_gradient' => $button_gradient,
                ];
                $ib_button = new WGL_Button();
                ob_start();
                    echo $ib_button->render($self, $button_options);
                $ib_button = ob_get_clean();
            }
        }

        if ($module_link && !empty($link['url'])) {
            $module_link_html = '<a class="wgl-infobox__link" ' . $self->get_render_attribute_string('link') . '></a>';
        }


        // Render
        echo $module_link_html,
            '<div class="wgl-infobox">',
                '<div class="wgl-infobox_wrapper', esc_attr($wrapper_classes), '">',
                    $ib_media,
                    '<div class="content_wrapper">',
                        $infobox_title,
                        $infobox_content,
                        $read_more_inline ? '' : $ib_button,
                    '</div>',
                    $read_more_inline ? $ib_button : '',
                '</div>',
            '</div>';
    }
}
