<?php

namespace WglAddons\Widgets;

defined('ABSPATH') || exit; // Abort, if called directly.

use WglAddons\Includes\Wgl_Icons;
use WglAddons\Templates\WglCountDown;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;


class Wgl_CountDown extends Widget_Base
{

    public function get_name()
    {
        return 'wgl-countdown';
    }

    public function get_title()
    {
        return esc_html__('WGL Countdown Timer', 'reuss-core');
    }

    public function get_icon()
    {
        return 'wgl-countdown';
    }

    public function get_categories()
    {
        return ['wgl-extensions'];
    }

    public function get_script_depends()
    {
        return [
            'jquery-coundown',
            'wgl-elementor-extensions-widgets',
        ];
    }


    protected function _register_controls()
    {
        $primary_color = esc_attr(\Reuss_Theme_Helper::get_option('theme-primary-color'));
        $h_font_color = esc_attr(\Reuss_Theme_Helper::get_option('header-font')['color']);


        /*-----------------------------------------------------------------------------------*/
        /*  CONTENT -> GENERAL
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'section_content_general',
            ['label' => esc_html__('General', 'reuss-core')]
        );

        $this->add_control(
            'h_tip',
            [
                'label' => esc_html__('Choose the specific date:', 'littledino-core'),
                'type' => Controls_Manager::HEADING,
            ]
        );

        $this->add_control(
            'countdown_year',
            [
                'label' => esc_html__('Year', 'reuss-core'),
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__('Example: 2020', 'reuss-core'),
                'default' => esc_html__('2020', 'reuss-core'),
            ]
        );

        $this->add_control(
            'countdown_month',
            [
                'label' => esc_html__('Month', 'reuss-core'),
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__('Example: 12', 'reuss-core'),
                'default' => esc_html__('12', 'reuss-core'),
            ]
        );

        $this->add_control(
            'countdown_day',
            [
                'label' => esc_html__('Day', 'reuss-core'),
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__('Example: 31', 'reuss-core'),
                'default' => esc_html__('31', 'reuss-core'),
            ]
        );

        $this->add_control(
            'countdown_hours',
            [
                'label' => esc_html__('Hours', 'reuss-core'),
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__('Example: 24', 'reuss-core'),
                'default' => esc_html__('24', 'reuss-core'),
            ]
        );

        $this->add_control(
            'countdown_min',
            [
                'label' => esc_html__('Minutes', 'reuss-core'),
                'type' => Controls_Manager::TEXT,
                'placeholder' => esc_html__('Example: 59', 'reuss-core'),
                'default' => esc_html__('59', 'reuss-core'),
            ]
        );

        $this->add_responsive_control(
            'alignment',
            [
                'label' => esc_html__('Alignment', 'reuss-core'),
                'type' => Controls_Manager::CHOOSE,
                'separator' => 'before',
                'options' => [
                    'left' => [
                        'title' => esc_html__('Left', 'reuss-core'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'reuss-core'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__('Right', 'reuss-core'),
                        'icon' => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__('Full Width', 'reuss-core'),
                        'icon' => 'fa fa-align-justify',
                    ],
                ],
                'default' => 'justify',
                'prefix_class' => 'a%s',
            ]
        );

        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  CONTENT -> CONTENT
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'section_content_content',
            [ 'label' => esc_html__('Content', 'reuss-core') ]
        );

        $this->add_control(
            'show_value_names',
            [
                'label' => esc_html__('Show Title?', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_separating',
            [
                'label' => esc_html__('Show Separating Dots?', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'hide_day',
            [
                'label' => esc_html__('Hide Days?', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'hide_hours',
            [
                'label' => esc_html__('Hide Hours?', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'hide_minutes',
            [
                'label' => esc_html__('Hide Minutes?', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'hide_seconds',
            [
                'label' => esc_html__('Hide Seconds?', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
            ]
        );

        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  STYLE -> NUMBERS
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'countdown_style_numbers',
            [
                'label' => esc_html__('Numbers', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label' => esc_html__('Typography', 'reuss-core'),
                'name' => 'custom_fonts_number',
                'selector' => '{{WRAPPER}} .countdown-amount',
            ]
        );

        $this->add_control(
            'number_color_idle',
            [
                'label' => esc_html__('Text Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => $h_font_color,
                'selectors' => [
                    '{{WRAPPER}} .countdown-amount' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'number_bg_idle',
            [
                'label' => esc_html__('Background Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .countdown-amount span' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'number_padding',
            [
                'label' => esc_html__('Padding', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'separator' => 'before',
                'size_units' => [ 'px', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .countdown-amount span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'number_margin',
            [
                'label' => esc_html__('Margin', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .countdown-amount span' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  STYLE -> TITLES
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'section_style_titles',
            [
                'label' => esc_html__('Titles', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'label' => esc_html__('Typography', 'reuss-core'),
                'name' => 'custom_fonts_text',
                'fields_options' => [
                    'typography' => ['default' => 'yes'],
                    'font_family' => ['default' => \Wgl_Addons_Elementor::$typography_1['font_family']],
                    'font_weight' => ['default' => \Wgl_Addons_Elementor::$typography_1['font_weight']],
                ],
                'selector' => '{{WRAPPER}} .countdown-period',
            ]
        );

        $this->add_control(
            'titles_color_idle',
            [
                'label' => esc_html__('Text Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '#1f242c',
                'selectors' => [
                    '{{WRAPPER}} .countdown-period' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        /*-----------------------------------------------------------------------------------*/
        /*  STYLE -> DOTS
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'section_style_dots',
            [
                'label' => esc_html__('Dots', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => ['show_separating!' => ''],
            ]
        );

        $this->add_control(
            'dots_color_idle',
            [
                'label' => esc_html__('Dots Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => $primary_color,
                'selectors' => [
                    '{{WRAPPER}} .has-dots .countdown-section .countdown-amount:before, {{WRAPPER}} .has-dots .countdown-section .countdown-amount:after' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'dots_margin',
            [
                'label' => esc_html__('Margin', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'separator' => 'before',
                'allowed_dimensions' => 'horizontal',
                'size_units' => [ 'px', 'em' ],
                'default' => [
                    'right' => 0.32,
                    'left' => 0.32,
                    'unit' => 'em',
                ],
                'selectors' => [
                    '{{WRAPPER}} .countdown-section:not(:first-child)' => 'margin-left: {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .countdown-section:not(:last-child)' => 'margin-right: {{RIGHT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'dots_shape',
            [
                'label' => esc_html__('Shape (circle or square)', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Circle', 'reuss-core'),
                'label_off' => esc_html__('Square', 'reuss-core'),
                'default' => 'yes',
                'selectors' => [
                    '{{WRAPPER}} .countdown-section .countdown-amount:before, {{WRAPPER}} .countdown-section .countdown-amount:after' => 'border-radius: 50%;',
                ],
            ]
        );

        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  STYLE -> SECTIONS
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'section_style_setions',
            [
                'label' => esc_html__('Sections', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => ['show_separating' => ''],
            ]
        );

        $this->add_responsive_control(
            'section_margin',
            [
                'label' => esc_html__('Margin', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'separator' => 'before',
                'allowed_dimensions' => 'horizontal',
                'size_units' => [ 'px', 'em' ],
                'default' => [
                    'right' => 0.32,
                    'left' => 0.32,
                    'unit' => 'em',
                ],
                'selectors' => [
                    '{{WRAPPER}} .countdown-section:not(:first-child)' => 'margin-left: {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .countdown-section:not(:last-child)' => 'margin-right: {{RIGHT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render()
    {
        $atts = $this->get_settings_for_display();

        $countdown = new WglCountDown();
        echo $countdown->render($this, $atts);
    }
}
