<?php
namespace WglAddons\Widgets;

defined( 'ABSPATH' ) || exit; // Abort, if called directly.

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Utils;
use WglAddons\Includes\Wgl_Elementor_Helper;

class Wgl_Double_Headings extends Widget_Base
{

    public function get_name() {
        return 'wgl-double-headings';
    }

    public function get_title() {
        return esc_html__('WGL Double Headings', 'reuss-core');
    }

    public function get_icon() {
        return 'wgl-double-headings';
    }

    public function get_categories() {
        return [ 'wgl-extensions' ];
    }


    protected function _register_controls() {
        $primary_color = esc_attr(\Reuss_Theme_Helper::get_option('theme-primary-color'));
        $secondary_color = esc_attr(\Reuss_Theme_Helper::get_option('theme-secondary-color'));
        $h_font_color = esc_attr(\Reuss_Theme_Helper::get_option('header-font')['color']);


        /*-----------------------------------------------------------------------------------*/
        /*  CONTENT -> GENERAL
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'wgl_double_headings_section',
            [ 'label' => esc_html__('General', 'reuss-core') ]
        );

        $this->add_control(
            'subtitle',
            [
                'label' => esc_html__('Subtitle', 'reuss-core'),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'placeholder' => esc_html__('subtitle', 'reuss-core'),
                'default' => esc_html__('subtitle', 'reuss-core'),
            ]
        );

        $this->add_control(
            'dbl_title',
            [
                'label' => esc_html__('Title', 'reuss-core'),
                'type' => Controls_Manager::TEXTAREA,
                'rows' => 1,
                'default' => esc_html__('Heading​', 'reuss-core'),
                'placeholder' => esc_html__('Heading​', 'reuss-core'),
            ]
        );

        $this->add_control(
            'alignment',
            [
                'label' => esc_html__('Alignment', 'reuss-core'),
                'type' => Controls_Manager::CHOOSE,
                'separator' => 'before',
                'options' => [
                    'left' => [
                        'title' => esc_html__('Left', 'reuss-core'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'reuss-core'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__('Right', 'reuss-core'),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'default' => 'left',
                'prefix_class' => 'a',
            ]
        );

        $this->add_control(
            'link',
            [
                'label' => esc_html__('Title Link', 'reuss-core'),
                'type' => Controls_Manager::URL,
                'placeholder' => esc_html__('https://your-link.com', 'reuss-core'),
            ]
        );

        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  STYLES -> TITLE
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'section_style_title',
            [
                'label' => esc_html__('Title', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [ 'dbl_title!'  => '' ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typo',
                'selector' => '{{WRAPPER}} .dbl__title',
            ]
        );

        $this->add_control(
            'title_tag',
            [
                'label' => esc_html__('HTML Tag', 'reuss-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'h1' => '‹h1›',
                    'h2' => '‹h2›',
                    'h3' => '‹h3›',
                    'h4' => '‹h4›',
                    'h5' => '‹h5›',
                    'h6' => '‹h6›',
                    'span' => '‹span›',
                    'div' => '‹div›',
                ],
                'default' => 'h3',
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__('Text Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => $h_font_color,
                'selectors' => [
                    '{{WRAPPER}} .dbl__title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  STYLES -> SUBTITLE
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'section_style_subtitle',
            [
                'label' => esc_html__('Subtitle', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [ 'subtitle!'  => '' ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subtitle_typo',
                'selector' => '{{WRAPPER}} .dbl__subtitle',
            ]
        );

        $this->add_control(
            'subtitle_color',
            [
                'label' => esc_html__('Text Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => $primary_color,
                'selectors' => [
                    '{{WRAPPER}} .dbl__subtitle' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'subtitle_layout',
            [
                'label' => esc_html__('Layout', 'reuss-core'),
                'type' => Controls_Manager::SELECT,
                'separator' => 'before',
                'options' => [
                    '' => esc_html__('Default', 'reuss-core'),
                    'subtitle-suspended' => esc_html__('Suspended', 'reuss-core'),
                ],
                'default' => '',
                'prefix_class' => '',
            ]
        );

        $this->add_control(
            'subtitle_responsive',
            [
                'label' => esc_html__('Fallback to Default on Mobile', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'condition' => [ 'subtitle_layout!' => '' ],
            ]
        );

        $this->add_control(
            'subtitle_breakpoint',
            [
                'label' => esc_html__('Breakpoint to Default fallback?', 'reuss-core'),
                'type' => Controls_Manager::NUMBER,
                'condition' => [
                    'subtitle_layout!' => '',
                    'subtitle_responsive!' => '',
                ],
                'min' => 530,
                'max' => 994,
                'default' => 768,
            ]
        );

        $this->add_control(
            'subtitle_bar',
            [
                'label' => esc_html__('Enable Decorative Bar?', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'separator' => 'before',
                'default' => 'yes',
                'selectors' => [
                    '{{WRAPPER}} .dbl__subtitle:before' => 'content: \'\';',
                ],
            ]
        );

        $this->add_responsive_control(
            'subtitle_margin',
            [
                'label' => esc_html__('Margin', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .dbl__subtitle' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render()
    {
        $_s = $this->get_settings_for_display();

        if ($_s['link']['url']) {
            $this->add_render_attribute('link', 'class', 'dbl__link');
            $this->add_link_attributes('link', $_s['link']);
        }

        if ($_s['subtitle_breakpoint']) {
            $styles = '@media (max-width: '.$_s[ 'subtitle_breakpoint' ].'px) { '
                . '.elementor-element.elementor-element-' . $this->get_id() . '.subtitle-suspended .dbl__subtitle {'
                    . 'position: relative;'
                    . 'right: 0;'
                    . 'transform: rotate(0);'
                . ' }'
            . ' }';
            Wgl_Elementor_Helper::enqueue_css($styles);
        }

        $this->add_render_attribute('heading_wrapper', 'class', 'wgl-double_heading');

        echo '<div ', $this->get_render_attribute_string('heading_wrapper'), '>';

            if ($_s[ 'subtitle' ]) {
                echo '<div class="dbl__subtitle">',
                    $_s[ 'subtitle' ],
                '</div>';
            }
            if ($_s['link']['url']) echo '<a ', $this->get_render_attribute_string('link'), '>';

            if ($_s[ 'dbl_title' ]) {
                echo '<', $_s[ 'title_tag' ], ' class="dbl__title-wrapper">',
                    '<span class="dbl__title">', $_s[ 'dbl_title' ], '</span>',
                '</', $_s[ 'title_tag' ], '>';
            }

            if ($_s['link']['url']) echo '</a>';

        echo '</div>';

    }

}