<?php
namespace WglAddons\Widgets;

defined('ABSPATH') || exit; // Abort, if called directly.

use WglAddons\Includes\Wgl_Icons;
use WglAddons\Includes\Wgl_Loop_Settings;
use WglAddons\Includes\Wgl_Carousel_Settings;
use WglAddons\Templates\WglProgressBar;
use Elementor\Widget_Base;
use Elementor\Utils;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;

class Wgl_Line_Circle_Chart extends Widget_Base {
    
    public function get_name() {
        return 'wgl-line-circle-chart';
    }

    public function get_title() {
        return esc_html__('WGL Line Circle Chart', 'reuss-core' );
    }

    public function get_icon() {
        return 'wgl-line-circle-chart';
    }

    public function get_categories() {
        return [ 'wgl-extensions' ];
    }

    public function get_script_depends() {
        return [
            'jquery-easypiechart',
            'jquery-appear',
        ];
    }

    // Adding the controls fields for the premium title
    // This will controls the animation, colors and background, dimensions etc
    protected function _register_controls() {
        $theme_color = esc_attr(\Reuss_Theme_Helper::get_option('theme-primary-color'));
        $second_color = esc_attr(\Reuss_Theme_Helper::get_option('theme-secondary-color'));
        $header_font_color = esc_attr(\Reuss_Theme_Helper::get_option('header-font')['color']);
        $main_font_color = esc_attr(\Reuss_Theme_Helper::get_option('main-font')['color']);

        /* Start General Settings Section */
        $this->start_controls_section('wgl_line_circle_chart_section',
            array(
                'label'         => esc_html__('Pie Chart Settings', 'reuss-core'),
            )
        );

        $this->add_control(
            'value',
            [
                'label' => esc_html__( 'Value', 'reuss-core' ),
                'type' => Controls_Manager::SLIDER,
                'default' => [
                    'size' => 98,
                    'unit' => '%',
                ],
                'range' => [
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],

                'label_block' => true,
            ]
        );  

        $this->add_control(
            'chart_align',
            array(
                'label' => esc_html__( 'Alignment', 'reuss-core' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'reuss-core' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'reuss-core' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'reuss-core' ),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'label_block' => false,
                'default' => 'center',
                'toggle' => true,
                'selectors' => [
                    '{{WRAPPER}} .wgl-line-circle_chart' => 'text-align: {{VALUE}};',
                ],
            )
        ); 


        /*End General Settings Section*/
        $this->end_controls_section();      

        /*-----------------------------------------------------------------------------------*/
        /*  Style Section
        /*-----------------------------------------------------------------------------------*/

        /*-----------------------------------------------------------------------------------*/
        /*  Style Section(Value Section)
        /*-----------------------------------------------------------------------------------*/    
        $this->start_controls_section(
            'value_style_section',
            array(
                'label'     => esc_html__( 'Value', 'reuss-core' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            )
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            array(
                'name' => 'line_circle_chart_value_typo',
                'selector' => '{{WRAPPER}} .wgl-line-circle_chart .percent',
            )
        );

        $this->add_control(
            'custom_value_color',
            array(
                'label' => esc_html__( 'Color', 'reuss-core' ),
                'type' => Controls_Manager::COLOR,
                'default' => $header_font_color,
                'selectors' => array(
                    '{{WRAPPER}} .wgl-line-circle_chart .percent' => 'color: {{VALUE}};',
                ),
            )
        );    

        $this->add_control(
            'custom_value_color_bg',
            array(
                'label' => esc_html__( 'Background Color', 'reuss-core' ),
                'type' => Controls_Manager::COLOR,
                'default' => '#f7f9ff',
                'selectors' => array(
                    '{{WRAPPER}} .wgl-line-circle_chart .percent' => 'background-color: {{VALUE}};',
                ),
            )
        );   

        $this->end_controls_section(); 

        /*-----------------------------------------------------------------------------------*/
        /*  Style Section(Progress Bar Section)
        /*-----------------------------------------------------------------------------------*/    
        $this->start_controls_section(
            'bar_style_section',
            array(
                'label'     => esc_html__( 'Line Circle Chart', 'reuss-core' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            )
        );

        $this->add_control(
            'size_chart',
            [
                'label' => esc_html__( 'Size Chart', 'reuss-core' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 500,
                    ],
                ],
                'default' => [
                    'size' => 140,
                    'unit' => 'px',
                ],
                'label_block' => true,
            ]
        );  	

        $this->add_control(
            'bar_color',
            array(
                'label' => esc_html__( 'Bar Color', 'reuss-core' ),
                'type' => Controls_Manager::COLOR,
                'default' => $theme_color,
            )
        );

        $this->add_control(
            'track_color',
            array(
                'label' => esc_html__( 'Track Color', 'reuss-core' ),
                'type' => Controls_Manager::COLOR,
            )
        );   

        $this->add_control(
            'line_width',
            [
                'label' => esc_html__( 'Line Width', 'reuss-core' ),
                'type' => Controls_Manager::NUMBER,
                'min' => 0,
                'step' => 1,
                'default' => 15,
                'selectors' => array(
                    '{{WRAPPER}} .wgl-line-circle_chart .percent' => 'top: {{VALUE}}px; right: {{VALUE}}px; bottom: {{VALUE}}px; left: {{VALUE}}px;',
                ),
            ]
        ); 

        $this->end_controls_section();  

    }

    public function render(){

        $settings = $this->get_settings_for_display();
        extract($settings);

        wp_enqueue_script('jquery-easypiechart', get_template_directory_uri() . '/js/jquery.easypiechart.min.js', array(), false, false);

        $this->add_render_attribute( 'line_circle_chart_wrapper', [
			'class' => [
                'wgl-line-circle_chart', 
            ],
        ] );

        $this->add_render_attribute( 'chart', [
            'class' => 'chart',
            'data-percent' => (int) esc_attr($value['size']),
            'data-track-color' => esc_attr($track_color),
            'data-bar-color' => esc_attr($bar_color),
            'data-line-width' => (int) esc_attr($line_width),
			'data-size' => (int) esc_attr($size_chart['size']),
        ] );

        ?>
        <div <?php echo $this->get_render_attribute_string( 'line_circle_chart_wrapper' ); ?>>
            <div class="line-circle-chart_wrap">
                <div <?php echo $this->get_render_attribute_string( 'chart' ); ?>>
                    <span class="percent">
                        0                     
                    </span>
                </div>
            </div>
        </div>
        <?php
        
    }
    
}