<?php

namespace WglAddons\Widgets;

defined('ABSPATH') || exit; // Abort, if called directly.

use WglAddons\Includes\Wgl_Loop_Settings;
use WglAddons\Includes\Wgl_Carousel_Settings;
use WglAddons\Templates\WglPortfolio;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Icons_Manager;


class Wgl_Portfolio extends Widget_Base
{
    public function get_name() {
        return 'wgl-portfolio';
    }

    public function get_title() {
        return esc_html__('WGL Portfolio', 'reuss-core');
    }

    public function get_icon() {
        return 'wgl-portfolio';
    }

    public function get_categories() {
        return [ 'wgl-extensions' ];
    }

    public function get_script_depends()
    {
        return [
            'jquery-slick',
            'imagesloaded',
            'isotope',
            'wgl-elementor-extensions-widgets',
        ];
    }


    protected function _register_controls()
    {
        $primary_color = esc_attr(\Reuss_Theme_Helper::get_option('theme-primary-color'));
        $secondary_color = esc_attr(\Reuss_Theme_Helper::get_option('theme-secondary-color'));
        $h_font_color = esc_attr(\Reuss_Theme_Helper::get_option('header-font')['color']);
        $main_font_color = esc_attr(\Reuss_Theme_Helper::get_option('main-font')['color']);

        $hsl_color = \Reuss_Theme_Helper::hexToHsl($primary_color);
        $primary_color_shaded = esc_attr(\Reuss_Theme_Helper::shaded($hsl_color, 5));


        /*-----------------------------------------------------------------------------------*/
        /*  CONTENT -> GENERAL
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'wgl_portfolio_section',
            [ 'label' => esc_html__('General', 'reuss-core') ]
        );

        $this->add_control(
            'portfolio_layout',
            [
                'label' => esc_html__('Layout', 'reuss-core'),
                'type' => 'wgl-radio-image',
                'options' => [
                    'grid' => [
                        'title' => esc_html__('Grid', 'reuss-core'),
                        'image' => WGL_ELEMENTOR_ADDONS_URL . 'assets/img/wgl_elementor_addon/icons/layout_grid.png',
                    ],
                    'carousel' => [
                        'title' => esc_html__('Carousel', 'reuss-core'),
                        'image' => WGL_ELEMENTOR_ADDONS_URL . 'assets/img/wgl_elementor_addon/icons/layout_carousel.png',
                    ],
                    'masonry' => [
                        'title' => esc_html__('Masonry', 'reuss-core'),
                        'image' => WGL_ELEMENTOR_ADDONS_URL . 'assets/img/wgl_elementor_addon/icons/layout_masonry.png',
                    ],
                    'masonry2' => [
                        'title' => esc_html__('Masonry 2', 'reuss-core'),
                        'image' => WGL_ELEMENTOR_ADDONS_URL . 'assets/img/wgl_elementor_addon/icons/layout_masonry_2.png',
                    ],
                    'masonry3' => [
                        'title' => esc_html__('Masonry 3', 'reuss-core'),
                        'image' => WGL_ELEMENTOR_ADDONS_URL . 'assets/img/wgl_elementor_addon/icons/layout_masonry_3.png',
                    ],
                    'masonry4' => [
                        'title' => esc_html__('Masonry 4', 'reuss-core'),
                        'image' => WGL_ELEMENTOR_ADDONS_URL . 'assets/img/wgl_elementor_addon/icons/layout_masonry_4.png',
                    ],
                ],
                'default' => 'grid',
            ]
        );

        $this->add_control(
            'posts_per_row',
            [
                'label' => esc_html__('Columns Amount', 'reuss-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1' => esc_html__('1', 'reuss-core'),
                    '2' => esc_html__('2', 'reuss-core'),
                    '3' => esc_html__('3', 'reuss-core'),
                    '4' => esc_html__('4', 'reuss-core'),
                    '5' => esc_html__('5', 'reuss-core'),
                ],
                'default' => '3',
                'condition' => [
                    'portfolio_layout' => [ 'grid', 'masonry', 'carousel' ]
                ],
            ]
        );

        $this->add_control(
            'grid_gap',
            [
                'label' => esc_html__('Grid Gap', 'reuss-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '0px' => esc_html__('0', 'reuss-core'),
                    '1px' => esc_html__('1', 'reuss-core'),
                    '2px' => esc_html__('2', 'reuss-core'),
                    '3px' => esc_html__('3', 'reuss-core'),
                    '4px' => esc_html__('4', 'reuss-core'),
                    '5px' => esc_html__('5', 'reuss-core'),
                    '10px' => esc_html__('10', 'reuss-core'),
                    '15px' => esc_html__('15', 'reuss-core'),
                    '20px' => esc_html__('20', 'reuss-core'),
                    '25px' => esc_html__('25', 'reuss-core'),
                    '30px' => esc_html__('30', 'reuss-core'),
                    '35px' => esc_html__('35', 'reuss-core'),
                    '40px' => esc_html__('40', 'reuss-core'),
                    '50px' => esc_html__('50', 'reuss-core'),
                    '60px' => esc_html__('60', 'reuss-core'),
                ],
                'default' => '30px',
            ]
        );

        $this->add_control(
            'show_filter',
            [
                'label' => esc_html__('Show Filter', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'condition' => [ 'portfolio_layout!' => 'carousel' ],
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'add_max_width_filter',
            [
                'label' => esc_html__('Limit the Filter Container Width', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'condition' => [ 'show_filter' => 'yes' ],
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'max_width_filter',
            [
                'label' => esc_html__('Filter Container Max Width (px)', 'reuss-core'),
                'type' => Controls_Manager::NUMBER,
                'condition' => [
                    'show_filter' => 'yes',
                    'add_max_width_filter' => 'yes',
                ],
                'default' => '1170',
                'selectors' => [
                    '{{WRAPPER}} .portfolio__filter' => 'max-width: {{VALUE}}px; margin-left: auto; margin-right: auto;',
                ],
            ]
        );

        $this->add_control(
            'filter_align',
            [
                'label' => esc_html__('Filter Align', 'reuss-core'),
                'type' => Controls_Manager::SELECT,
                'condition' => [
                    'portfolio_layout!' => 'carousel',
                    'show_filter' => 'yes',
                ],
                'options' => [
                    'left' => esc_html__('Left', 'reuss-core'),
                    'center' => esc_html__('Сenter', 'reuss-core'),
                    'right' => esc_html__('Right', 'reuss-core'),
                ],
                'default' => 'center',
            ]
        );


        $this->add_control(
            'size',
            [
                'type' => Controls_Manager::SELECT,
                'label' => esc_html__('Image Size', 'reuss-core'),
                'options' => [
                    '150' => 'Thumbnail - 150x150',
                    '300' => 'Medium - 300x300',
                    '768' => 'Medium Large - 768x768',
                    '1024' => 'Large - 1024x1024',
                    '740x740' => '740x740', // 3col
                    '770x460' => '770x460', // slider variable width
                    '886x650' => '886x650', // 4col-wide
                    '1140x840' => '1140x840', // 2col
                    'full' => 'Full',
                    'custom' => 'Custom',
                ],
                'default' => '740x740', // 3col
                'condition' => [
                    'portfolio_layout' => ['grid', 'carousel']
                ],
                'separator' => 'before'
            ]
        );

        $this->add_control(
            'custom_size',
            [
                'label' => esc_html__('Image Dimension', 'reuss-core'),
                'type' => Controls_Manager::IMAGE_DIMENSIONS,
                'description' => esc_html__('You can crop the original image size to any custom size. You can also set a single value for height or width in order to keep the original size ratio.', 'reuss-core'),
                'condition' => [
                    'size' => 'custom',
                    'portfolio_layout' => ['grid', 'carousel']
                ],
                'default' => [
                    'width' => '740',
                    'height' => '940',
                ]
            ]
        );

        $this->add_control(
            'aspect_ratio',
            [
                'type' => Controls_Manager::SELECT,
                'label' => esc_html__('Image Aspect Ratio', 'reuss-core'),
                'options' => [
                    '1:1' => '1:1',
                    '3:2' => '3:2',
                    '4:3' => '4:3',
                    '9:16' => '9:16',
                    '16:9' => '16:9',
                    '21:9' => '21:9',
                    '' => 'Not Crop',
                ],
                'default' => '',
                'condition' => [
                    'portfolio_layout' => ['grid', 'carousel']
                ],
            ]
        );

        $this->add_control(
            'navigation',
            [
                'label' => esc_html__('Navigation Type', 'reuss-core'),
                'type' => Controls_Manager::SELECT,
                'condition' => [ 'portfolio_layout!' => 'carousel' ],
                'options' => [
                    'none' => esc_html__('None', 'reuss-core'),
                    'pagination' => esc_html__('Pagination', 'reuss-core'),
                    'infinite' => esc_html__('Infinite Scroll', 'reuss-core'),
                    'load_more' => esc_html__('Load More', 'reuss-core'),
                    'custom_link' => esc_html__('Custom Link', 'reuss-core'),
                ],
                'default' => 'none',
            ]
        );

        $this->add_control(
            'item_link',
            [
                'label' => esc_html__('Link', 'reuss-core'),
                'type' => Controls_Manager::URL,
                'condition' => [ 'navigation' => 'custom_link' ],
                'placeholder' => esc_html__('https://your-link.com', 'reuss-core'),
                'default' => [ 'url' => '#' ],
            ]
        );

        $this->add_control(
            'link_position',
            [
                'label' => esc_html__('Link Position', 'reuss-core'),
                'type' => Controls_Manager::SELECT,
                'condition' => [ 'navigation' => 'custom_link' ],
                'options' => [
                    'below_items' => esc_html__('Below Items', 'reuss-core'),
                    'after_items' => esc_html__('After Items', 'reuss-core'),
                ],
                'default' => 'below_items',
            ]
        );

        $this->add_control(
            'link_align',
            [
                'label' => esc_html__('Link Alignment', 'reuss-core'),
                'type' => Controls_Manager::SELECT,
                'condition' => [ 'navigation' => 'custom_link' ],
                'options' => [
                    'left' => esc_html__('Left', 'reuss-core'),
                    'center' => esc_html__('Сenter', 'reuss-core'),
                    'right' => esc_html__('Right', 'reuss-core'),
                ],
                'default' => 'left',
            ]
        );

        $this->add_responsive_control(
            'link_margin',
            [
                'label' => esc_html__('Spacing', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'condition' => [ 'navigation' => 'custom_link' ],
                'size_units' => [ 'px', 'em', '%' ],
                'default' => [
                    'top' => 0,
                    'left' => 0,
                    'right' => 0,
                    'bottom' => 60,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .wgl-portfolio_item_link' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'nav_align',
            [
                'label' => esc_html__('Alignment', 'reuss-core'),
                'type' => Controls_Manager::SELECT,
                'condition' => [ 'navigation' => 'pagination' ],
                'options' => [
                    'left' => esc_html__('Left', 'reuss-core'),
                    'center' => esc_html__('Сenter', 'reuss-core'),
                    'right' => esc_html__('Right', 'reuss-core'),
                ],
                'default' => 'center',
            ]
        );

        $this->add_control(
            'items_load',
            [
                'label' => esc_html__('Items to be loaded', 'reuss-core'),
                'type' => Controls_Manager::TEXT,
                'condition' => [
                    'navigation' => [ 'load_more', 'infinite' ],
                ],
                'default' => esc_html__('4', 'reuss-core'),
            ]
        );

        $this->add_control(
            'name_load_more',
            [
                'label' => esc_html__('Button Text', 'reuss-core'),
                'type' => Controls_Manager::TEXT,
                'condition' => [
                    'navigation' => [ 'load_more', 'custom_link' ],
                ],
                'default' => esc_html__('Load More', 'reuss-core'),
            ]
        );

        $this->add_control(
            'add_animation',
            [
                'label' => esc_html__('Add Appear Animation', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'appear_animation',
            [
                'label' => esc_html__('Animation Style', 'reuss-core'),
                'type' => Controls_Manager::SELECT,
                'condition' => [ 'add_animation' => 'yes' ],
                'options' => [
                    'fade-in' => esc_html__('Fade In', 'reuss-core'),
                    'slide-top' => esc_html__('Slide Top', 'reuss-core'),
                    'slide-bottom' => esc_html__('Slide Bottom', 'reuss-core'),
                    'slide-left' => esc_html__('Slide Left', 'reuss-core'),
                    'slide-right' => esc_html__('Slide Right', 'reuss-core'),
                    'zoom' => esc_html__('Zoom', 'reuss-core'),
                ],
                'default' => 'fade-in',
            ]
        );

        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  CONTENT -> APPEARANCE
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'display_section',
            [ 'label' => esc_html__('Appearance', 'reuss-core') ]
        );

        $this->add_control(
            'gallery_mode',
            [
                'label' => esc_html__('Gallery Mode', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'separator' => 'after',
                'label_on' => esc_html__('On', 'reuss-core'),
                'label_off' => esc_html__('Off', 'reuss-core'),
            ]
        );

        $this->add_control(
            'show_portfolio_title',
            [
                'label' => esc_html__('Show Heading?', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'condition' => [ 'gallery_mode' => '' ],
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_meta_categories',
            [
                'label' => esc_html__('Show Categories?', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'condition' => [ 'gallery_mode' => '' ],
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_content',
            [
                'label' => esc_html__('Show Excerpt/Content?', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'condition' => [ 'gallery_mode' => '' ],
                'label_on' => esc_html__('On', 'reuss-core'),
                'label_off' => esc_html__('Off', 'reuss-core'),
            ]
        );

        $this->add_control(
            'content_letter_count',
            [
                'label' => esc_html__('Content Letter Limit', 'reuss-core'),
                'type' => Controls_Manager::NUMBER,
                'condition' => [
                    'show_content' => 'yes',
                    'gallery_mode' => '',
                ],
                'min' => 1,
                'default' => '85',
            ]
        );

        $this->add_control(
            'info_position',
            [
                'label' => esc_html__('Meta Position', 'reuss-core'),
                'condition' => [ 'gallery_mode' => '' ],
                'type' => Controls_Manager::SELECT,
                'separator' => 'before',
                'options' => [
                    'inside_image' => esc_html__('within image', 'reuss-core'),
                    'under_image' => esc_html__('beneath image', 'reuss-core'),
                ],
                'default' => 'inside_image',
            ]
        );

        $this->add_control(
            'image_anim',
            [
                'label' => esc_html__('Meta Animation', 'reuss-core'),
                'type' => Controls_Manager::SELECT,
                'condition' => [
                    'info_position' => 'inside_image',
                    'gallery_mode' => '',
                    'portfolio_layout!' => 'carousel',
                ],
                'options' => [
                    'simple' => esc_html__('Simple', 'reuss-core'),
                    'sub_layer' => esc_html__('On Sub-Layer', 'reuss-core'),
                    'offset' => esc_html__('Side Offset', 'reuss-core'),
                    'zoom_in' => esc_html__('Zoom In', 'reuss-core'),
                    'outline' => esc_html__('Outline', 'reuss-core'),
                    'always_info' => esc_html__('Visible Until Hover', 'reuss-core'),
                ],
                'default' => 'sub_layer',
            ]
        );

        $this->add_control(
            'meta_alignment',
            [
                'label' => esc_html__('Meta Alignment', 'reuss-core'),
                'type' => Controls_Manager::CHOOSE,
                'condition' => [ 'gallery_mode' => '' ],
                'label_block' => true,
                'options' => [
                    'left' => [
                        'title' => esc_html__('Left', 'reuss-core'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'reuss-core'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__('Right', 'reuss-core'),
                        'icon' => 'fa fa-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__('Justified', 'reuss-core'),
                        'icon' => 'fa fa-align-justify',
                    ],
                ],
                'default' => 'center',
                'selectors' => [
					'{{WRAPPER}} .portfolio__description' => 'text-align: {{VALUE}};',
				],
            ]
        );

        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  CONTENT -> LINKS
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'section_content_links',
            [
                'label' => esc_html__('Links', 'reuss-core'),
                'condition' => [ 'gallery_mode' => '' ],
            ]
        );

        $this->add_control(
            'linked_image',
            [
                'label' => esc_html__('Add link on Image', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes'
            ]
        );

        $this->add_control(
            'linked_title',
            [
                'label' => esc_html__('Add link on Heading', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'condition' => [ 'show_portfolio_title!' => '' ],
                'default' => 'yes'
            ]
        );

        $this->add_control(
            'link_destination',
            [
                'label' => esc_html__('Link Action', 'reuss-core'),
                'type' => Controls_Manager::SELECT,
                'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name' => 'linked_title',
                            'operator' => '!==',
                            'value' => '',
                        ],
                        [
                            'name' => 'linked_image',
                            'operator' => '!==',
                            'value' => '',
                        ],
                    ],
                ],
                'options' => [
                    'single' => esc_html__('Open Single Page', 'reuss-core'),
                    'custom' => esc_html__('Open Custom Link', 'reuss-core'),
                    'popup' => esc_html__('Popup the Image', 'reuss-core'),
                ],
                'default' => 'single',
            ]
        );

        $this->add_control(
            'link_custom_notice',
            [
                'type' => Controls_Manager::RAW_HTML,
                'condition' => [ 'link_destination' => 'custom' ],
                'content_classes' => 'elementor-panel-alert elementor-panel-alert-warning',
                'raw' => esc_html__('Note: Custom link can be specified in corresponding metabox options section of each post.', 'reuss-core' ),
            ]
        );

        $this->add_control(
            'link_target',
            [
                'label' => esc_html__('Open link in a new tab', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'conditions' => [
                    'terms' => [
                        [
                            'relation' => 'or',
                            'terms' => [
                                [
                                    'name' => 'linked_title',
                                    'operator' => '!==',
                                    'value' => '',
                                ],
                                [
                                    'name' => 'linked_image',
                                    'operator' => '!==',
                                    'value' => '',
                                ],
                            ],
                        ],
                        [
                            'name' => 'link_destination',
                            'operator' => '!==',
                            'value' => 'popup',
                        ],
                    ],
                ],
            ]
        );

        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  CONTENT -> CAROUSEL OPTIONS
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'wgl_carousel_section',
            [
                'label' => esc_html__('Carousel Options', 'reuss-core'),
                'condition' => [ 'portfolio_layout' => 'carousel' ],
            ]
        );

        $this->add_control(
            'autoplay',
            [
                'label' => esc_html__('Autoplay', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('On', 'reuss-core'),
                'label_off' => esc_html__('Off', 'reuss-core'),
            ]
        );

        $this->add_control(
            'autoplay_speed',
            [
                'label' => esc_html__('Autoplay Speed', 'reuss-core'),
                'type' => Controls_Manager::NUMBER,
                'condition' => [ 'autoplay' => 'yes' ],
                'min' => 1,
                'default' => '3000',
            ]
        );

        $this->add_control(
            'c_infinite_loop',
            [
                'label' => esc_html__('Infinite Loop', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('On', 'reuss-core'),
                'label_off' => esc_html__('Off', 'reuss-core'),
            ]
        );

        $this->add_control(
            'c_slide_per_single',
            [
                'label' => esc_html__('Slide per single item', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'center_mode',
            [
                'label' => esc_html__('Center Mode', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('On', 'reuss-core'),
                'label_off' => esc_html__('Off', 'reuss-core'),
            ]
        );

        $this->add_control(
            'center_info',
            [
                'label' => esc_html__('Show Center Info', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'condition' => [ 'center_mode' => 'yes' ],
            ]
        );

        $this->add_control(
            'variable_width',
            [
                'label' => esc_html__('Variable Width', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('On', 'reuss-core'),
                'label_off' => esc_html__('Off', 'reuss-core'),
            ]
        );

        $this->add_responsive_control(
            'slide_variable_width',
            [
                'label' => esc_html__('Slide Width', 'reuss-core'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => ['min' => 200, 'max' => 1200, 'step' => 10],
                ],
                'default' => [
                    'size' => 770,
                ],
                'tablet_default' => [
                    'size' => 540,
                ],
                'mobile_default' => [
                    'size' => 400,
                ],
                'selectors' => [
                    '{{WRAPPER}} .wgl-carousel .wgl-portfolio-list_item' => 'width: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [ 'variable_width' => 'yes' ],
                'render_type' => 'template',
            ]
        );

        $this->add_control(
            'use_pagination',
            [
                'label' => esc_html__('Add Pagination control', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'pag_type',
            [
                'label' => esc_html__('Pagination Type', 'reuss-core'),
                'type' => 'wgl-radio-image',
                'condition' => [ 'use_pagination' => 'yes' ],
                'options' => [
                    'circle' => [
                        'title' => esc_html__('Circle', 'reuss-core'),
                        'image' => WGL_ELEMENTOR_ADDONS_URL . 'assets/img/wgl_elementor_addon/icons/pag_circle.png',
                    ],
                    'circle_border' => [
                        'title' => esc_html__('Empty Circle', 'reuss-core'),
                        'image' => WGL_ELEMENTOR_ADDONS_URL . 'assets/img/wgl_elementor_addon/icons/pag_circle_border.png',
                    ],
                    'square' => [
                        'title' => esc_html__('Square', 'reuss-core'),
                        'image' => WGL_ELEMENTOR_ADDONS_URL . 'assets/img/wgl_elementor_addon/icons/pag_square.png',
                    ],
                    'square_border' => [
                        'title' => esc_html__('Empty Square', 'reuss-core'),
                        'image' => WGL_ELEMENTOR_ADDONS_URL . 'assets/img/wgl_elementor_addon/icons/pag_square_border.png',
                    ],
                    'line' => [
                        'title' => esc_html__('Line', 'reuss-core'),
                        'image' => WGL_ELEMENTOR_ADDONS_URL . 'assets/img/wgl_elementor_addon/icons/pag_line.png',
                    ],
                    'line_circle' => [
                        'title' => esc_html__('Line - Circle', 'reuss-core'),
                        'image' => WGL_ELEMENTOR_ADDONS_URL . 'assets/img/wgl_elementor_addon/icons/pag_line_circle.png',
                    ],
                ],
                'default' => 'circle',
            ]
        );

        $this->add_control(
            'pag_offset',
            [
                'label' => esc_html__('Pagination Top Offset', 'reuss-core'),
                'type' => Controls_Manager::NUMBER,
                'condition' => [ 'use_pagination' => 'yes' ],
                'min' => -55,
                'max' => 55,
                'default' => 14,
                'selectors' => [
                    '{{WRAPPER}} .wgl-carousel .slick-dots' => 'margin-top: {{VALUE}}px;',
                ],
            ]
        );

        $this->add_control(
            'custom_pag_color',
            [
                'label' => esc_html__('Customize Pagination Color', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'condition' => [ 'use_pagination!' => '' ],
            ]
        );

        $this->add_control(
            'pag_color',
            [
                'label' => esc_html__('Pagination Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => $primary_color,
                'condition' => [ 'custom_pag_color' => 'yes' ],
            ]
        );

        $this->add_control(
            'use_prev_next',
            [
                'label' => esc_html__('Add Prev/Next buttons', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'arrows_center_mode',
            [
                'label' => esc_html__('Center Mode', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'condition' => [ 'use_prev_next' => 'yes' ],
                'label_on' => esc_html__('On', 'reuss-core'),
                'label_off' => esc_html__('Off', 'reuss-core'),
            ]
        );


        $this->add_control(
            'custom_resp',
            [
                'label' => esc_html__('Customize Responsive', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('On', 'reuss-core'),
                'label_off' => esc_html__('Off', 'reuss-core'),
            ]
        );

        $this->add_control(
            'heading_desktop',
            [
                'label' => esc_html__('Desktop Settings', 'reuss-core'),
                'type' => Controls_Manager::HEADING,
                'condition' => [ 'custom_resp' => 'yes' ],
                'separator' => 'after',
            ]
        );

        $this->add_control(
            'resp_medium',
            [
                'label' => esc_html__('Desktop Screen Breakpoint', 'reuss-core'),
                'type' => Controls_Manager::NUMBER,
                'condition' => [ 'custom_resp' => 'yes' ],
                'min' => 1,
                'default' => '1025',
            ]
        );

        $this->add_control(
            'resp_medium_slides',
            [
                'label' => esc_html__('Columns amount', 'reuss-core'),
                'type' => Controls_Manager::NUMBER,
                'condition' => [ 'custom_resp' => 'yes' ],
                'min' => 1,
            ]
        );

        $this->add_control(
            'heading_tablet',
            [
                'label' => esc_html__('Tablet Settings', 'reuss-core'),
                'type' => Controls_Manager::HEADING,
                'separator' => 'after',
                'condition' => [ 'custom_resp' => 'yes' ],
            ]
        );

        $this->add_control(
            'resp_tablets',
            [
                'label' => esc_html__('Tablet Screen Breakpoint', 'reuss-core'),
                'type' => Controls_Manager::NUMBER,
                'condition' => [ 'custom_resp' => 'yes' ],
                'min' => 1,
                'default' => '800',
            ]
        );

        $this->add_control(
            'resp_tablets_slides',
            [
                'label' => esc_html__('Columns amount', 'reuss-core'),
                'type' => Controls_Manager::NUMBER,
                'condition' => [ 'custom_resp' => 'yes' ],
                'min' => 1,
                'step' => 1,
            ]
        );

        $this->add_control(
            'heading_mobile',
            [
                'label' => esc_html__('Mobile Settings', 'reuss-core'),
                'type' => Controls_Manager::HEADING,
                'condition' => [ 'custom_resp' => 'yes' ],
                'separator' => 'after',
            ]
        );

        $this->add_control(
            'resp_mobile',
            [
                'label' => esc_html__('Mobile Screen Breakpoint', 'reuss-core'),
                'type' => Controls_Manager::NUMBER,
                'condition' => [ 'custom_resp' => 'yes' ],
                'min' => 1,
                'default' => '480',
            ]
        );

        $this->add_control(
            'resp_mobile_slides',
            [
                'label' => esc_html__('Columns amount', 'reuss-core'),
                'type' => Controls_Manager::NUMBER,
                'condition' => [ 'custom_resp' => 'yes' ],
                'min' => 1,
            ]
        );

        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  SETTINGS -> QUERY
        /*-----------------------------------------------------------------------------------*/

        Wgl_Loop_Settings::init(
            $this,
            [
                'post_type' => 'portfolio',
                'hide_cats' => true,
                'hide_tags' => true
            ]
        );


        /*-----------------------------------------------------------------------------------*/
        /*  STYLE -> GENERAL
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'media_style_section',
            [
                'label' => esc_html__('General', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'items_padding',
            [
                'label' => esc_html__('Description Padding', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'condition' => [ 'gallery_mode' => '' ],
                'size_units' => [ 'px', 'em', '%' ],
                'default' => [
                    'top' => 17,
                    'right' => 30,
                    'bottom' => 21,
                    'left' => 30,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .wgl-portfolio-item_description' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'description',
                'types' => [ 'classic', 'gradient' ],
                'condition' => [
                    'info_position' => 'under_image',
                    'gallery_mode' => ''
                ],
                'selector' => '{{WRAPPER}} .wgl-portfolio-item_description',
                'fields_options' => [
                    'background' => [ 'default' => 'classic' ],
                    'color' => [ 'default' => '#ffffff'],
                ],
            ]
        );

        $this->add_control(
            'overlay_heading',
            [
                'label' => esc_html__('Item Overlay', 'reuss-core'),
                'type' => Controls_Manager::HEADING,
                'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'name' => 'info_position',
                            'operator' => '===',
                            'value' => 'inside_image',
                        ],
                        [
                            'name' => 'gallery_mode',
                            'operator' => '!==',
                            'value' => '',
                        ],
                    ],
                ],
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'custom_image_mask_color',
                'types' => [ 'classic', 'gradient' ],
                'conditions' => [
                    'relation' => 'or',
                    'terms' => [
                        [
                            'terms' => [
                                [
                                    'name' => 'info_position',
                                    'operator' => '===',
                                    'value' => 'inside_image',
                                ],
                                [
                                    'name' => 'image_anim',
                                    'operator' => '!==',
                                    'value' => 'sub_layer',
                                ],
                            ],
                        ],
                        [
                            'name' => 'gallery_mode',
                            'operator' => '!==',
                            'value' => '',
                        ],
                    ],
                ],
                'selector' => '{{WRAPPER}} .overlay',
                'fields_options' => [
                    'background' => [ 'default' => 'classic' ],
                    'color' => [ 'default' => '#ffffff' ],
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'custom_desc_mask_color',
                'types' => [ 'classic', 'gradient' ],
                'condition' => [
                    'info_position' => 'inside_image',
                    'image_anim' => 'sub_layer',
                    'gallery_mode' => ''
                ],
                'selector' => '{{WRAPPER}} .wgl-portfolio-item_description',
                'fields_options' => [
                    'background' => [ 'default' => 'classic' ],
                    'color' => [ 'default' => '#ffffff' ],
                ],
            ]
        );

        $this->add_control(
            'sec_overlay_color',
            [
                'label' => esc_html__('Additional Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'info_position' => 'inside_image',
                    'image_anim' => [ 'offset', 'outline', 'always_info' ],
                ],
                'default' => $primary_color,
                'selectors' => [
                    '{{WRAPPER}} .inside_image .overlay:before' => 'box-shadow: inset 0px 0px 0px 0px {{VALUE}}',
                    '{{WRAPPER}} .inside_image:hover .overlay:before' => 'box-shadow: inset 0px 0px 0px 10px {{VALUE}}',
                    '{{WRAPPER}} .inside_image.offset_animation:before' => 'border-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'sec_overlay_bg',
            [
                'label' => esc_html__('Offset Background', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'info_position' => 'inside_image',
                    'image_anim' => [ 'offset' ],
                ],
                'default' => $primary_color,
                'selectors' => [
                    '{{WRAPPER}} .inside_image.offset_animation:before' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  STYLE -> FILTER
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'section_style_filter',
            [
                'label' => esc_html__('Filter', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [ 'show_filter' => 'yes' ],
            ]
        );

        $this->add_responsive_control(
            'filter_cats_padding',
            [
                'label' => esc_html__('Padding', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'default' => [
                    'top' => 0,
                    'right' => 0,
                    'bottom' => 0,
                    'left' => 0,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .isotope-filter a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'filter_cats_margin',
            [
                'label' => esc_html__('Margin', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'default' => [
                    'top' => 0,
                    'right' => 50,
                    'bottom' => 0,
                    'left' => 0,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .isotope-filter a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .isotope-filter' => 'margin-bottom: calc(48px - {{BOTTOM}}{{UNIT}});',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'custom_fonts_filter_cats',
                'selector' => '{{WRAPPER}} .isotope-filter a',
            ]
        );

        $this->start_controls_tabs('filter_cats_color_tabs');

        $this->start_controls_tab(
            'filter_cats_color_idle',
            [ 'label' => esc_html__('Idle', 'reuss-core') ]
        );

        $this->add_control(
            'filter_color_idle',
            [
                'label' => esc_html__('Text Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => $h_font_color,
                'selectors' => [
                    '{{WRAPPER}} .isotope-filter a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'filter_bg_idle',
            [
                'label' => esc_html__('Background', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .isotope-filter a' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'filter_cats_color_hover',
            [ 'label' => esc_html__('Hover', 'reuss-core') ]
        );

        $this->add_control(
            'filter_color_hover',
            [
                'label' => esc_html__('Text Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => $primary_color,
                'selectors' => [
                    '{{WRAPPER}} .isotope-filter a:hover' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .isotope-filter a:before' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'filter_bg_hover',
            [
                'label' => esc_html__('Background', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .isotope-filter a:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'filter_cats_color_active',
            [ 'label' => esc_html__('Active', 'reuss-core') ]
        );

        $this->add_control(
            'filter_color_active',
            [
                'label' => esc_html__('Text Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => $primary_color,
                'selectors' => [
                    '{{WRAPPER}} .isotope-filter a.active' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'filter_bg_active',
            [
                'label' => esc_html__('Background', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .isotope-filter a.active' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->add_control(
            'filter_cats_radius',
            [
                'label' => esc_html__('Border Radius', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'default' => [
                    'top' => 0,
                    'left' => 0,
                    'right' => 0,
                    'bottom' => 0,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .isotope-filter a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'filter_cats_shadow',
                'selector' => '{{WRAPPER}} .isotope-filter a',
            ]
        );

        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  STYLE -> HEADINGS
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'section_style_headings',
            [
                'label' => esc_html__('Headings', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'show_portfolio_title!' => '',
                    'gallery_mode' => ''
                ],
            ]
        );

        $this->add_responsive_control(
            'headings_padding',
            [
                'label' => esc_html__('Padding', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'default' => [
                    'top' => 5,
                    'right' => 0,
                    'bottom' => 0,
                    'left' => 0,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .portfolio-item__title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'custom_fonts_portfolio_headings',
                'fields_options' => [
                    'typography' => ['default' => 'yes'],
                    'font_family' => ['default' => \Wgl_Addons_Elementor::$typography_1['font_family']],
                    'font_weight' => ['default' => \Wgl_Addons_Elementor::$typography_1['font_weight']],
                ],
                'selector' => '{{WRAPPER}} .title',
            ]
        );

        $this->start_controls_tabs('headings_color');

        $this->start_controls_tab(
            'custom_headings_color_idle',
            [ 'label' => esc_html__('Idle', 'reuss-core') ]
        );

        $this->add_control(
            'custom_headings_color',
            [
                'label' => esc_html__('Text Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => $h_font_color,
                'selectors' => [
                    '{{WRAPPER}} .title,
                     {{WRAPPER}} .inside_image .portfolio-item__title .title a:not(:hover)' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'custom_headings_color_hover',
            [ 'label' => esc_html__('Hover', 'reuss-core') ]
        );

        $this->add_control(
            'custom_hover_headings_color',
            [
                'label' => esc_html__('Text Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => $secondary_color,
                'selectors' => [
                    '{{WRAPPER}} .title:hover, {{WRAPPER}} .title:hover a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  STYLE -> CATEGORIES
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'cats_style_section',
            [
                'label' => esc_html__('Categories', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [ 'show_meta_categories!' => '' ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'custom_fonts_portfolio_cats',
                'selector' => '{{WRAPPER}} .post_cats',
            ]
        );

        $this->start_controls_tabs('cats_color_tabs');

        $this->start_controls_tab(
            'custom_cats_color_idle',
            [ 'label' => esc_html__('Idle', 'reuss-core') ]
        );

        $this->add_control(
            'cat_color_idle',
            [
                'label' => esc_html__('Text Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => $primary_color,
                'selectors' => [
                    '{{WRAPPER}} .portfolio-category,
                     {{WRAPPER}} .portfolio-category:before,
                     {{WRAPPER}} .portfolio-category:after' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'custom_cats_color_hover',
            [ 'label' => esc_html__('Hover', 'reuss-core') ]
        );

        $this->add_control(
            'cat_color_hover',
            [
                'label' => esc_html__('Text Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => $secondary_color,
                'selectors' => [
                    '{{WRAPPER}} .portfolio-category:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  STYLE -> EXCERPT/CONTENT
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'section_style_content',
            [
                'label' => esc_html__('Excerpt/Content', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [ 'show_content!' => '' ],
            ]
        );

        $this->add_control(
            'custom_content_color',
            [
                'label' => esc_html__('Text Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '#ffffff',
                'selectors' => [
                    '{{WRAPPER}} .wgl-portfolio-item_content' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  STYLE -> LOAD MORE
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'load_more_style_section',
            [
                'label' => esc_html__('Load More', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [ 'navigation' => 'load_more' ],
            ]
        );

        $this->add_control(
            'align_load_more',
            [
                'label' => esc_html__( 'Alignment', 'reuss-core' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'reuss-core' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'reuss-core' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'reuss-core' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                ],
                'default' => 'center',
                'selectors' => [
                    '{{WRAPPER}} .load_more_wrapper' => 'text-align: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'load_more_padding',
            [
                'label' => esc_html__('Padding', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .load_more_wrapper .load_more_item' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'load_more_margin',
            [
                'label' => esc_html__('Margin', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'default' => [
                    'top' => 37,
                    'left' => 0,
                    'right' => 0,
                    'bottom' => 0,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .load_more_wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'custom_fonts_load_more',
                'selector' => '{{WRAPPER}} .load_more_wrapper .load_more_item',
            ]
        );

        $this->start_controls_tabs('load_more_styles');

        $this->start_controls_tab(
            'load_more_idle',
            [ 'label' => esc_html__('Idle', 'reuss-core') ]
        );

        $this->add_control(
            'load_more_color_idle',
            [
                'label' => esc_html__('Text Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .load_more_wrapper .load_more_item' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'load_more_bg_idle',
            [
                'label' => esc_html__('Background', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .load_more_wrapper .load_more_item' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'load_more_hover',
            [ 'label' => esc_html__('Hover', 'reuss-core') ]
        );

        $this->add_control(
            'load_more_color_hover',
            [
                'label' => esc_html__('Text Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .load_more_wrapper .load_more_item:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'load_more_bg_hover',
            [
                'label' => esc_html__('Background', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .load_more_wrapper .load_more_item:hover' => 'background: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'load_more_border',
                'label' => esc_html__('Border Type', 'reuss-core'),
                'selector' => '{{WRAPPER}} .load_more_wrapper .load_more_item',
            ]
        );

        $this->add_control(
            'load_more_radius',
            [
                'label' => esc_html__('Border Radius', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'default' => [
                    'top' => 35,
                    'right' => 35,
                    'bottom' => 35,
                    'left' => 35,
                    'unit' => 'px',
                ],
                'selectors' => [
                    '{{WRAPPER}} .load_more_wrapper .load_more_item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'load_more_shadow',
                'selector' => '{{WRAPPER}} .load_more_wrapper .load_more_item',
            ]
        );

        $this->end_controls_section();
    }

    protected function render()
    {
        $atts = $this->get_settings_for_display();

        $portfolio = new WglPortfolio();
        echo $portfolio->render($atts, $this);
    }

}
