<?php

namespace WglAddons\Widgets;

defined( 'ABSPATH' ) || exit; // Abort, if called directly.

use WglAddons\Includes\Wgl_Icons;
use WglAddons\Includes\Wgl_Elementor_Helper;
use Elementor\Frontend;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Control_Media;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Text_Shadow;
use Elementor\Group_Control_Background;
use Elementor\Utils;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Css_Filter;
use Elementor\Repeater;


class Wgl_Time_Line_Horizontal extends Widget_Base
{
    public function get_name() {
        return 'wgl-time-line-horizontal';
    }

    public function get_title() {
        return esc_html__('WGL Time Line Horizontal', 'reuss-core');
    }

    public function get_icon() {
        return 'wgl-time-line-horizontal';
    }

    public function get_categories() {
        return [ 'wgl-extensions' ];
    }

    public function get_script_depends() {
        return [ 'jquery-appear' ];
    }


    protected function _register_controls()
    {
        $primary_color = esc_attr(\Reuss_Theme_Helper::get_option('theme-primary-color'));
        $secondary_color = esc_attr(\Reuss_Theme_Helper::get_option('theme-secondary-color'));
        $header_font_color = esc_attr(\Reuss_Theme_Helper::get_option('header-font')['color']);
        $main_font_color = esc_attr(\Reuss_Theme_Helper::get_option('main-font')['color']);


        /*-----------------------------------------------------------------------------------*/
        /*  CONTENT -> GENERAL
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'wgl_time_line_h_section',
            [
                'label' => esc_html__('General', 'reuss-core'),
            ]
        );

        $this->add_control(
            'add_appear',
            [
                'label' => esc_html__('Add Appear Animation', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__('On', 'reuss-core'),
                'label_off' => esc_html__('Off', 'reuss-core'),
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'alignment',
            [
                'label' => esc_html__('Alignment', 'reuss-core'),
                'type' => Controls_Manager::CHOOSE,
                'toggle' => true,
                'options' => [
                    'left' => [
                        'title' => esc_html__('Left', 'reuss-core'),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'reuss-core'),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__('Right', 'reuss-core'),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'default' => 'center',
                'prefix_class' => 'a',
            ]
        );

        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  CONTENT -> CONTENT
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__('Content', 'reuss-core'),
            ]
        );

        $repeater = new Repeater();

	    $repeater->add_control(
		    'date',
		    [
			    'label' => esc_html__('Date', 'reuss-core'),
			    'type' => Controls_Manager::TEXT,
		    ]
	    );

	    $repeater->add_control(
		    'content_type',
		    [
			    'label' => esc_html__('Content Type', 'reuss-core'),
			    'type' => Controls_Manager::SELECT,
			    'options' => [
				    'content' => esc_html__('Content', 'reuss-core'),
				    'template' => esc_html__('Saved Templates', 'reuss-core'),
			    ],
			    'default' => 'content',
		    ]
	    );
	    $repeater->add_control(
		    'content_templates',
		    [
			    'label' => esc_html__('Choose Template', 'reuss-core'),
			    'type' => Controls_Manager::SELECT,
			    'condition' => [ 'content_type' => 'template' ],
			    'options' => Wgl_Elementor_Helper::get_instance()->get_elementor_templates(),
		    ]
	    );

        $repeater->add_control(
            'title',
            [
                'label' => esc_html__('Title', 'reuss-core'),
                'type' => Controls_Manager::TEXTAREA,
				'default' => esc_html__('This is the heading​', 'reuss-core'),
				'placeholder' => esc_html__('This is the heading​', 'reuss-core'),
                'dynamic' => [ 'active' => true],
                'condition' => [ 'content_type' => 'content' ],
            ]
        );

        $repeater->add_control(
            'content',
            [
                'label' => esc_html__('Content', 'reuss-core'),
                'type' => Controls_Manager::WYSIWYG,
                'default' => esc_html__('Lorem ipsum dolor sit amet, consectetur adipisicing elit. Optio, neque qui velit. Magni dolorum quidem ipsam eligendi, totam, facilis laudantium cum accusamus ullam voluptatibus commodi numquam, error, est. Ea, consequatur.', 'reuss-core'),
                'dynamic' => [ 'active' => true],
                'condition' => [ 'content_type' => 'content' ],
            ]
        );

        $this->add_control(
            'items',
            [
                'label' => esc_html__('Layers', 'reuss-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'title' => esc_html__('First heading​', 'reuss-core'),
                        'date' => esc_html__('2000', 'reuss-core'),
                    ],
                    [
                        'title' => esc_html__('Second heading​', 'reuss-core'),
                        'date' => esc_html__('2005', 'reuss-core'),
                    ]
                ],
                'title_field' => '{{title}}',
            ]
        );

        $this->end_controls_section();


	    /*-----------------------------------------------------------------------------------*/
	    /*  CONTENT -> CAROUSEL OPTIONS
		/*-----------------------------------------------------------------------------------*/

	    $this->start_controls_section(
		    'content_section_carousel',
		    [
			    'label' => esc_html__('Carousel Options', 'reuss-core'),
		    ]
	    );

	    $this->add_control(
		    'autoplay',
		    [
			    'label' => esc_html__('Autoplay', 'reuss-core'),
			    'type' => Controls_Manager::SWITCHER,
			    'label_on' => esc_html__('On', 'reuss-core'),
			    'label_off' => esc_html__('Off', 'reuss-core'),
		    ]
	    );

	    $this->add_control(
		    'autoplay_speed',
		    [
			    'label' => esc_html__('Autoplay Speed', 'reuss-core'),
			    'type' => Controls_Manager::NUMBER,
			    'condition' => [ 'autoplay' => 'yes' ],
			    'min' => 1,
			    'default' => '3000',
		    ]
	    );

	    $this->end_controls_section();

        /*-----------------------------------------------------------------------------------*/
        /*  STYLE -> DATE
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'date_style_section',
            [
                'label' => esc_html__('Date', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'date_typo',
                'selector' => '{{WRAPPER}} .time_line-date',
            ]
        );

	    $this->add_responsive_control(
		    'pag_offset',
		    [
			    'label' => esc_html__('Dots Bottom Offset', 'reuss-core'),
			    'type' => Controls_Manager::SLIDER,
			    'range' => [ 'px' => [ 'min' => -50, 'max' => 200 ] ],
			    'default' => [ 'size' => 70 ],
			    'selectors' => [
				    '{{WRAPPER}} .time_line_h-date_wrap' => 'margin-bottom: {{SIZE}}px;',
			    ],
		    ]
	    );

        $this->add_responsive_control(
            'date_wrapper_size',
            [
                'label' => esc_html__('Date Wrapper Max Width', 'reuss-core'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [ 'max' => 1920 ],
                    '%' => [ 'max' => 100 ],
                ],
                'size_units' => [ 'px', '%' ],
                'default' => [ 'size' => 70, 'unit' => '%' ],
                'selectors' => [
                    '{{WRAPPER}} .time_line_h-date_wrap .slick-track' => 'max-width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'line_color',
            [
                'label' => esc_html__('Line Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '#b0b7d3',
                'selectors' => [
                    '{{WRAPPER}} .time_line_h-date:before' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .time_line_h-date:after' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->start_controls_tabs( 'date_colors' );

        $this->start_controls_tab(
            'date_colors_idle',
            [
                'label' => esc_html__('Idle', 'reuss-core'),
            ]
        );

        $this->add_control(
            'date_color',
            [
                'label' => esc_html__('Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '#b0b7d3',
                'selectors' => [
                    '{{WRAPPER}} .time_line_h-date_inner .time_line-date' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .time_line_h-date_inner .time_line-dot' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'date_colors_hover',
            [
                'label' => esc_html__('Hover', 'reuss-core'),
            ]
        );

        $this->add_control(
            'date_hover_color',
            [
                'label' => esc_html__('Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => $secondary_color,
                'selectors' => [
                    '{{WRAPPER}} .time_line_h-date_inner:hover .time_line-date' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .time_line_h-date_inner:hover .time_line-dot' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'date_colors_active',
            [
                'label' => esc_html__('Active', 'reuss-core'),
            ]
        );

        $this->add_control(
            'date_active_color',
            [
                'label' => esc_html__('Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => $primary_color,
                'selectors' => [
                    '{{WRAPPER}} .time_line_h-date.slick-current .time_line_h-date_inner .time_line-date' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .time_line_h-date.slick-current .time_line_h-date_inner .time_line-dot' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();

	    /*-----------------------------------------------------------------------------------*/
        /*  STYLE -> TITLE
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'title_style_section',
            [
                'label' => esc_html__('Title', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typo',
                'fields_options' => [
                    'typography' => ['default' => 'yes'],
                    'font_family' => ['default' => \Wgl_Addons_Elementor::$typography_1['font_family']],
                    'font_weight' => ['default' => \Wgl_Addons_Elementor::$typography_1['font_weight']],
                ],
                'selector' => '{{WRAPPER}} .time_line_h-title',
            ]
        );

        $this->start_controls_tabs( 'title_colors' );

        $this->start_controls_tab(
            'title_colors_idle',
            [
                'label' => esc_html__('Idle', 'reuss-core'),
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__('Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => $header_font_color,
                'selectors' => [
                    '{{WRAPPER}} .time_line_h-title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'title_colors_hover',
            [
                'label' => esc_html__('Hover', 'reuss-core'),
            ]
        );

        $this->add_control(
            'title_hover_color',
            [
                'label' => esc_html__('Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .time_line_h-item:hover .time_line_h-title' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .time_line_h-item:hover .time_line_h-pointer:before' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  STYLE -> CONTENT
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'content_style_section',
            [
                'label' => esc_html__('Content', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_typo',
                'selector' => '{{WRAPPER}} .time_line_h-text',
            ]
        );

        $this->start_controls_tabs( 'content_colors' );

        $this->start_controls_tab(
            'content_colors_idle',
            [
                'label' => esc_html__('Idle', 'reuss-core'),
            ]
        );

        $this->add_control(
            'content_color',
            [
                'label' => esc_html__('Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => $main_font_color,
                'selectors' => [
                    '{{WRAPPER}} .time_line_h-text' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'content_colors_hover',
            [
                'label' => esc_html__('Hover', 'reuss-core'),
            ]
        );

        $this->add_control(
            'content_hover_color',
            [
                'label' => esc_html__('Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .time_line_h-item:hover .time_line_h-text' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();

    }

    protected function render()
    {

        wp_enqueue_script('jquery-appear', get_template_directory_uri() . '/js/jquery.appear.js', [], false, false);
	    wp_enqueue_script('jquery-slick', get_template_directory_uri() . '/js/slick.min.js', [], false, false);

        $settings = $this->get_settings_for_display();

        // HTML tags allowed for rendering
        $allowed_html = [
            'a' => [
                'href' => true,
                'title' => true,
            ],
            'br' => [],
            'em' => [],
            'strong' => [],
            'span' => [
                'class' => true,
                'style' => true,
            ],
            'p' => [
                'class' => true,
                'style' => true,
            ]
        ];

	    $this->add_render_attribute( 'timeline-horizontal', [
		    'class' => [
			    'wgl-timeline-horizontal',
			    ( $settings['add_appear'] ? 'appear_anim' : '' ),
		    ],
	    ] );


	    $data_array = [];
	    $data_array['slidesToShow'] = 1;
	    $data_array['autoplay'] = $settings['autoplay'] ? true : false;
	    $data_array['speed'] = $settings['autoplay_speed'] ? (int)$settings['autoplay_speed'] : '3000';
	    $data_array['arrows'] = false;

	    $data_attribute = " data-wgl-slick='".json_encode($data_array, true)."'";

	    $data_array_dots['slidesToShow'] = count($settings[ 'items' ]);
	    $data_attribute_dots = " data-wgl-slick-dots='".json_encode($data_array_dots, true)."'";

        ?>
        <div <?php echo $this->get_render_attribute_string( 'timeline-horizontal' ); ?>>
            <div class="time_line_h-items_wrap"><?php

            $_date = $_content = '';

            foreach ( $settings[ 'items' ] as $index => $item ) {

                $title = $this->get_repeater_setting_key( 'title', 'items' , $index );
                $this->add_render_attribute(
                    $title,
                    [ 'class' => 'time_line_h-title' ]
                );

                $item_wrap = $this->get_repeater_setting_key( 'item_wrap', 'items' , $index );
                $this->add_render_attribute(
                    $item_wrap,
                    [ 'class' => 'time_line_h-item' ]
                );

                $_date .= '<div class="time_line_h-date">';
                    $_date .= '<div class="time_line_h-date_inner">';
                        $_date .= '<span class="time_line-dot"></span>';
                        $_date .= '<span class="time_line-date">'.$item[ 'date' ].'</span>';
                    $_date .= '</div>';
                $_date .= '</div>';

	            $_content .= '<div class="time_line_h-content_wrap">';
	            if ( $item['content_type'] == 'content' ) {
		            if ( ! empty( $item['content'] ) || ! empty( $item['title'] ) ) {
			            if ( ! empty( $item['title'] ) ) {
				            $_content .= '<h3 ' . $this->get_render_attribute_string( $title ) . '>' . $item['title'] . '</h3>';
			            }
			            if ( ! empty( $item['content'] ) ) {
				            $_content .= '<div class="time_line_h-text">' . $item['content'] . '</div>';
			            }
		            }
	            } else if ( $item['content_type'] == 'template' ) {
		            $wgl_frontend = new Frontend;
		            $_content .= $wgl_frontend->get_builder_content_for_display( $item['content_templates'], false );
	            }
	            $_content .= '</div>';

            } // end foreach

            echo '<div class="time_line_h-date_wrap" '.$data_attribute_dots.'>',
                $_date,
            '</div>';

            echo '<div class="time_line_h-content" '.$data_attribute.'>',
                $_content,
            '</div>';

            ?>
            </div>
        </div><?php

    }
}