<?php

namespace WglAddons\Widgets;

defined( 'ABSPATH' ) || exit; // Abort, if called directly.

use WglAddons\Includes\Wgl_Icons;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Control_Media;
use Elementor\Scheme_Color;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use Elementor\Utils;
use Elementor\Repeater;
use WglAddons\Includes\Wgl_Elementor_Helper;


class Wgl_Time_Line_Vertical extends Widget_Base
{
    public function get_name() {
        return 'wgl-time-line-vertical';
    }

    public function get_title() {
        return esc_html__('WGL Time Line Vertical', 'reuss-core');
    }

    public function get_icon() {
        return 'wgl-time-line-vertical';
    }

    public function get_categories() {
        return [ 'wgl-extensions' ];
    }

    public function get_script_depends() {
        return [ 'jquery-appear' ];
    }


    protected function _register_controls()
    {
        $primary_color = esc_attr(\Reuss_Theme_Helper::get_option('theme-primary-color'));
        $secondary_color = esc_attr(\Reuss_Theme_Helper::get_option('theme-secondary-color'));
        $theme_gradient_from = esc_attr(\Reuss_Theme_Helper::get_option('theme-gradient')['from']);
        $theme_gradient_to = esc_attr(\Reuss_Theme_Helper::get_option('theme-gradient')['to']);
        $h_font_color = esc_attr(\Reuss_Theme_Helper::get_option('header-font')['color']);
        $main_font_color = esc_attr(\Reuss_Theme_Helper::get_option('main-font')['color']);


        /*-----------------------------------------------------------------------------------*/
        /*  CONTENT -> GENERAL
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'section_content_general',
            [ 'label' => esc_html__('General', 'reuss-core') ]
        );

        $this->add_control(
            'add_appear',
            [
                'label' => esc_html__('Use Appear Animation?', 'reuss-core'),
                'type' => Controls_Manager::SWITCHER,
                'default' => 'yes',
            ]
        );

        $this->add_responsive_control(
            'module_padding',
            [
                'label' => esc_html__('Padding', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'default' => [
                    'top' => 80,
                    'right' => 0,
                    'bottom' => 65,
                    'left' => 0,
                ],
                'selectors' => [
                    '{{WRAPPER}} .tlv__items-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  CONTENT -> CONTENT
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'section_content_content',
            [ 'label' => esc_html__('Content', 'reuss-core') ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'thumbnail_idle',
            [
                'label' => esc_html__('Thumbnail', 'reuss-core'),
                'type' => Controls_Manager::MEDIA,
            ]
        );

        $repeater->add_control(
            'date',
            [
                'label' => esc_html__('Number', 'reuss-core'),
                'type' => Controls_Manager::TEXT,
            ]
        );

        $repeater->add_control(
            'title',
            [
                'label' => esc_html__('Title', 'reuss-core'),
                'type' => Controls_Manager::TEXTAREA,
                'rows' => 1,
                'separator' => 'before',
                'placeholder' => esc_html__('Your title', 'reuss-core'),
            ]
        );

        $repeater->add_control(
            'content',
            [
                'label' => esc_html__('Content', 'reuss-core'),
                'type' => Controls_Manager::WYSIWYG,
                'default' => esc_html__('Lorem ipsum dolor sit amet, consectetur adipisicing elit. Optio, neque qui velit.', 'reuss-core'),
            ]
        );

        $repeater->add_control(
            'color_style',
            [
                'label' => esc_html__('Color Style', 'reuss-core'),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'color' => esc_html__('Color', 'reuss-core'),
                    'gradient' => esc_html__('Gradient', 'reuss-core'),
                ],
                'default' => 'color',
                'render_type' => 'template',
            ]
        );

        // Color Styles
        $repeater->add_control(
            'text_color_color',
            [
                'label' => esc_html__('Text Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '#ffffff',
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.tlv__item .tlv__date' => 'color: {{VALUE}};',
                    '{{WRAPPER}} {{CURRENT_ITEM}}.tlv__item .tlv__curve-wrapper:after' => 'background-color: {{VALUE}};',
                ],
                'condition' => ['color_style' => 'color'],
            ]
        );

        $repeater->add_control(
            'bg_color',
            [
                'label' => esc_html__('Background Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => $primary_color,
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.tlv__item .tlv__date' => 'background-color: {{VALUE}};',
                    '{{WRAPPER}} {{CURRENT_ITEM}}.tlv__item .tlv__curve-circle' => 'background-color: {{VALUE}};',
                ],
                'condition' => ['color_style' => 'color'],
            ]
        );

        // End Color Styles

        // Gradient Styles 
        
        $repeater->add_control(
            'text_color_gradient',
            [
                'label' => esc_html__('Text Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '#ffffff',
                'selectors' => [
                    '{{WRAPPER}} {{CURRENT_ITEM}}.tlv__item .tlv__date' => 'color: {{VALUE}};',
                    '{{WRAPPER}} {{CURRENT_ITEM}}.tlv__item .tlv__curve-wrapper:after' => 'background-color: {{VALUE}};',
                ],
                'condition' => ['color_style' => 'gradient'],
            ]
        );

        $repeater->add_control(
            'bg_gradient_from',
            [
                'label' => esc_html__('Background Gradient From', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => $theme_gradient_from,
                'condition' => ['color_style' => 'gradient'],
                'render_type' => 'template',
            ]
        );

        $repeater->add_control(
            'bg_gradient_to',
            [
                'label' => esc_html__('Background Gradient To', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => $theme_gradient_to,
                'condition' => ['color_style' => 'gradient'],
                'render_type' => 'template',
            ]
        );

        // End Gradien Styles 


        $this->add_control(
            'items',
            [
                'label' => esc_html__('Layers', 'reuss-core'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'title' => esc_html__('First heading​', 'reuss-core'),
                        'date' => esc_html__('01', 'reuss-core'),
                    ],
                    [
                        'title' => esc_html__('Second heading​', 'reuss-core'),
                        'date' => esc_html__('02', 'reuss-core'),
                    ],
                ],
                'title_field' => '{{title}}',
            ]
        );

        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  STYLE -> LINE
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'section_style_line',
            [
                'label' => esc_html__('Main Line', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'line_margin',
            [
                'label' => esc_html__('Margin', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'separator' => 'after',
                'default' => [
                    'top' => 0,
                    'right' => 100,
                    'bottom' => 0,
                    'left' => 100,
                ],
                'tablet_default' => [
                    'top' => 0,
                    'right' => 40,
                    'bottom' => 0,
                    'left' => 40,
                ],
                'mobile_default' => [
                    'top' => 0,
                    'right' => 40,
                    'bottom' => 0,
                    'left' => 10,
                ],
                'selectors' => [
                    '{{WRAPPER}} .tlv__curve-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    '{{WRAPPER}} .tlv__curve-wrapper:before' => 'width: calc({{RIGHT}}{{UNIT}} + 30px);',
                ],
            ]
        );

        $this->add_control(
            'line_bg',
            [
                'label' => esc_html__('Line Background Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '#c0c8de',
                'render_type' => 'template',
                'selectors' => [
                    '{{WRAPPER}} .tlv__items-wrapper:before' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .tlv__curve-wrapper:before' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .wgl-timeline-vertical:before' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .wgl-timeline-vertical:after' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  STYLE -> CONTENT
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'section_style_wrapper',
            [
                'label' => esc_html__('Content', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'wrapper_notice',
            [
                'type' => Controls_Manager::RAW_HTML,
                'content_classes' => 'elementor-panel-alert elementor-panel-alert-warning',
                'raw' => esc_html__('Note: Left/right values are inversed for even items.', 'elementor' ),
            ]
        );

	    $this->add_responsive_control(
		    'items_space',
		    [
			    'label' => esc_html__('Space between items', 'reuss-core'),
			    'type' => Controls_Manager::SLIDER,
			    'range' => [ 'px' => [ 'min' => -50, 'max' => 200 ] ],
			    'default' => [ 'size' => 70 ],
			    'selectors' => [
				    '{{WRAPPER}} .tlv__item:not(:last-child)' => 'margin-bottom: {{SIZE}}px;',
			    ],
		    ]
        );
        
        $this->add_responsive_control(
            'content_margin',
            [
                'label' => esc_html__('Content Margin', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'default' => [
                    'top' => 0,
                    'right' => 45,
                    'bottom' => 0,
                    'left' => 0,
                ],
                'tablet_default' => [
                    'top' => 0,
                    'right' => 0,
                    'bottom' => 0,
                    'left' => 0,
                ],
                'selectors' => [
                    '{{WRAPPER}} .tlv__content-wrapper' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    'body[data-elementor-device-mode="desktop"] {{WRAPPER}} .tlv__item:nth-child(even) .tlv__content-wrapper' => 'margin-left: {{RIGHT}}{{UNIT}}; margin-right: {{LEFT}}{{UNIT}};',

                ],
            ]
        );

        $this->add_responsive_control(
            'wrapper_padding',
            [
                'label' => esc_html__('Padding', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'default' => [
                    'top' => 34,
                    'right' => 40,
                    'bottom' => 30,
                    'left' => 50,
                ],
                'mobile_default' => [
                    'top' => 20,
                    'right' => 30,
                    'bottom' => 15,
                    'left' => 30,
                ],
                'selectors' => [
                    '{{WRAPPER}} .tlv__content-wrapper' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    'body[data-elementor-device-mode="desktop"] {{WRAPPER}} .tlv__item:nth-child(even) .tlv__content-wrapper' => 'padding-left: {{RIGHT}}{{UNIT}}; padding-right: {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'wrapper_border_radius',
            [
                'label' => esc_html__('Border Radius', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'default' => [
                    'top' => 5,
                    'right' => 5,
                    'bottom' => 5,
                    'left' => 5,
                ],
                'selectors' => [
                    '{{WRAPPER}} .tlv__content-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    'body[data-elementor-device-mode="desktop"] {{WRAPPER}} .tlv__item:nth-child(even) .tlv__content-wrapper' => 'border-radius: {{RIGHT}}{{UNIT}} {{TOP}}{{UNIT}} {{LEFT}}{{UNIT}} {{BOTTOM}}{{UNIT}};',
                ],
            ]
        );

        $this->start_controls_tabs(
            'tabs_wrapper',
            [ 'separator' => 'before' ]
        );

        $this->start_controls_tab(
            'tab_wrapper_idle',
            [ 'label' => esc_html__('Idle', 'reuss-core') ]
        );

        $this->add_control(
            'wrapper_bg_idle',
            [
                'label' => esc_html__('Background Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => '#ffffff',
                'selectors' => [
                    '{{WRAPPER}} .tlv__content-wrapper' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'wrapper_idle',
                'selector' => '{{WRAPPER}} .tlv__content-wrapper',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'wrapper_idle',
                'selector' => '{{WRAPPER}} .tlv__content-wrapper',
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_wrapper_hover',
            [ 'label' => esc_html__('Hover', 'reuss-core') ]
        );

        $this->add_control(
            'wrapper_bg_hover',
            [
                'label' => esc_html__('Background Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tlv__item:hover .tlv__content-wrapper' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'wrapper_hover',
                'selector' => '{{WRAPPER}} .tlv__item:hover .tlv__content-wrapper',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'wrapper_hover',
                'selector' => '{{WRAPPER}} .tlv__item:hover .tlv__content-wrapper',
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  STYLE -> MEDIA
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'section_style_media',
            [
                'label' => esc_html__('Media', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'media_notice',
            [
                'type' => Controls_Manager::RAW_HTML,
                'content_classes' => 'elementor-panel-alert elementor-panel-alert-warning',
                'raw' => esc_html__('Note: Left/right values are inversed for even items.', 'elementor' ),
            ]
        );

        $this->add_responsive_control(
            'media_margin',
            [
                'label' => esc_html__('Margin', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'selectors' => [
                    '{{WRAPPER}} .tlv__media' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    'body[data-elementor-device-mode="desktop"] {{WRAPPER}} .tlv__item:nth-child(even) .tlv__media' => 'margin-left: {{RIGHT}}{{UNIT}}; margin-right: {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'media_padding',
            [
                'label' => esc_html__('Padding', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'selectors' => [
                    '{{WRAPPER}} .tlv__media' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    'body[data-elementor-device-mode="desktop"] {{WRAPPER}} .tlv__item:nth-child(even) .tlv__media' => 'padding-left: {{RIGHT}}{{UNIT}}; padding-right: {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'media_border_radius',
            [
                'label' => esc_html__('Border Radius', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'separator' => 'after',
                'size_units' => [ 'px', '%' ],
                'default' => [
                    'top' => 10,
                    'right' => 10,
                    'bottom' => 10,
                    'left' => 10,
                ],
                'selectors' => [
                    '{{WRAPPER}} .tlv__media' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    'body[data-elementor-device-mode="desktop"] {{WRAPPER}} .tlv__item:nth-child(even) .tlv__media' => 'border-radius: {{RIGHT}}{{UNIT}} {{TOP}}{{UNIT}} {{LEFT}}{{UNIT}} {{BOTTOM}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'media',
                'selector' => '{{WRAPPER}} .tlv__media',
            ]
        );

        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  STYLE -> CONTENT TEXT
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'section_style_content',
            [
                'label' => esc_html__('Content Text', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'heading_title',
            [
                'label' => esc_html__('Title Styles', 'reuss-core'),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_title',
                'selector' => '{{WRAPPER}} .tlv__title',
            ]
        );

        $this->start_controls_tabs( 'tabs_title' );

        $this->start_controls_tab(
            'tab_title_idle',
            [ 'label' => esc_html__('Idle', 'reuss-core') ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__('Text Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tlv__title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_title_hover',
            [ 'label' => esc_html__('Hover', 'reuss-core') ]
        );

        $this->add_control(
            'title_hover_color',
            [
                'label' => esc_html__('Text Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tlv__item:hover .tlv__title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->add_control(
            'heading_text',
            [
                'label' => esc_html__('Text Styles', 'reuss-core'),
                'type' => Controls_Manager::HEADING,
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'content_text',
                'selector' => '{{WRAPPER}} .tlv__text',
            ]
        );

        $this->start_controls_tabs( 'tabs_content' );

        $this->start_controls_tab(
            'tab_content_idle',
            [ 'label' => esc_html__('Idle', 'reuss-core') ]
        );

        $this->add_control(
            'content_color',
            [
                'label' => esc_html__('Text Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'default' => $main_font_color,
                'selectors' => [
                    '{{WRAPPER}} .tlv__text' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_content_hover',
            [ 'label' => esc_html__('Hover', 'reuss-core') ]
        );

        $this->add_control(
            'content_color_hover',
            [
                'label' => esc_html__('Text Color', 'reuss-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .tlv__item:hover .tlv__text' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();
        $this->end_controls_section();


        /*-----------------------------------------------------------------------------------*/
        /*  STYLE -> NUMBER
        /*-----------------------------------------------------------------------------------*/

        $this->start_controls_section(
            'section_style_date',
            [
                'label' => esc_html__('Number', 'reuss-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'date',
                'selector' => '{{WRAPPER}} .tlv__date',
            ]
        );

        $this->add_responsive_control(
            'date_margin',
            [
                'label' => esc_html__('Margin', 'reuss-core'),
                'type' => Controls_Manager::DIMENSIONS,
                'selectors' => [
                    '{{WRAPPER}} .tlv__date' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render()
    {
        $_s = $this->get_settings_for_display();

        $rgb_color = '';
        // Allowed HTML tags
        $allowed_html = [
            'a' => [
                'href' => true, 'title' => true,
                'class' => true, 'style' => true,
                'rel' => true, 'target' => true
            ],
            'br' => [ 'class' => true, 'style' => true ],
            'em' => [ 'class' => true, 'style' => true ],
            'strong' => [ 'class' => true, 'style' => true ],
            'span' => [ 'class' => true, 'style' => true ],
            'p' => [ 'class' => true, 'style' => true ],
            'ul' => [ 'class' => true, 'style' => true ],
            'ol' => [ 'class' => true, 'style' => true ],
        ];

        $this->add_render_attribute(
            'timeline-vertical',
            [
                'class' => [
                    'wgl-timeline-vertical',
                    $_s[ 'add_appear' ] ? 'appear_animation' : '',
                ],
            ]
        );

        echo '<div ', $this->get_render_attribute_string('timeline-vertical'), '>';
        echo '<div class="tlv__items-wrapper">';

        foreach ($_s['items'] as $index => $item) {

            if (!empty($item['thumbnail_idle']['url'])) {
                $thumbnail_idle = $this->get_repeater_setting_key('thumbnail', 'list', $index);
                $this->add_render_attribute($thumbnail_idle, [
                    'class' => 'tlv__thumbnail--idle',
                    'src' => esc_url($item['thumbnail_idle']['url']),
                    'alt' => Control_Media::get_image_alt($item['thumbnail_idle']),
                ]);
            }

            if ($item['color_style'] == 'gradient') {
                $rgb_color = \Reuss_Theme_Helper::HexToRGB($item['bg_gradient_from']);
            } else if ($item['color_style'] == 'color') {
                $rgb_color = \Reuss_Theme_Helper::HexToRGB($item['bg_color']);
            }

            $item_shadow = $rgb_color ? 'box-shadow: 19px 13px 32px 0px rgba('.$rgb_color.',0.2);' : '';

            $bg_gradient = ($item['color_style'] == 'gradient') ? ' background-image: linear-gradient(90deg, '.$item['bg_gradient_from'].' 30%, '.$item['bg_gradient_to'].' 100%);' : '';
            $bg_style = $bg_gradient ? ' style="'.$bg_gradient.'"' : '';
            
            echo '<div class="tlv__item elementor-repeater-item-' , $item['_id'] , '">';

                echo '<div class="tlv__date-wrapper">',
                    '<div class="tlv__media">';
                    if (!empty($item['thumbnail_idle']['url'])) {
                        echo '<img ', $this->get_render_attribute_string($thumbnail_idle), '/>';
                    }
                    echo '</div>', // media
                '</div>';

                echo '<div class="tlv__curve-wrapper"><span class="tlv__curve-circle"',$bg_style,'></span></div>';

                echo '<div class="tlv__volume-wrapper">';
                    echo '<span class="tlv__date" style="',$item_shadow,$bg_gradient,'">', $item['date'], '</span>';

                    echo '<div class="tlv__content-wrapper">';

                    echo '<div class="tlv__content">';
                    if (!empty($item['title'])) {
                        echo '<h3 class="tlv__title">',
                            $item['title'],
                        '</h3>';
                    }
                    if (!empty($item['content'])) {
                        echo '<div class="tlv__text">', $item['content'], '</div>';
                    }
                    echo '</div>'; // content

                    echo '</div>'; // content-wrapper
                echo '</div>'; // volume-wrapper

            echo '</div>';
        }

        echo '</div>';
        echo '</div>';

    }

}
