<?php

if (!class_exists('Reuss_Core')) {
    return;
}

if (!function_exists('wgl_get_redux_icons')) {
    function wgl_get_redux_icons()
    {
        return Wgl_Admin_Icon()->get_icons_name(true);
    }

    add_filter('redux/font-icons', 'wgl_get_redux_icons');
}

if (!function_exists('reuss_redux_get_custom_menu')) {
    function reuss_redux_get_custom_menu() {
        $taxonomies = array();

        $menus = get_terms('nav_menu');
        foreach ($menus as $key => $value) {
            $taxonomies[$value->name] = $value->name;
        }
        return $taxonomies;
    }
}

//* This is theme option name where all the Redux data is stored.
$theme_slug = 'reuss_set';

/**
 * ---> SET ARGUMENTS
 * All the possible arguments for Redux.
 * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
 * */
$theme = wp_get_theme();

$args = [
    'opt_name' => $theme_slug, //* This is where your data is stored in the database and also becomes your global variable name.
    'display_name' => $theme->get('Name'), //* Name that appears at the top of your panel
    'display_version' => $theme->get('Version'), //* Version that appears at the top of your panel
    'menu_type' => 'menu', //* Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu' => true, //* Show the sections below the admin menu item or not
    'menu_title' => esc_html__('Theme Options', 'reuss'),
    'page_title' => esc_html__('Theme Options', 'reuss'),
    'google_api_key' => '', //* You will need to generate a Google API key to use this feature. Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_update_weekly' => false, //* Set it you want google fonts to update weekly. A google_api_key value is required.
    'async_typography' => true, //* Must be defined to add google fonts to the typography module
    'admin_bar' => true, //* Show the panel pages on the admin bar
    'admin_bar_icon' => 'dashicons-admin-generic', //* Choose an icon for the admin bar menu
    'admin_bar_priority' => 50, //* Choose an priority for the admin bar menu
    'global_variable' => '', //* Set a different name for your global variable other than the opt_name
    'dev_mode' => false,
    'update_notice' => true, //* If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer' => true,
    'page_priority' => 3, //* Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent' => 'wgl-dashboard-panel', //* For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions' => 'manage_options', //* Permissions needed to access the options panel.
    'menu_icon' => 'dashicons-admin-generic', //* Specify a custom URL to an icon
    'last_tab' => '', //* Force your panel to always open to a specific tab (by id)
    'page_icon' => 'icon-themes', //* Icon displayed in the admin panel next to your menu_title
    'page_slug' => 'wgl-theme-options-panel', //* Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults' => true, //* On load save the defaults to DB before user clicks save or not
    'default_show' => false, //* If true, shows the default value next to each field that is not the default value.
    'default_mark' => '', //* What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export' => true, //* Shows the Import/Export panel when not used as a field.
    'transient_time' => 60 * MINUTE_IN_SECONDS, //* Show the time the page took to load, etc
    'output' => true, //* Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag' => true, //* FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database' => '', //* possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn' => true,
];


Redux::setArgs($theme_slug, $args);

//* START Basic Fields
Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('General', 'reuss'),
        'id' => 'general',
        'icon' => 'el el-cog',
        'fields' => [
            [
                'id' => 'use_minify',
                'type' => 'switch',
                'title' => esc_html__('Use minify css/js files', 'reuss'),
                'desc' => esc_html__('Recommended for site load speed.', 'reuss'),
            ],
            [
                'id' => 'preloder_settings',
                'type' => 'section',
                'title' => esc_html__('Preloader Settings', 'reuss'),
                'indent' => true,
            ],
            [
                'id' => 'preloader',
                'type' => 'switch',
                'title' => esc_html__('Preloader On/Off', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'preloader_background',
                'type' => 'color',
                'title' => esc_html__('Preloader Background', 'reuss'),
                'default' => '#ffffff',
                'transparent' => false,
                'required' => ['preloader', '=', '1'],
            ],
            [
                'id' => 'preloader_color_1',
                'type' => 'color',
                'title' => esc_html__('Preloader Color', 'reuss'),
                'default' => '#ff7268',
                'transparent' => false,
                'required' => ['preloader', '=', '1'],
            ],
            [
                'id' => 'preloader_color_2',
                'type' => 'color',
                'title' => esc_html__('Preloader Color', 'reuss'),
                'default' => '#8e6de2',
                'transparent' => false,
                'required' => ['preloader', '=', '1'],
            ],
            [
                'id' => 'preloader_color_3',
                'type' => 'color',
                'title' => esc_html__('Preloader Color', 'reuss'),
                'default' => '#1fe8f5',
                'transparent' => false,
                'required' => ['preloader', '=', '1'],
            ],
            [
                'id' => 'preloader_settings-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'search_settings',
                'type' => 'section',
                'title' => esc_html__('Search Settings', 'reuss'),
                'indent' => true,
            ],
            [
                'id' => 'search_style',
                'type' => 'button_set',
                'title' => esc_html__('Choose search style', 'reuss'),
                'options' => [
                    'standard' => esc_html__('Standard', 'reuss'),
                    'alt' => esc_html__('Full Page Width', 'reuss'),
                ],
                'default' => 'standard',
            ],
            [
                'id' => 'search_settings-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'scroll_up_settings',
                'type' => 'section',
                'title' => esc_html__('Scroll Up Button Settings', 'reuss'),
                'indent' => true,
            ],
            [
                'id' => 'scroll_up',
                'type' => 'switch',
                'title' => esc_html__('Button', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Disable', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'scroll_up_gradient_switch',
                'type' => 'switch',
                'title' => esc_html__('Appearance', 'reuss'),
                'on' => esc_html__('Gradient', 'reuss'),
                'off' => esc_html__('Color', 'reuss'),
                'default' => true,
                'required' => ['scroll_up', '=', true],
            ],
            [
                'id' => 'scroll_up_arrow_color',
                'type' => 'color',
                'title' => esc_html__('Icon Color', 'reuss'),
                'default' => '#ffffff',
                'transparent' => false,
                'required' => ['scroll_up', '=', true],
            ],
            [
                'id' => 'scroll_up_bg_color',
                'type' => 'color',
                'title' => esc_html__('Background Color', 'reuss'),
                'default' => '#ff7268',
                'transparent' => false,
                'required' => ['scroll_up_gradient_switch', '=', false],
            ],
            [
                'id'       => 'scroll_up_bg_gradient',
                'type'     => 'color_gradient',
                'title'    => esc_html__('Button Gradient', 'reuss' ),
                'validate' => 'color',
                'default'  => [
                    'from' => '#ff7268',
                    'to'   => '#ffb06c',
                ],
                'required' => [ 'scroll_up_gradient_switch', '=', true ],
            ],
            [
                'id' => 'scroll_up_settings-end',
                'type' => 'section',
                'indent' => false,
            ],
        ],
    ]
);

Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Custom JS', 'reuss'),
        'id' => 'editors-option',
        'subsection' => true,
        'fields' => [
            [
                'id' => 'custom_js',
                'type' => 'ace_editor',
                'title' => esc_html__('Custom JS', 'reuss'),
                'subtitle' => esc_html__('Paste your JS code here.', 'reuss'),
                'mode' => 'javascript',
                'theme' => 'chrome',
                'default' => ''
            ],
            [
                'id' => 'header_custom_js',
                'type' => 'ace_editor',
                'title' => esc_html__('Custom JS', 'reuss'),
                'subtitle' => esc_html__('Code to be added inside HEAD tag', 'reuss'),
                'mode' => 'html',
                'theme' => 'chrome',
                'default' => ''
            ],
        ],
    ]
);

//* START Basic Fields
Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Header', 'reuss'),
        'id' => 'header_section',
    ]
);

Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Logo', 'reuss'),
        'id' => 'logo',
        'subsection' => true,
        'fields' => [
            [
                'id' => 'header_logo',
                'type' => 'media',
                'title' => esc_html__('Header Logo', 'reuss'),
            ],
            [
                'id' => 'logo_height_custom',
                'type' => 'switch',
                'title' => esc_html__('Enable Logo Height', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'logo_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Logo Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => 100],
                'required' => ['logo_height_custom', '=', '1'],
            ],
            [
                'id' => 'logo_sticky',
                'type' => 'media',
                'title' => esc_html__('Sticky Logo', 'reuss'),
            ],
            [
                'id' => 'sticky_logo_height_custom',
                'type' => 'switch',
                'title' => esc_html__('Enable Sticky Logo Height', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'sticky_logo_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Sticky Logo Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => ''],
                'required' => [
                    ['sticky_logo_height_custom', '=', '1'],
                ],
            ],
            [
                'id' => 'logo_mobile',
                'type' => 'media',
                'title' => esc_html__('Mobile Logo', 'reuss'),
            ],
            [
                'id' => 'mobile_logo_height_custom',
                'type' => 'switch',
                'title' => esc_html__('Enable Mobile Logo Height', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'mobile_logo_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Mobile Logo Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => ''],
                'required' => [
                    ['mobile_logo_height_custom', '=', '1'],
                ],
            ],
            [
                'id' => 'logo_mobile_menu',
                'type' => 'media',
                'title' => esc_html__('Mobile Menu Logo', 'reuss'),
            ],
            [
                'id' => 'mobile_logo_menu_height_custom',
                'type' => 'switch',
                'title' => esc_html__('Enable Mobile Menu Logo Height', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'mobile_logo_menu_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Mobile Menu Logo Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => ''],
                'required' => [
                    ['mobile_logo_menu_height_custom', '=', '1'],
                ],
            ],
        ]
    ]
);

$header_builder_items = [
    'default' => [
        'html1' => ['title' => esc_html__('HTML 1', 'reuss'), 'settings' => true],
        'html2' => ['title' => esc_html__('HTML 2', 'reuss'), 'settings' => true],
        'html3' => ['title' => esc_html__('HTML 3', 'reuss'), 'settings' => true],
        'html4' => ['title' => esc_html__('HTML 4', 'reuss'), 'settings' => true],
        'html5' => ['title' => esc_html__('HTML 5', 'reuss'), 'settings' => true],
        'html6' => ['title' => esc_html__('HTML 6', 'reuss'), 'settings' => true],
        'html7' => ['title' => esc_html__('HTML 7', 'reuss'), 'settings' => true],
        'html8' => ['title' => esc_html__('HTML 8', 'reuss'), 'settings' => true],
        'delimiter1' => ['title' => esc_html__('|', 'reuss'), 'settings' => true],
        'delimiter2' => ['title' => esc_html__('|', 'reuss'), 'settings' => true],
        'delimiter3' => ['title' => esc_html__('|', 'reuss'), 'settings' => true],
        'delimiter4' => ['title' => esc_html__('|', 'reuss'), 'settings' => true],
        'delimiter5' => ['title' => esc_html__('|', 'reuss'), 'settings' => true],
        'delimiter6' => ['title' => esc_html__('|', 'reuss'), 'settings' => true],
        'spacer1' => ['title' => esc_html__('Spacer 1', 'reuss'), 'settings' => true],
        'spacer2' => ['title' => esc_html__('Spacer 2', 'reuss'), 'settings' => true],
        'spacer3' => ['title' => esc_html__('Spacer 3', 'reuss'), 'settings' => true],
        'spacer4' => ['title' => esc_html__('Spacer 4', 'reuss'), 'settings' => true],
        'spacer5' => ['title' => esc_html__('Spacer 5', 'reuss'), 'settings' => true],
        'spacer6' => ['title' => esc_html__('Spacer 6', 'reuss'), 'settings' => true],
        'spacer7' => ['title' => esc_html__('Spacer 7', 'reuss'), 'settings' => true],
        'spacer8' => ['title' => esc_html__('Spacer 8', 'reuss'), 'settings' => true],
        'button1' => ['title' => esc_html__('Button', 'reuss'), 'settings' => true],
        'button2' => ['title' => esc_html__('Button', 'reuss'), 'settings' => true],
        'wpml' => ['title' => esc_html__('WPML', 'reuss'), 'settings' => false],
        'cart' => ['title' => esc_html__('Cart', 'reuss'), 'settings' => true],
        'login' => ['title' => esc_html__('Login', 'reuss'), 'settings' => false],
        'side_panel' => ['title' => esc_html__('Side Panel', 'reuss'), 'settings' => true],
    ],
    'mobile' => [
        'html1' => esc_html__('HTML 1', 'reuss'),
        'html2' => esc_html__('HTML 2', 'reuss'),
        'html3' => esc_html__('HTML 3', 'reuss'),
        'html4' => esc_html__('HTML 4', 'reuss'),
        'html5' => esc_html__('HTML 5', 'reuss'),
        'html6' => esc_html__('HTML 6', 'reuss'),
        'spacer1' => esc_html__('Spacer 1', 'reuss'),
        'spacer2' => esc_html__('Spacer 2', 'reuss'),
        'spacer3' => esc_html__('Spacer 3', 'reuss'),
        'spacer4' => esc_html__('Spacer 4', 'reuss'),
        'spacer5' => esc_html__('Spacer 5', 'reuss'),
        'spacer6' => esc_html__('Spacer 6', 'reuss'),
        'side_panel' => esc_html__('Side Panel', 'reuss'),
        'wpml' => esc_html__('WPML', 'reuss'),
        'cart' => esc_html__('Cart', 'reuss'),
        'login' => esc_html__('Login', 'reuss'),
    ],
    'mobile_drawer' => [
        'html1' => esc_html__('HTML 1', 'reuss'),
        'html2' => esc_html__('HTML 2', 'reuss'),
        'html3' => esc_html__('HTML 3', 'reuss'),
        'html4' => esc_html__('HTML 4', 'reuss'),
        'html5' => esc_html__('HTML 5', 'reuss'),
        'html6' => esc_html__('HTML 6', 'reuss'),
        'wpml' => esc_html__('WPML', 'reuss'),
        'spacer1' => esc_html__('Spacer 1', 'reuss'),
        'spacer2' => esc_html__('Spacer 2', 'reuss'),
        'spacer3' => esc_html__('Spacer 3', 'reuss'),
        'spacer4' => esc_html__('Spacer 4', 'reuss'),
        'spacer5' => esc_html__('Spacer 5', 'reuss'),
        'spacer6' => esc_html__('Spacer 6', 'reuss'),
    ],
];

Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Header Builder', 'reuss'),
        'id' => 'header-customize',
        'subsection' => true,
        'fields' => [
            [
                'id' => 'header_switch',
                'title' => esc_html__('Header', 'reuss'),
                'type' => 'switch',
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Disable', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'header_type',
                'type' => 'select',
                'title' => esc_html__('Layout Building Tool', 'reuss'),
                'desc' => esc_html__('Custom Builder allows create templates within Elementor environment.', 'reuss'),
                'options' => [
                    'default' => esc_html__('Default Builder', 'reuss'),
                    'custom' => esc_html__('Custom Builder ( Recommended )', 'reuss')
                ],
                'default' => 'default',
                'required' => ['header_switch', '=', '1'],
            ],
            [
                'id' => 'header_page_select',
                'type' => 'select',
                'title' => esc_html__('Header Template', 'reuss'),
                'data' => 'posts',
                'desc' => sprintf(
                    '%s <a href="%s" target="_blank">%s</a> %s',
                    esc_html__('Selected Template will be used for all pages by default. You can edit/create Header Template in the', 'reuss'),
                    admin_url('edit.php?post_type=header'),
                    esc_html__('Header Templates', 'reuss'),
                    esc_html__('dashboard tab.', 'reuss')
                ),
                'args' => [
                    'post_type' => 'header',
                    'posts_per_page' => -1,
                    'orderby' => 'title',
                    'order' => 'ASC',
                ],
                'required' => ['header_type', '=', 'custom'],
            ],
            [
                'id' => 'bottom_header_layout',
                'type' => 'custom_header_builder',
                'title' => esc_html__('Header Builder', 'reuss'),
                'compiler' => 'true',
                'full_width' => true,
                'options' => [
                    'items' => $header_builder_items['default'],
                    'Top Left area' => [],
                    'Top Center area' => [],
                    'Top Right area' => [],
                    'Middle Left area' => [
                        'spacer1' => ['title' => esc_html__('Spacer 1', 'reuss'), 'settings' => true],
                        'logo' => ['title' => esc_html__('Logo', 'reuss'), 'settings' => false],
                    ],
                    'Middle Center area' => [
                        'menu' => ['title' => esc_html__('Menu', 'reuss'), 'settings' => false],
                    ],
                    'Middle Right area' => [
                        'html1' => ['title' => esc_html__('HTML 1', 'reuss'), 'settings' => true],
                        'delimiter1' => ['title' => esc_html__('|', 'reuss'), 'settings' => true],
                        'item_search' => ['title' => esc_html__('Search', 'reuss'), 'settings' => true],
                        'spacer2' => ['title' => esc_html__('Spacer 2', 'reuss'), 'settings' => true],
                    ],
                    'Bottom Left area' => [],
                    'Bottom Center area' => [],
                    'Bottom Right area' => [],
                ],
                'default' => [
                    'items' => $header_builder_items['default'],
                    'Top Left area' => [],
                    'Top Center area' => [],
                    'Top Right area' => [],
                    'Middle Left area' => [
                        'spacer1' => ['title' => esc_html__('Spacer 1', 'reuss'), 'settings' => true],
                        'logo' => ['title' => esc_html__('Logo', 'reuss'), 'settings' => false],
                    ],
                    'Middle Center area' => [
                        'menu' => ['title' => esc_html__('Menu', 'reuss'), 'settings' => false],
                    ],
                    'Middle Right area' => [
                        'html1' => ['title' => esc_html__('HTML 1', 'reuss'), 'settings' => true],
                        'delimiter1' => ['title' => esc_html__('|', 'reuss'), 'settings' => true],
                        'item_search' => ['title' => esc_html__('Search', 'reuss'), 'settings' => true],
                        'spacer2' => ['title' => esc_html__('Spacer 2', 'reuss'), 'settings' => true],
                    ],
                    'Bottom Left area' => [],
                    'Bottom Center area' => [],
                    'Bottom Right area' => [],
                ],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_spacer1',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Header Spacer 1 Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 20],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_spacer2',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Header Spacer 2 Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 20],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_spacer3',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Header Spacer 3 Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 25],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_spacer4',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Header Spacer 4 Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 25],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_spacer5',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Header Spacer 5 Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 25],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_spacer6',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Header Spacer 6 Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 25],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_spacer7',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Header Spacer 7 Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 25],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_spacer8',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Header Spacer 8 Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 25],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_item_search_custom',
                'type' => 'switch',
                'title' => esc_html__('Customize Search', 'reuss'),
                'default' => false,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_item_search_color_txt',
                'type' => 'color_rgba',
                'title' => esc_html__('Icon Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(33,33,33,1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_item_search_custom', '=', '1'],
            ],
            [
                'id' => 'bottom_header_item_search_hover_color_txt',
                'type' => 'color_rgba',
                'title' => esc_html__('Hover Icon Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(33,33,33, 1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_item_search_custom', '=', '1'],
            ],
            [
                'id' => 'bottom_header_item_search_custom_sticky',
                'type' => 'switch',
                'title' => esc_html__('Customize Sticky Search', 'reuss'),
                'default' => false,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_item_search_color_txt_sticky',
                'type' => 'color_rgba',
                'title' => esc_html__('Sticky Icon Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(33,33,33,1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_item_search_custom_sticky', '=', '1'],
            ],
            [
                'id' => 'bottom_header_item_search_hover_color_txt_sticky',
                'type' => 'color_rgba',
                'title' => esc_html__('Sticky Hover Icon Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(33,33,33, 1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_item_search_custom_sticky', '=', '1'],
            ],
            [
                'id' => 'bottom_header_cart_custom',
                'type' => 'switch',
                'title' => esc_html__('Customize cart', 'reuss'),
                'default' => false,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_cart_color_txt',
                'type' => 'color_rgba',
                'title' => esc_html__('Icon Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(33,33,33,1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_cart_custom', '=', '1'],
            ],
            [
                'id' => 'bottom_header_cart_hover_color_txt',
                'type' => 'color_rgba',
                'title' => esc_html__('Hover Icon Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(33,33,33, 1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_cart_custom', '=', '1'],
            ],
            [
                'id' => 'bottom_header_cart_custom_sticky',
                'type' => 'switch',
                'title' => esc_html__('Customize Sticky cart', 'reuss'),
                'default' => false,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_cart_color_txt_sticky',
                'type' => 'color_rgba',
                'title' => esc_html__('Sticky Icon Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(33,33,33,1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_cart_custom_sticky', '=', '1'],
            ],
            [
                'id' => 'bottom_header_cart_hover_color_txt_sticky',
                'type' => 'color_rgba',
                'title' => esc_html__('Sticky Hover Icon Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(33,33,33, 1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_cart_custom_sticky', '=', '1'],
            ],
            [
                'id' => 'bottom_header_delimiter1_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Delimiter Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => 50],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter1_width',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Delimiter Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 1],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter1_bg',
                'type' => 'color_rgba',
                'title' => esc_html__('Delimiter Background', 'reuss'),
                'default' => [
                    'color' => '#000000',
                    'alpha' => '0.1',
                    'rgba' => 'rgba(0, 0, 0, 0.1)'
                ],
                'mode' => 'background',
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter1_margin',
                'type' => 'spacing',
                'mode' => 'margin',
                'all' => false,
                'bottom' => false,
                'top' => false,
                'left' => true,
                'right' => true,
                'title' => esc_html__('Delimiter Spacing', 'reuss'),
                'default' => [
                    'margin-left' => '20',
                    'margin-right' => '30',
                ],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter1_sticky_custom',
                'type' => 'switch',
                'title' => esc_html__('Customize Sticky Delimiter', 'reuss'),
                'default' => false,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter1_sticky_color',
                'type' => 'color_rgba',
                'title' => esc_html__('Delimiter Background', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,1)'
                ],
                'mode' => 'background',
                'required' => [
                    ['bottom_header_delimiter1_sticky_custom', '=', '1'],
                ],
            ],
            [
                'id' => 'bottom_header_delimiter1_sticky_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Delimiter Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => 100],
                'required' => [
                    ['bottom_header_delimiter1_sticky_custom', '=', '1'],
                ],
            ],
            [
                'id' => 'bottom_header_delimiter2_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Delimiter Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => 100],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter2_width',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Delimiter Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 1],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter2_bg',
                'type' => 'color_rgba',
                'title' => esc_html__('Delimiter Background', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '.9',
                    'rgba' => 'rgba(255,255,255,0.9)'
                ],
                'mode' => 'background',
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter2_margin',
                'type' => 'spacing',
                'mode' => 'margin',
                'all' => false,
                'bottom' => false,
                'top' => false,
                'left' => true,
                'right' => true,
                'title' => esc_html__('Delimiter Spacing', 'reuss'),
                'default' => [
                    'margin-left' => '30',
                    'margin-right' => '30',
                ],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter2_sticky_custom',
                'type' => 'switch',
                'title' => esc_html__('Customize Sticky Delimiter', 'reuss'),
                'default' => false,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter2_sticky_color',
                'type' => 'color_rgba',
                'title' => esc_html__('Delimiter Background', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,1)'
                ],
                'mode' => 'background',
                'required' => [
                    ['bottom_header_delimiter2_sticky_custom', '=', '1'],
                ],
            ],
            [
                'id' => 'bottom_header_delimiter2_sticky_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Delimiter Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => 100],
                'required' => [
                    ['bottom_header_delimiter2_sticky_custom', '=', '1'],
                ],
            ],
            [
                'id' => 'bottom_header_delimiter3_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Delimiter Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => 100],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter3_width',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Delimiter Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 1],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter3_bg',
                'type' => 'color_rgba',
                'title' => esc_html__('Delimiter Background', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '.9',
                    'rgba' => 'rgba(255,255,255,0.9)'
                ],
                'mode' => 'background',
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter3_margin',
                'type' => 'spacing',
                'mode' => 'margin',
                'all' => false,
                'bottom' => false,
                'top' => false,
                'left' => true,
                'right' => true,
                'title' => esc_html__('Delimiter Spacing', 'reuss'),
                'default' => [
                    'margin-left' => '30',
                    'margin-right' => '30',
                ],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter3_sticky_custom',
                'type' => 'switch',
                'title' => esc_html__('Customize Sticky Delimiter', 'reuss'),
                'default' => false,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter3_sticky_color',
                'type' => 'color_rgba',
                'title' => esc_html__('Delimiter Background', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_delimiter3_sticky_custom', '=', '1'],
            ],
            [
                'id' => 'bottom_header_delimiter3_sticky_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Delimiter Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => 100],
                'required' => [
                    ['bottom_header_delimiter3_sticky_custom', '=', '1'],
                ],
            ],
            [
                'id' => 'bottom_header_delimiter4_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Delimiter Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => 100],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter4_width',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Delimiter Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 1],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter4_bg',
                'type' => 'color_rgba',
                'title' => esc_html__('Delimiter Background', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '.9',
                    'rgba' => 'rgba(255,255,255,0.9)'
                ],
                'mode' => 'background',
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter4_margin',
                'type' => 'spacing',
                'mode' => 'margin',
                'all' => false,
                'bottom' => false,
                'top' => false,
                'left' => true,
                'right' => true,
                'title' => esc_html__('Delimiter Spacing', 'reuss'),
                'default' => [
                    'margin-left' => '30',
                    'margin-right' => '30',
                ],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter4_sticky_custom',
                'type' => 'switch',
                'title' => esc_html__('Customize Sticky Delimiter', 'reuss'),
                'default' => false,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter4_sticky_color',
                'type' => 'color_rgba',
                'title' => esc_html__('Delimiter Background', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,1)'
                ],
                'mode' => 'background',
                'required' => [
                    ['bottom_header_delimiter4_sticky_custom', '=', '1'],
                ],
            ],
            [
                'id' => 'bottom_header_delimiter4_sticky_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Delimiter Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => 100],
                'required' => [
                    ['bottom_header_delimiter4_sticky_custom', '=', '1'],
                ],
            ],
            [
                'id' => 'bottom_header_delimiter5_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Delimiter Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => 100],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter5_width',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Delimiter Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 1],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter5_bg',
                'type' => 'color_rgba',
                'title' => esc_html__('Delimiter Background', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '.9',
                    'rgba' => 'rgba(255,255,255,0.9)'
                ],
                'mode' => 'background',
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter5_margin',
                'type' => 'spacing',
                'mode' => 'margin',
                'all' => false,
                'bottom' => false,
                'top' => false,
                'left' => true,
                'right' => true,
                'title' => esc_html__('Delimiter Spacing', 'reuss'),
                'default' => [
                    'margin-left' => '30',
                    'margin-right' => '30',
                ],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter5_sticky_custom',
                'type' => 'switch',
                'title' => esc_html__('Customize Sticky Delimiter', 'reuss'),
                'default' => false,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter5_sticky_color',
                'type' => 'color_rgba',
                'title' => esc_html__('Delimiter Background', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,1)'
                ],
                'mode' => 'background',
                'required' => [
                    ['bottom_header_delimiter5_sticky_custom', '=', '1'],
                ],
            ],
            [
                'id' => 'bottom_header_delimiter5_sticky_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Delimiter Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => 100],
                'required' => [
                    ['bottom_header_delimiter5_sticky_custom', '=', '1'],
                ],
            ],
            [
                'id' => 'bottom_header_delimiter6_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Delimiter Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => 100],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter6_width',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Delimiter Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 1],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter6_bg',
                'type' => 'color_rgba',
                'title' => esc_html__('Delimiter Background', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '.9',
                    'rgba' => 'rgba(255,255,255,0.9)'
                ],
                'mode' => 'background',
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter6_margin',
                'type' => 'spacing',
                'mode' => 'margin',
                'all' => false,
                'bottom' => false,
                'top' => false,
                'left' => true,
                'right' => true,
                'title' => esc_html__('Delimiter Spacing', 'reuss'),
                'default' => [
                    'margin-left' => '30',
                    'margin-right' => '30',
                ],
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter6_sticky_custom',
                'type' => 'switch',
                'title' => esc_html__('Customize Sticky Delimiter', 'reuss'),
                'default' => false,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_delimiter6_sticky_color',
                'type' => 'color_rgba',
                'title' => esc_html__('Delimiter Background', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_delimiter6_sticky_custom', '=', '1'],
            ],
            [
                'id' => 'bottom_header_delimiter6_sticky_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Delimiter Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => 100],
                'required' => ['bottom_header_delimiter6_sticky_custom', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button1_title',
                'type' => 'text',
                'title' => esc_html__('Button Text', 'reuss'),
                'default' => esc_html__('Get Ticket', 'reuss'),
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_button1_link',
                'type' => 'text',
                'title' => esc_html__('Link', 'reuss'),
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_button1_target',
                'type' => 'switch',
                'title' => esc_html__('Open link in a new tab', 'reuss'),
                'default' => true,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_button1_size',
                'type' => 'select',
                'title' => esc_html__('Button Size', 'reuss'),
                'options' => [
                    's' => esc_html__('Small', 'reuss'),
                    'm' => esc_html__('Medium', 'reuss'),
                    'l' => esc_html__('Large', 'reuss'),
                    'xl' => esc_html__('Extra Large', 'reuss'),
                ],
                'default' => 's',
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_button1_radius',
                'type' => 'text',
                'title' => esc_html__('Button Border Radius', 'reuss'),
                'default' => '0',
                'desc' => esc_html__('Value in pixels.', 'reuss'),
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_button1_custom',
                'type' => 'switch',
                'title' => esc_html__('Customize Button', 'reuss'),
                'default' => false,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_button1_color_txt',
                'type' => 'color_rgba',
                'title' => esc_html__('Text Color', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button1_custom', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button1_hover_color_txt',
                'type' => 'color_rgba',
                'title' => esc_html__('Hover Text Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(28,28,37, 1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button1_custom', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button1_bg',
                'type' => 'color_rgba',
                'title' => esc_html__('Background Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(28,28,37, 1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button1_custom', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button1_hover_bg',
                'type' => 'color_rgba',
                'title' => esc_html__('Hover Background Color', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button1_custom', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button1_border',
                'type' => 'color_rgba',
                'title' => esc_html__('Border Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(28,28,37, 1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button1_custom', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button1_hover_border',
                'type' => 'color_rgba',
                'title' => esc_html__('Hover Border Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(28,28,37, 1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button1_custom', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button1_custom_sticky',
                'type' => 'switch',
                'title' => esc_html__('Customize Sticky Button', 'reuss'),
                'default' => false,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_button1_color_txt_sticky',
                'type' => 'color_rgba',
                'title' => esc_html__('Sticky Text Color', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button1_custom_sticky', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button1_hover_color_txt_sticky',
                'type' => 'color_rgba',
                'title' => esc_html__('Sticky Hover Text Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(28,28,37, 1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button1_custom_sticky', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button1_bg_sticky',
                'type' => 'color_rgba',
                'title' => esc_html__('Sticky Background Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(28,28,37, 1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button1_custom_sticky', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button1_hover_bg_sticky',
                'type' => 'color_rgba',
                'title' => esc_html__('Sticky Hover Background Color', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button1_custom_sticky', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button1_border_sticky',
                'type' => 'color_rgba',
                'title' => esc_html__('Sticky Border Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(28,28,37, 1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button1_custom_sticky', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button1_hover_border_sticky',
                'type' => 'color_rgba',
                'title' => esc_html__('Sticky Hover Border Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(28,28,37, 1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button1_custom_sticky', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button2_title',
                'type' => 'text',
                'title' => esc_html__('Button Text', 'reuss'),
                'default' => esc_html__('Get Ticket', 'reuss'),
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_button2_link',
                'type' => 'text',
                'title' => esc_html__('Link', 'reuss'),
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_button2_target',
                'type' => 'switch',
                'title' => esc_html__('Open link in a new tab', 'reuss'),
                'default' => true,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_button2_size',
                'type' => 'select',
                'title' => esc_html__('Button Size', 'reuss'),
                'options' => [
                    's' => esc_html__('Small', 'reuss'),
                    'm' => esc_html__('Medium', 'reuss'),
                    'l' => esc_html__('Large', 'reuss'),
                    'xl' => esc_html__('Extra Large', 'reuss'),
                ],
                'default' => 'm',
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_button2_radius',
                'type' => 'text',
                'title' => esc_html__('Button Border Radius', 'reuss'),
                'default' => '0',
                'desc' => esc_html__('Value in pixels.', 'reuss'),
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_button2_custom',
                'type' => 'switch',
                'title' => esc_html__('Customize Button', 'reuss'),
                'default' => false,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_button2_color_txt',
                'type' => 'color_rgba',
                'title' => esc_html__('Text Color', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button2_custom', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button2_hover_color_txt',
                'type' => 'color_rgba',
                'title' => esc_html__('Hover Text Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(28,28,37, 1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button2_custom', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button2_bg',
                'type' => 'color_rgba',
                'title' => esc_html__('Background Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(28,28,37, 1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button2_custom', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button2_hover_bg',
                'type' => 'color_rgba',
                'title' => esc_html__('Hover Background Color', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button2_custom', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button2_border',
                'type' => 'color_rgba',
                'title' => esc_html__('Border Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(28,28,37, 1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button2_custom', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button2_hover_border',
                'type' => 'color_rgba',
                'title' => esc_html__('Hover Border Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(28,28,37, 1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button2_custom', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button2_custom_sticky',
                'type' => 'switch',
                'title' => esc_html__('Customize Sticky Button', 'reuss'),
                'default' => false,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_button2_color_txt_sticky',
                'type' => 'color_rgba',
                'title' => esc_html__('Sticky Text Color', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button2_custom_sticky', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button2_hover_color_txt_sticky',
                'type' => 'color_rgba',
                'title' => esc_html__('Sticky Hover Text Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(28,28,37, 1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button2_custom_sticky', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button2_bg_sticky',
                'type' => 'color_rgba',
                'title' => esc_html__('Sticky Background Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(28,28,37, 1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button2_custom_sticky', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button2_hover_bg_sticky',
                'type' => 'color_rgba',
                'title' => esc_html__('Sticky Hover Background Color', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button2_custom_sticky', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button2_border_sticky',
                'type' => 'color_rgba',
                'title' => esc_html__('Sticky Border Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(28,28,37, 1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button2_custom_sticky', '=', '1'],
            ],
            [
                'id' => 'bottom_header_button2_hover_border_sticky',
                'type' => 'color_rgba',
                'title' => esc_html__('Sticky Hover Border Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(28,28,37, 1)'
                ],
                'mode' => 'background',
                'required' => ['bottom_header_button2_custom_sticky', '=', '1'],
            ],
            [
                'id' => 'bottom_header_bar_html1_editor',
                'type' => 'ace_editor',
                'mode' => 'html',
                'title' => esc_html__('HTML Element 1 Editor', 'reuss'),
                'default' => '',
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_bar_html2_editor',
                'type' => 'ace_editor',
                'mode' => 'html',
                'title' => esc_html__('HTML Element 2 Editor', 'reuss'),
                'default' => '',
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_bar_html3_editor',
                'type' => 'ace_editor',
                'mode' => 'html',
                'title' => esc_html__('HTML Element 3 Editor', 'reuss'),
                'default' => '',
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_bar_html4_editor',
                'type' => 'ace_editor',
                'mode' => 'html',
                'title' => esc_html__('HTML Element 4 Editor', 'reuss'),
                'default' => '',
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_bar_html5_editor',
                'type' => 'ace_editor',
                'mode' => 'html',
                'title' => esc_html__('HTML Element 5 Editor', 'reuss'),
                'default' => '',
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_bar_html6_editor',
                'type' => 'ace_editor',
                'mode' => 'html',
                'title' => esc_html__('HTML Element 6 Editor', 'reuss'),
                'default' => '',
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_bar_html7_editor',
                'type' => 'ace_editor',
                'mode' => 'html',
                'title' => esc_html__('HTML Element 7 Editor', 'reuss'),
                'default' => '',
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_bar_html8_editor',
                'type' => 'ace_editor',
                'mode' => 'html',
                'title' => esc_html__('HTML Element 8 Editor', 'reuss'),
                'default' => '',
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_side_panel_color',
                'type' => 'color_rgba',
                'title' => esc_html__('Icon Color', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,1)'
                ],
                'mode' => 'background',
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_side_panel_background',
                'type' => 'color_rgba',
                'title' => esc_html__('Background Icon', 'reuss'),
                'default' => [
                    'color' => '#ff7268',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,114,104, 1)'
                ],
                'mode' => 'background',
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_side_panel_sticky_custom',
                'type' => 'switch',
                'title' => esc_html__('Customize Sticky Icon', 'reuss'),
                'default' => false,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'bottom_header_side_panel_sticky_color',
                'type' => 'color_rgba',
                'title' => esc_html__('Icon Color', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,1)'
                ],
                'mode' => 'background',
                'required' => [
                    ['bottom_header_side_panel_sticky_custom', '=', '1']
                ],
            ],
            [
                'id' => 'bottom_header_side_panel_sticky_background',
                'type' => 'color_rgba',
                'title' => esc_html__('Background Icon', 'reuss'),
                'default' => [
                    'color' => '#ff7268',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,114,104, 1)'
                ],
                'mode' => 'background',
                'required' => [
                    ['bottom_header_side_panel_sticky_custom', '=', '1']
                ],
            ],
            [
                'id' => 'header_top-start',
                'type' => 'section',
                'title' => esc_html__('Header Top Options', 'reuss'),
                'indent' => true,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'header_top_full_width',
                'type' => 'switch',
                'title' => esc_html__('Full Width Header', 'reuss'),
                'subtitle' => esc_html__('Set header content in full width', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'header_top_max_width_custom',
                'type' => 'switch',
                'title' => esc_html__('Customize Max Width Container', 'reuss'),
                'subtitle' => esc_html__('Set max width container', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'header_top_max_width',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Max Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => [
                    'width' => 1290,
                ],
                'required' => ['header_top_max_width_custom', '=', '1'],
            ],
            [
                'id' => 'header_top_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Header Top Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => 40]
            ],
            [
                'id' => 'header_top_background_image',
                'type' => 'media',
                'title' => esc_html__('Header Top Background Image', 'reuss'),
            ],
            [
                'id' => 'header_top_background',
                'type' => 'color_rgba',
                'title' => esc_html__('Header Top Background', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '.9',
                    'rgba' => 'rgba(255,255,255,0.9)'
                ],
                'mode' => 'background',
            ],
            [
                'id' => 'header_top_color',
                'type' => 'color_rgba',
                'title' => esc_html__('Header Top Text Color', 'reuss'),
                'default' => [
                    'color' => '#fefefe',
                    'alpha' => '.5',
                    'rgba' => 'rgba(254,254,254,0.5)'
                ],
                'mode' => 'background',
            ],
            [
                'id' => 'header_top_bottom_border',
                'type' => 'switch',
                'title' => esc_html__('Set Header Top Bottom Border', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'header_top_border_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Header Top Border Width', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => [
                    'height' => '1',
                ],
                'required' => [
                    ['header_top_bottom_border', '=', '1']
                ],
            ],
            [
                'id' => 'header_top_bottom_border_color',
                'type' => 'color_rgba',
                'title' => esc_html__('Header Top Border Color', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,0.2)'
                ],
                'mode' => 'background',
                'required' => [
                    ['header_top_bottom_border', '=', '1'],
                ],
            ],
            [
                'id' => 'header_top-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'header_middle-start',
                'type' => 'section',
                'title' => esc_html__('Header Middle Options', 'reuss'),
                'indent' => true,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'header_middle_full_width',
                'type' => 'switch',
                'title' => esc_html__('Full Width Middle Header', 'reuss'),
                'subtitle' => esc_html__('Set header content in full width', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'header_middle_max_width_custom',
                'type' => 'switch',
                'title' => esc_html__('Customize Max Width Container', 'reuss'),
                'subtitle' => esc_html__('Set max width container', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'header_middle_max_width',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Max Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 1290],
                'required' => ['header_middle_max_width_custom', '=', '1'],
            ],
            [
                'id' => 'header_middle_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Header Middle Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => 110]
            ],
            [
                'id' => 'header_middle_background_image',
                'type' => 'media',
                'title' => esc_html__('Header Middle Background Image', 'reuss'),
            ],
            [
                'id' => 'header_middle_background',
                'type' => 'color_rgba',
                'title' => esc_html__('Header Middle Background', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,1)'
                ],
                'mode' => 'background',
            ],
            [
                'id' => 'header_middle_color',
                'type' => 'color_rgba',
                'title' => esc_html__('Header Middle Text Color', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(33,33,33,1)'
                ],
                'mode' => 'background',
            ],
            [
                'id' => 'header_middle_bottom_border',
                'type' => 'switch',
                'title' => esc_html__('Set Header Middle Bottom Border', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'header_middle_border_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Header Middle Border Width', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => '1'],
                'required' => [
                    ['header_middle_bottom_border', '=', '1']
                ],
            ],
            [
                'id' => 'header_middle_bottom_border_color',
                'type' => 'color_rgba',
                'title' => esc_html__('Header Middle Border Color', 'reuss'),
                'default' => [
                    'color' => '#f5f5f5',
                    'alpha' => '1',
                    'rgba' => 'rgba(245,245,245,1)'
                ],
                'mode' => 'background',
                'required' => [
                    ['header_middle_bottom_border', '=', '1'],
                ],
            ],
            [
                'id' => 'header_middle-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'header_bottom-start',
                'type' => 'section',
                'title' => esc_html__('Header Bottom Options', 'reuss'),
                'indent' => true,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'header_bottom_full_width',
                'type' => 'switch',
                'title' => esc_html__('Full Width Bottom Header', 'reuss'),
                'subtitle' => esc_html__('Set header content in full width', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'header_bottom_max_width_custom',
                'type' => 'switch',
                'title' => esc_html__('Customize Max Width Container', 'reuss'),
                'subtitle' => esc_html__('Set max width container', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'header_bottom_max_width',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Max Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 1290],
                'required' => ['header_bottom_max_width_custom', '=', '1'],
            ],
            [
                'id' => 'header_bottom_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Header Bottom Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => 100],
            ],
            [
                'id' => 'header_bottom_background_image',
                'type' => 'media',
                'title' => esc_html__('Header Bottom Background Image', 'reuss'),
            ],
            [
                'id' => 'header_bottom_background',
                'type' => 'color_rgba',
                'title' => esc_html__('Header Bottom Background', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '.9',
                    'rgba' => 'rgba(255,255,255,0.9)'
                ],
                'mode' => 'background',
            ],
            [
                'id' => 'header_bottom_color',
                'type' => 'color_rgba',
                'title' => esc_html__('Header Bottom Text Color', 'reuss'),
                'default' => [
                    'color' => '#fefefe',
                    'alpha' => '.5',
                    'rgba' => 'rgba(254,254,254,0.5)'
                ],
                'mode' => 'background',
            ],
            [
                'id' => 'header_bottom_bottom_border',
                'type' => 'switch',
                'title' => esc_html__('Set Header Bottom Border', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'header_bottom_border_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Header Bottom Border Width', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => '1'],
                'required' => [
                    ['header_bottom_bottom_border', '=', '1']
                ],
            ],
            [
                'id' => 'header_bottom_bottom_border_color',
                'type' => 'color_rgba',
                'title' => esc_html__('Header Bottom Border Color', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,0.2)'
                ],
                'mode' => 'background',
                'required' => [
                    ['header_bottom_bottom_border', '=', '1'],
                ],
            ],
            [
                'id' => 'header_bottom-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'header_column-top-left-start',
                'type' => 'section',
                'title' => esc_html__('Top Left Column Options', 'reuss'),
                'indent' => true,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'header_column_top_left_horz',
                'type' => 'button_set',
                'title' => esc_html__('Horizontal Align', 'reuss'),
                'options' => [
                    'left' => esc_html__('Left', 'reuss'),
                    'center' => esc_html__('Center', 'reuss'),
                    'right' => esc_html__('Right', 'reuss'),
                ],
                'default' => 'left'
            ],
            [
                'id' => 'header_column_top_left_vert',
                'type' => 'button_set',
                'title' => esc_html__('Vertical Align', 'reuss'),
                'options' => [
                    'top' => esc_html__('Top', 'reuss'),
                    'middle' => esc_html__('Middle', 'reuss'),
                    'bottom' => esc_html__('Bottom', 'reuss'),
                ],
                'default' => 'middle'
            ],
            [
                'id' => 'header_column_top_left_display',
                'type' => 'button_set',
                'title' => esc_html__('Display', 'reuss'),
                'options' => [
                    'normal' => esc_html__('Normal', 'reuss'),
                    'grow' => esc_html__('Grow', 'reuss'),
                ],
                'default' => 'normal'
            ],
            [
                'id' => 'header_column-top-left-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'header_column-top-center-start',
                'type' => 'section',
                'title' => esc_html__('Top Center Column Options', 'reuss'),
                'indent' => true,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'header_column_top_center_horz',
                'type' => 'button_set',
                'title' => esc_html__('Horizontal Align', 'reuss'),
                'options' => [
                    'left' => esc_html__('Left', 'reuss'),
                    'center' => esc_html__('Center', 'reuss'),
                    'right' => esc_html__('Right', 'reuss'),
                ],
                'default' => 'left'
            ],
            [
                'id' => 'header_column_top_center_vert',
                'type' => 'button_set',
                'title' => esc_html__('Vertical Align', 'reuss'),
                'options' => [
                    'top' => esc_html__('Top', 'reuss'),
                    'middle' => esc_html__('Middle', 'reuss'),
                    'bottom' => esc_html__('Bottom', 'reuss'),
                ],
                'default' => 'middle'
            ],
            [
                'id' => 'header_column_top_center_display',
                'type' => 'button_set',
                'title' => esc_html__('Display', 'reuss'),
                'options' => [
                    'normal' => esc_html__('Normal', 'reuss'),
                    'grow' => esc_html__('Grow', 'reuss'),
                ],
                'default' => 'normal'
            ],
            [
                'id' => 'header_column-top-center-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'header_column-top-center-start',
                'type' => 'section',
                'title' => esc_html__('Top Center Column Options', 'reuss'),
                'indent' => true,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'header_column_top_center_horz',
                'type' => 'button_set',
                'title' => esc_html__('Horizontal Align', 'reuss'),
                'options' => [
                    'left' => esc_html__('Left', 'reuss'),
                    'center' => esc_html__('Center', 'reuss'),
                    'right' => esc_html__('Right', 'reuss'),
                ],
                'default' => 'left'
            ],
            [
                'id' => 'header_column_top_center_vert',
                'type' => 'button_set',
                'title' => esc_html__('Vertical Align', 'reuss'),
                'options' => [
                    'top' => esc_html__('Top', 'reuss'),
                    'middle' => esc_html__('Middle', 'reuss'),
                    'bottom' => esc_html__('Bottom', 'reuss'),
                ],
                'default' => 'middle'
            ],
            [
                'id' => 'header_column_top_center_display',
                'type' => 'button_set',
                'title' => esc_html__('Display', 'reuss'),
                'options' => [
                    'normal' => esc_html__('Normal', 'reuss'),
                    'grow' => esc_html__('Grow', 'reuss'),
                ],
                'default' => 'normal'
            ],
            [
                'id' => 'header_column-top-center-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'header_column-top-right-start',
                'type' => 'section',
                'title' => esc_html__('Top Right Column Options', 'reuss'),
                'indent' => true,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'header_column_top_right_horz',
                'type' => 'button_set',
                'title' => esc_html__('Horizontal Align', 'reuss'),
                'options' => [
                    'left' => esc_html__('Left', 'reuss'),
                    'center' => esc_html__('Center', 'reuss'),
                    'right' => esc_html__('Right', 'reuss'),
                ],
                'default' => 'right'
            ],
            [
                'id' => 'header_column_top_right_vert',
                'type' => 'button_set',
                'title' => esc_html__('Vertical Align', 'reuss'),
                'options' => [
                    'top' => esc_html__('Top', 'reuss'),
                    'middle' => esc_html__('Middle', 'reuss'),
                    'bottom' => esc_html__('Bottom', 'reuss'),
                ],
                'default' => 'middle'
            ],
            [
                'id' => 'header_column_top_right_display',
                'type' => 'button_set',
                'title' => esc_html__('Display', 'reuss'),
                'options' => [
                    'normal' => esc_html__('Normal', 'reuss'),
                    'grow' => esc_html__('Grow', 'reuss'),
                ],
                'default' => 'normal'
            ],
            [
                'id' => 'header_column-top-right-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'header_column-middle-left-start',
                'type' => 'section',
                'title' => esc_html__('Middle Left Column Options', 'reuss'),
                'indent' => true,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'header_column_middle_left_horz',
                'type' => 'button_set',
                'title' => esc_html__('Horizontal Align', 'reuss'),
                'options' => [
                    'left' => esc_html__('Left', 'reuss'),
                    'center' => esc_html__('Center', 'reuss'),
                    'right' => esc_html__('Right', 'reuss'),
                ],
                'default' => 'left'
            ],
            [
                'id' => 'header_column_middle_left_vert',
                'type' => 'button_set',
                'title' => esc_html__('Vertical Align', 'reuss'),
                'options' => [
                    'top' => esc_html__('Top', 'reuss'),
                    'middle' => esc_html__('Middle', 'reuss'),
                    'bottom' => esc_html__('Bottom', 'reuss'),
                ],
                'default' => 'middle'
            ],
            [
                'id' => 'header_column_middle_left_display',
                'type' => 'button_set',
                'title' => esc_html__('Display', 'reuss'),
                'options' => [
                    'normal' => esc_html__('Normal', 'reuss'),
                    'grow' => esc_html__('Grow', 'reuss'),
                ],
                'default' => 'normal'
            ],
            [
                'id' => 'header_column-middle-left-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'header_column-middle-center-start',
                'type' => 'section',
                'title' => esc_html__('Middle Center Column Options', 'reuss'),
                'indent' => true,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'header_column_middle_center_horz',
                'type' => 'button_set',
                'title' => esc_html__('Horizontal Align', 'reuss'),
                'options' => [
                    'left' => esc_html__('Left', 'reuss'),
                    'center' => esc_html__('Center', 'reuss'),
                    'right' => esc_html__('Right', 'reuss'),
                ],
                'default' => 'left'
            ],
            [
                'id' => 'header_column_middle_center_vert',
                'type' => 'button_set',
                'title' => esc_html__('Vertical Align', 'reuss'),
                'options' => [
                    'top' => esc_html__('Top', 'reuss'),
                    'middle' => esc_html__('Middle', 'reuss'),
                    'bottom' => esc_html__('Bottom', 'reuss'),
                ],
                'default' => 'middle'
            ],
            [
                'id' => 'header_column_middle_center_display',
                'type' => 'button_set',
                'title' => esc_html__('Display', 'reuss'),
                'options' => [
                    'normal' => esc_html__('Normal', 'reuss'),
                    'grow' => esc_html__('Grow', 'reuss'),
                ],
                'default' => 'normal'
            ],
            [
                'id' => 'header_column-middle-center-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'header_column-middle-center-start',
                'type' => 'section',
                'title' => esc_html__('Middle Center Column Options', 'reuss'),
                'indent' => true,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'header_column_middle_center_horz',
                'type' => 'button_set',
                'title' => esc_html__('Horizontal Align', 'reuss'),
                'options' => [
                    'left' => esc_html__('Left', 'reuss'),
                    'center' => esc_html__('Center', 'reuss'),
                    'right' => esc_html__('Right', 'reuss'),
                ],
                'default' => 'left'
            ],
            [
                'id' => 'header_column_middle_center_vert',
                'type' => 'button_set',
                'title' => esc_html__('Vertical Align', 'reuss'),
                'options' => [
                    'top' => esc_html__('Top', 'reuss'),
                    'middle' => esc_html__('Middle', 'reuss'),
                    'bottom' => esc_html__('Bottom', 'reuss'),
                ],
                'default' => 'middle'
            ],
            [
                'id' => 'header_column_middle_center_display',
                'type' => 'button_set',
                'title' => esc_html__('Display', 'reuss'),
                'options' => [
                    'normal' => esc_html__('Normal', 'reuss'),
                    'grow' => esc_html__('Grow', 'reuss'),
                ],
                'default' => 'normal'
            ],
            [
                'id' => 'header_column-middle-center-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'header_column-middle-right-start',
                'type' => 'section',
                'title' => esc_html__('Middle Right Column Options', 'reuss'),
                'indent' => true,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'header_column_middle_right_horz',
                'type' => 'button_set',
                'title' => esc_html__('Horizontal Align', 'reuss'),
                'options' => [
                    'left' => esc_html__('Left', 'reuss'),
                    'center' => esc_html__('Center', 'reuss'),
                    'right' => esc_html__('Right', 'reuss'),
                ],
                'default' => 'right'
            ],
            [
                'id' => 'header_column_middle_right_vert',
                'type' => 'button_set',
                'title' => esc_html__('Vertical Align', 'reuss'),
                'options' => [
                    'top' => esc_html__('Top', 'reuss'),
                    'middle' => esc_html__('Middle', 'reuss'),
                    'bottom' => esc_html__('Bottom', 'reuss'),
                ],
                'default' => 'middle'
            ],
            [
                'id' => 'header_column_middle_right_display',
                'type' => 'button_set',
                'title' => esc_html__('Display', 'reuss'),
                'options' => [
                    'normal' => esc_html__('Normal', 'reuss'),
                    'grow' => esc_html__('Grow', 'reuss'),
                ],
                'default' => 'normal'
            ],
            [
                'id' => 'header_column-middle-right-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'header_column-bottom-left-start',
                'type' => 'section',
                'title' => esc_html__('Bottom Left Column Options', 'reuss'),
                'indent' => true,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'header_column_bottom_left_horz',
                'type' => 'button_set',
                'title' => esc_html__('Horizontal Align', 'reuss'),
                'options' => [
                    'left' => esc_html__('Left', 'reuss'),
                    'center' => esc_html__('Center', 'reuss'),
                    'right' => esc_html__('Right', 'reuss'),
                ],
                'default' => 'left'
            ],
            [
                'id' => 'header_column_bottom_left_vert',
                'type' => 'button_set',
                'title' => esc_html__('Vertical Align', 'reuss'),
                'options' => [
                    'top' => esc_html__('Top', 'reuss'),
                    'middle' => esc_html__('Middle', 'reuss'),
                    'bottom' => esc_html__('Bottom', 'reuss'),
                ],
                'default' => 'middle'
            ],
            [
                'id' => 'header_column_bottom_left_display',
                'type' => 'button_set',
                'title' => esc_html__('Display', 'reuss'),
                'options' => [
                    'normal' => esc_html__('Normal', 'reuss'),
                    'grow' => esc_html__('Grow', 'reuss'),
                ],
                'default' => 'normal'
            ],
            [
                'id' => 'header_column-bottom-left-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'header_column-bottom-center-start',
                'type' => 'section',
                'title' => esc_html__('Bottom Center Column Options', 'reuss'),
                'indent' => true,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'header_column_bottom_center_horz',
                'type' => 'button_set',
                'title' => esc_html__('Horizontal Align', 'reuss'),
                'options' => [
                    'left' => esc_html__('Left', 'reuss'),
                    'center' => esc_html__('Center', 'reuss'),
                    'right' => esc_html__('Right', 'reuss'),
                ],
                'default' => 'left'
            ],
            [
                'id' => 'header_column_bottom_center_vert',
                'type' => 'button_set',
                'title' => esc_html__('Vertical Align', 'reuss'),
                'options' => [
                    'top' => esc_html__('Top', 'reuss'),
                    'middle' => esc_html__('Middle', 'reuss'),
                    'bottom' => esc_html__('Bottom', 'reuss'),
                ],
                'default' => 'middle'
            ],
            [
                'id' => 'header_column_bottom_center_display',
                'type' => 'button_set',
                'title' => esc_html__('Display', 'reuss'),
                'options' => [
                    'normal' => esc_html__('Normal', 'reuss'),
                    'grow' => esc_html__('Grow', 'reuss'),
                ],
                'default' => 'normal'
            ],
            [
                'id' => 'header_column-bottom-center-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'header_column-bottom-right-start',
                'type' => 'section',
                'title' => esc_html__('Bottom Right Column Options', 'reuss'),
                'indent' => true,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'header_column_bottom_right_horz',
                'type' => 'button_set',
                'title' => esc_html__('Horizontal Align', 'reuss'),
                'options' => [
                    'left' => esc_html__('Left', 'reuss'),
                    'center' => esc_html__('Center', 'reuss'),
                    'right' => esc_html__('Right', 'reuss'),
                ],
                'default' => 'right'
            ],
            [
                'id' => 'header_column_bottom_right_vert',
                'type' => 'button_set',
                'title' => esc_html__('Vertical Align', 'reuss'),
                'options' => [
                    'top' => esc_html__('Top', 'reuss'),
                    'middle' => esc_html__('Middle', 'reuss'),
                    'bottom' => esc_html__('Bottom', 'reuss'),
                ],
                'default' => 'middle'
            ],
            [
                'id' => 'header_column_bottom_right_display',
                'type' => 'button_set',
                'title' => esc_html__('Display', 'reuss'),
                'options' => [
                    'normal' => esc_html__('Normal', 'reuss'),
                    'grow' => esc_html__('Grow', 'reuss'),
                ],
                'default' => 'normal'
            ],
            [
                'id' => 'header_column-bottom-right-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'header_row_settings-start',
                'type' => 'section',
                'title' => esc_html__('Header Settings', 'reuss'),
                'indent' => true,
                'required' => ['header_type', '=', 'default'],
            ],
            [
                'id' => 'header_shadow',
                'type' => 'switch',
                'title' => esc_html__('Header Bottom Shadow', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'header_on_bg',
                'type' => 'switch',
                'title' => esc_html__('Over content', 'reuss'),
                'subtitle' => esc_html__('Display header template over the content.', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'lavalamp_active',
                'type' => 'switch',
                'title' => esc_html__('Enable Lavalamp Marker', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'sub_menu_background',
                'type' => 'color_rgba',
                'title' => esc_html__('Sub Menu Background', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,1)'
                ],
                'mode' => 'background',
            ],
            [
                'id' => 'sub_menu_color',
                'type' => 'color',
                'title' => esc_html__('Sub Menu Text Color', 'reuss'),
                'default' => '#1c1c25',
                'transparent' => false,
            ],
            [
                'id' => 'header_sub_menu_bottom_border',
                'type' => 'switch',
                'title' => esc_html__('Sub Menu Bottom Border', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'header_sub_menu_border_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Sub Menu Border Width', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => '1'],
                'required' => ['header_sub_menu_bottom_border', '=', '1']
            ],
            [
                'id' => 'header_sub_menu_bottom_border_color',
                'type' => 'color_rgba',
                'title' => esc_html__('Sub Menu Border Color', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(0, 0, 0, 0.08)'
                ],
                'mode' => 'background',
                'required' => ['header_sub_menu_bottom_border', '=', '1'],
            ],
            [
                'id' => 'header_mobile_queris',
                'type' => 'slider',
                'title' => esc_html__('Mobile Header Switch Breakpoint', 'reuss'),
                'display_value' => 'text',
                'min' => 400,
                'max' => 1920,
                'default' => 1200,
            ],
            [
                'id' => 'header_row_settings-end',
                'type' => 'section',
                'indent' => false,
            ],
        ]
    ]
);

Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Header Sticky', 'reuss'),
        'id' => 'header_builder_sticky',
        'subsection' => true,
        'fields' => [
            [
                'id' => 'header_sticky',
                'type' => 'switch',
                'title' => esc_html__('Header Sticky', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'header_sticky-start',
                'type' => 'section',
                'title' => esc_html__('Sticky Settings', 'reuss'),
                'indent' => true,
                'required' => ['header_sticky', '=', '1'],
            ],
            [
                'id' => 'header_sticky_page_select',
                'type' => 'select',
                'title' => esc_html__('Header Sticky Template', 'reuss'),
                'data' => 'posts',
                'args' => [
                    'post_type' => 'header',
                    'posts_per_page' => -1,
                    'orderby' => 'title',
                    'order' => 'ASC',
                ],
                'required' => ['header_sticky', '=', '1'],
                'desc' => sprintf(
                    '%s <a href="%s" target="_blank">%s</a> %s',
                    esc_html__('Selected Template will be used for all pages by default. You can edit/create Header Template in the', 'reuss'),
                    admin_url('edit.php?post_type=header'),
                    esc_html__('Header Templates', 'reuss'),
                    esc_html__('dashboard tab.', 'reuss')
                ),
            ],
            [
                'id' => 'header_sticky_style',
                'type' => 'select',
                'title' => esc_html__('Appearance', 'reuss'),
                'options' => [
                    'standard' => esc_html__('Always Visible', 'reuss'),
                    'scroll_up' => esc_html__('Visible while scrolling upwards', 'reuss'),
                ],
                'default' => 'standard'
            ],
            [
                'id' => 'header_sticky-end',
                'type' => 'section',
                'indent' => false,
                'required' => ['header_sticky', '=', '1'],
            ],
        ]
    ]
);

Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Header Mobile', 'reuss'),
        'id' => 'header_builder_mobile',
        'subsection' => true,
        'fields' => [
            [
                'id' => 'mobile_header',
                'type' => 'switch',
                'title' => esc_html__('Mobile Header', 'reuss'),
                'on' => esc_html__('Custom', 'reuss'),
                'off' => esc_html__('Default', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'header_mobile_appearance-start',
                'type' => 'section',
                'title' => esc_html__('Appearance', 'reuss'),
                'indent' => true,
                'required' => ['mobile_header', '=', '1'],
            ],
            [
                'id' => 'header_mobile_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Header Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => [ 'height' => '100' ],
            ],
            [
                'id' => 'header_mobile_full_width',
                'type' => 'switch',
                'title' => esc_html__('Full Width Header', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'mobile_sticky',
                'type' => 'switch',
                'title' => esc_html__('Mobile Sticky Header', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'mobile_over_content',
                'type' => 'switch',
                'title' => esc_html__('Header Over Content', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'custom_mobile_menu',
                'type' => 'switch',
                'title' => esc_html__('Custom Mobile Menu', 'reuss'),
                'default' => false,
            ],
            [
                'id'       => 'mobile_menu',
                'type'     => 'select',
                'title'    => esc_html__( 'Mobile Menu', 'reuss' ),
                'select2'  => array('allowClear' => false),
                'options'  => reuss_redux_get_custom_menu(),
                'required' => ['custom_mobile_menu', '=', '1'],
            ],
            [
                'id' => 'header_mobile_appearance-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'header_mobile_general-start',
                'type' => 'section',
                'title' => esc_html__('General', 'reuss'),
                'indent' => true,
                'required' => ['mobile_header', '=', '1'],
            ],
            [
                'id' => 'mobile_background',
                'type' => 'color_rgba',
                'title' => esc_html__('Header Background', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(28,28,37, 1)'
                ],
                'mode' => 'background',
            ],
            [
                'id' => 'mobile_color',
                'type' => 'color',
                'title' => esc_html__('Header Text Color', 'reuss'),
                'default' => '#ffffff',
                'transparent' => false,
            ],
            [
                'id' => 'header_mobile_general-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'header_mobile_submenu-start',
                'type' => 'section',
                'title' => esc_html__('Sub Menu', 'reuss'),
                'indent' => true,
                'required' => ['mobile_header', '=', '1'],
            ],
            [
                'id' => 'mobile_position',
                'type' => 'button_set',
                'title' => esc_html__('Sub Menu Position', 'reuss'),
                'options' => [
                    'left' => esc_html__('Left', 'reuss'),
                    'right' => esc_html__('Right', 'reuss'),
                ],
                'default' => 'left',
            ],
            [
                'id' => 'mobile_sub_menu_color',
                'type' => 'color',
                'title' => esc_html__('Sub Menu Text Color', 'reuss'),
                'default' => '#ffffff',
                'transparent' => false,
            ],
            [
                'id' => 'mobile_sub_menu_background',
                'type' => 'color_rgba',
                'title' => esc_html__('Sub Menu Background', 'reuss'),
                'default' => [
                    'color' => '#2d2d2d',
                    'alpha' => '1',
                    'rgba' => 'rgba(45,45,45,1)'
                ],
                'mode' => 'background',
            ],
            [
                'id' => 'mobile_sub_menu_overlay',
                'type' => 'color_rgba',
                'title' => esc_html__('Sub Menu Overlay', 'reuss'),
                'default' => [
                    'color' => '#1c1c25',
                    'alpha' => '1',
                    'rgba' => 'rgba(49, 49, 49, 0.8)'
                ],
                'mode' => 'background',
            ],
            [
                'id' => 'header_mobile_submenu-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'mobile_header_layout',
                'type' => 'sorter',
                'title' => esc_html__('Mobile Header Order', 'reuss'),
                'desc' => esc_html__('Organize the layout of the mobile header', 'reuss'),
                'compiler' => 'true',
                'full_width' => true,
                'options' => [
                    'items' => $header_builder_items['mobile'],
                    'Left align side' => [
                        'menu' => esc_html__('Menu', 'reuss'),
                    ],
                    'Center align side' => [
                        'logo' => esc_html__('Logo', 'reuss'),
                    ],
                    'Right align side' => [
                        'item_search' => esc_html__('Search', 'reuss'),
                    ],
                ],
                'default' => [
                    'items' => $header_builder_items['mobile'],
                    'Left align side' => [
                        'menu' => esc_html__('Menu', 'reuss'),
                    ],
                    'Center align side' => [
                        'logo' => esc_html__('Logo', 'reuss'),
                    ],
                    'Right align side' => [
                        'item_search' => esc_html__('Search', 'reuss'),
                    ],
                ],
                'required' => ['mobile_header', '=', '1'],
            ],
            [
                'id' => 'mobile_content_header_layout',
                'type' => 'sorter',
                'title' => esc_html__('Mobile Drawer Content', 'reuss'),
                'desc' => esc_html__('Organize the layout of the mobile header', 'reuss'),
                'compiler' => 'true',
                'full_width' => true,
                'options' => [
                    'items' => $header_builder_items['mobile_drawer'],
                    'Left align side' => [
                        'logo' => esc_html__('Logo', 'reuss'),
                        'menu' => esc_html__('Menu', 'reuss'),
                        'item_search' => esc_html__('Search', 'reuss'),
                    ],
                ],
                'default' => [
                    'items' => $header_builder_items['mobile_drawer'],
                    'Left align side' => [
                        'logo' => esc_html__('Logo', 'reuss'),
                        'menu' => esc_html__('Menu', 'reuss'),
                        'item_search' => esc_html__('Search', 'reuss'),
                    ],
                ],
                'required' => ['mobile_header', '=', '1'],
            ],
            [
                'id' => 'mobile_header_bar_html1_editor',
                'type' => 'ace_editor',
                'mode' => 'html',
                'title' => esc_html__('HTML Element 1 Editor', 'reuss'),
                'default' => '',
                'required' => ['mobile_header', '=', '1'],
            ],
            [
                'id' => 'mobile_header_bar_html2_editor',
                'type' => 'ace_editor',
                'title' => esc_html__('HTML Element 2 Editor', 'reuss'),
                'mode' => 'html',
                'default' => '',
                'required' => ['mobile_header', '=', '1'],
            ],
            [
                'id' => 'mobile_header_bar_html3_editor',
                'type' => 'ace_editor',
                'title' => esc_html__('HTML Element 3 Editor', 'reuss'),
                'mode' => 'html',
                'default' => '',
                'required' => ['mobile_header', '=', '1'],
            ],
            [
                'id' => 'mobile_header_bar_html4_editor',
                'type' => 'ace_editor',
                'title' => esc_html__('HTML Element 4 Editor', 'reuss'),
                'mode' => 'html',
                'default' => '',
                'required' => ['mobile_header', '=', '1'],
            ],
            [
                'id' => 'mobile_header_bar_html5_editor',
                'type' => 'ace_editor',
                'title' => esc_html__('HTML Element 5 Editor', 'reuss'),
                'mode' => 'html',
                'default' => '',
                'required' => ['mobile_header', '=', '1'],
            ],
            [
                'id' => 'mobile_header_bar_html6_editor',
                'type' => 'ace_editor',
                'title' => esc_html__('HTML Element 6 Editor', 'reuss'),
                'mode' => 'html',
                'default' => '',
                'required' => ['mobile_header', '=', '1'],
            ],
            [
                'id' => 'mobile_header_spacer1',
                'type' => 'dimensions',
                'title' => esc_html__('Spacer 1 Width', 'reuss'),
                'units' => 'px',
                'units_extended' => false,
                'height' => false,
                'width' => true,
                'default' => ['width' => 25],
                'required' => ['mobile_header', '=', '1'],
            ],
            [
                'id' => 'mobile_header_spacer2',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Spacer 2 Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 25],
                'required' => ['mobile_header', '=', '1'],
            ],
            [
                'id' => 'mobile_header_spacer3',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Spacer 3 Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 25],
                'required' => ['mobile_header', '=', '1'],
            ],
            [
                'id' => 'mobile_header_spacer4',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Spacer 4 Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 25],
                'required' => ['mobile_header', '=', '1'],
            ],
            [
                'id' => 'mobile_header_spacer5',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Spacer 5 Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 25],
                'required' => ['mobile_header', '=', '1'],
            ],
            [
                'id' => 'mobile_header_spacer6',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Spacer 6 Width', 'reuss'),
                'height' => false,
                'width' => true,
                'default' => ['width' => 25],
                'required' => ['mobile_header', '=', '1'],
            ],
        ]
    ]
);

Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Page Title', 'reuss'),
        'id' => 'page_title',
    ]
);

Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Settings', 'reuss'),
        'id' => 'page_title_settings',
        'subsection' => true,
        'fields' => [
            [
                'id' => 'page_title_switch',
                'type' => 'switch',
                'title' => esc_html__('Use Page Title?', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'page_title-start',
                'type' => 'section',
                'title' => esc_html__('Appearance', 'reuss'),
                'indent' => true,
                'required' => ['page_title_switch', '=', '1'],
            ],
            [
                'id' => 'page_title_bg_switch',
                'type' => 'switch',
                'title' => esc_html__('Use Background Image/Color?', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'page_title_bg_image',
                'type' => 'background',
                'title' => esc_html__('Background Image/Color', 'reuss'),
                'preview' => false,
                'preview_media' => true,
                'background-color' => true,
                'transparent' => false,
                'default' => [
                    'background-image' => '',
                    'background-repeat' => 'no-repeat',
                    'background-size' => 'cover',
                    'background-attachment' => 'scroll',
                    'background-position' => 'center bottom',
                    'background-color' => '#2f057b',
                ],
                'required' => ['page_title_bg_switch', '=', true],
            ],
            [
                'id' => 'page_title_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => 300],
                'required' => ['page_title_bg_switch', '=', true],
            ],
            [
                'id' => 'page_title_padding',
                'type' => 'spacing',
                'title' => esc_html__('Paddings Top/Bottom', 'reuss'),
                'mode' => 'padding',
                'all' => false,
                'bottom' => true,
                'top' => true,
                'left' => false,
                'right' => false,
                'default' => [
                    'padding-top' => '60',
                    'padding-bottom' => '60',
                ],
            ],
            [
                'id' => 'page_title_margin',
                'type' => 'spacing',
                'title' => esc_html__('Margin Bottom', 'reuss'),
                'mode' => 'margin',
                'all' => false,
                'bottom' => true,
                'top' => false,
                'left' => false,
                'right' => false,
                'default' => ['margin-bottom' => '50'],
            ],
            [
                'id' => 'page_title_align',
                'type' => 'button_set',
                'title' => esc_html__('Title Alignment', 'reuss'),
                'options' => [
                    'left' => 'Left',
                    'center' => 'Center',
                    'right' => 'Right'
                ],
                'default' => 'center',
            ],
            [
                'id' => 'page_title_breadcrumbs_switch',
                'type' => 'switch',
                'title' => esc_html__('Breadcrumbs', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'page_title_breadcrumbs_block_switch',
                'type' => 'switch',
                'title' => esc_html__('Breadcrumbs Full Width', 'reuss'),
                'on' => esc_html__('Yes', 'reuss'),
                'off' => esc_html__('No', 'reuss'),
                'default' => true,
                'required' => ['page_title_breadcrumbs_switch', '=', true],
            ],
            [
                'id' => 'page_title_breadcrumbs_align',
                'type' => 'button_set',
                'title' => esc_html__('Breadcrumbs Alignment', 'reuss'),
                'options' => [
                    'left' => 'Left',
                    'center' => 'Center',
                    'right' => 'Right'
                ],
                'default' => 'center',
                'required' => ['page_title_breadcrumbs_block_switch', '=', true],
            ],
            [
                'id' => 'page_title_parallax',
                'type' => 'switch',
                'title' => esc_html__('Parallax Effect', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'page_title_parallax_speed',
                'type' => 'spinner',
                'title' => esc_html__('Parallax Speed', 'reuss'),
                'default' => '0.3',
                'min' => '-5',
                'step' => '0.1',
                'max' => '5',
                'required' => ['page_title_parallax', '=', '1'],
            ],
            [
                'id' => 'page_title-end',
                'type' => 'section',
                'indent' => false,
                'required' => ['page_title_switch', '=', '1'],
            ],
        ]
    ]
);

Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Typography', 'reuss'),
        'id' => 'page_title_typography',
        'subsection' => true,
        'fields' => [
            [
                'id' => 'page_title_font',
                'type' => 'custom_typography',
                'title' => esc_html__('Page Title Font', 'reuss'),
                'font-size' => true,
                'google' => false,
                'font-weight' => false,
                'font-family' => false,
                'font-style' => false,
                'color' => true,
                'line-height' => true,
                'font-backup' => false,
                'text-align' => false,
                'all_styles' => false,
                'default' => [
                    'font-size' => '40px',
                    'line-height' => '52px',
                    'color' => '#fefeff',
                ],
            ],
            [
                'id' => 'page_title_breadcrumbs_font',
                'type' => 'custom_typography',
                'title' => esc_html__('Page Title Breadcrumbs Font', 'reuss'),
                'font-size' => true,
                'google' => false,
                'font-weight' => false,
                'font-family' => false,
                'font-style' => false,
                'color' => true,
                'line-height' => true,
                'font-backup' => false,
                'text-align' => false,
                'all_styles' => false,
                'default' => [
                    'font-size' => '14px',
                    'color' => '#fefeff',
                    'line-height' => '24px',
                ],
            ],
        ]
    ]
);

Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Responsive', 'reuss'),
        'id' => 'page_title_responsive',
        'subsection' => true,
        'fields' => [
            [
                'id' => 'page_title_resp_switch',
                'type' => 'switch',
                'title' => esc_html__('Responsive Layout On/Off', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'page_title_resp_resolution',
                'type' => 'slider',
                'title' => esc_html__('Screen breakpoint', 'reuss'),
                'default' => 768,
                'min' => 1,
                'step' => 1,
                'max' => 1700,
                'display_value' => 'text',
                'required' => ['page_title_resp_switch', '=', '1'],
            ],
            [
                'id' => 'page_title_resp_height',
                'type' => 'dimensions',
                'units' => 'px',
                'units_extended' => false,
                'title' => esc_html__('Height', 'reuss'),
                'height' => true,
                'width' => false,
                'default' => ['height' => 180],
                'required' => ['page_title_resp_switch', '=', '1'],
            ],
            [
                'id' => 'page_title_resp_padding',
                'type' => 'spacing',
                'mode' => 'padding',
                'all' => false,
                'bottom' => true,
                'top' => true,
                'left' => false,
                'right' => false,
                'title' => esc_html__('Paddings Top/Bottom', 'reuss'),
                'default' => [
                    'padding-top' => '15',
                    'padding-bottom' => '15',
                ],
                'required' => ['page_title_resp_switch', '=', '1'],
            ],
            [
                'id' => 'page_title_resp_font',
                'type' => 'custom_typography',
                'title' => esc_html__('Page Title Font', 'reuss'),
                'font-size' => true,
                'google' => false,
                'font-weight' => false,
                'font-family' => false,
                'font-style' => false,
                'color' => true,
                'line-height' => true,
                'font-backup' => false,
                'text-align' => false,
                'all_styles' => false,
                'default' => [
                    'font-size' => '42px',
                    'line-height' => '48px',
                    'color' => '#ffffff',
                ],
                'required' => ['page_title_resp_switch', '=', '1'],
            ],
            [
                'id' => 'page_title_resp_breadcrumbs_switch',
                'type' => 'switch',
                'title' => esc_html__('Breadcrumbs On/Off', 'reuss'),
                'default' => true,
                'required' => ['page_title_resp_switch', '=', '1'],
            ],
            [
                'id' => 'page_title_resp_breadcrumbs_font',
                'type' => 'custom_typography',
                'title' => esc_html__('Page Title Breadcrumbs Font', 'reuss'),
                'font-size' => true,
                'google' => false,
                'font-weight' => false,
                'font-family' => false,
                'font-style' => false,
                'color' => true,
                'line-height' => true,
                'font-backup' => false,
                'text-align' => false,
                'all_styles' => false,
                'default' => [
                    'font-size' => '16px',
                    'color' => '#fefeff',
                    'line-height' => '24px',
                ],
                'required' => ['page_title_resp_breadcrumbs_switch', '=', '1'],
            ],

        ]
    ]
);

//* START Footer Options
Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Footer', 'reuss'),
        'id' => 'footer',
    ]
);

Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Settings', 'reuss'),
        'id' => 'footer_settings',
        'subsection' => true,
        'fields' => [
            [
                'id' => 'footer_switch',
                'type' => 'switch',
                'title' => esc_html__('Footer', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Disable', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'footer-start',
                'type' => 'section',
                'title' => esc_html__('Footer Settings', 'reuss'),
                'indent' => true,
                'required' => ['footer_switch', '=', '1'],
            ],
            [
                'id' => 'footer_content_type',
                'type' => 'select',
                'title' => esc_html__('Content Type', 'reuss'),
                'options' => [
                    'widgets' => 'Get Widgets',
                    'pages' => 'Get Pages'
                ],
                'default' => 'pages',
            ],
            [
                'id' => 'footer_page_select',
                'type' => 'select',
                'title' => esc_html__('Page Select', 'reuss'),
                'data' => 'posts',
                'args' => [
                    'post_type' => 'footer',
                    'posts_per_page' => -1,
                    'orderby' => 'title',
                    'order' => 'ASC',
                ],
                'required' => ['footer_content_type', '=', 'pages'],
            ],
            [
                'id' => 'widget_columns',
                'type' => 'button_set',
                'title' => esc_html__('Columns', 'reuss'),
                'options' => [
                    '1' => '1',
                    '2' => '2',
                    '3' => '3',
                    '4' => '4',
                ],
                'default' => '4',
                'required' => ['footer_content_type', '=', 'widgets'],
            ],
            [
                'id' => 'widget_columns_2',
                'type' => 'image_select',
                'title' => esc_html__('Columns Layout', 'reuss'),
                'options' => [
                    '6-6' => [
                        'alt' => '50-50',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/50-50.png'
                    ],
                    '3-9' => [
                        'alt' => '25-75',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/25-75.png'
                    ],
                    '9-3' => [
                        'alt' => '75-25',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/75-25.png'
                    ],
                    '4-8' => [
                        'alt' => '33-66',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/33-66.png'
                    ],
                    '8-4' => [
                        'alt' => '66-33',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/66-33.png'
                    ]
                ],
                'default' => '6-6',
                'required' => ['widget_columns', '=', '2'],
            ],
            [
                'id' => 'widget_columns_3',
                'type' => 'image_select',
                'title' => esc_html__('Columns Layout', 'reuss'),
                'options' => [
                    '4-4-4' => [
                        'alt' => '33-33-33',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/33-33-33.png'
                    ],
                    '3-3-6' => [
                        'alt' => '25-25-50',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/25-25-50.png'
                    ],
                    '3-6-3' => [
                        'alt' => '25-50-25',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/25-50-25.png'
                    ],
                    '6-3-3' => [
                        'alt' => '50-25-25',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/50-25-25.png'
                    ],
                ],
                'default' => '4-4-4',
                'required' => ['widget_columns', '=', '3'],
            ],
            [
                'id' => 'footer_spacing',
                'type' => 'spacing',
                'output' => ['.wgl-footer'],
                'mode' => 'padding',
                'units' => 'px',
                'all' => false,
                'title' => esc_html__('Paddings', 'reuss'),
                'default' => [
                    'padding-top' => '50px',
                    'padding-right' => '0px',
                    'padding-bottom' => '0px',
                    'padding-left' => '0px'
                ],
                'required' => ['footer_content_type', '=', 'widgets'],
            ],
            [
                'id' => 'footer_full_width',
                'type' => 'switch',
                'title' => esc_html__('Full Width On/Off', 'reuss'),
                'default' => false,
                'required' => ['footer_content_type', '=', 'widgets'],
            ],
            [
                'id' => 'footer-end',
                'type' => 'section',
                'indent' => false,
                'required' => ['footer_switch', '=', '1'],
            ],
            [
                'id' => 'footer-start-styles',
                'type' => 'section',
                'title' => esc_html__('Footer Styling', 'reuss'),
                'indent' => true,
                'required' => [
                    ['footer_switch', '=', '1'],
                    ['footer_content_type', '=', 'widgets'],
                ],
            ],
            [
                'id' => 'footer_bg_image',
                'type' => 'background',
                'background-color' => false,
                'preview_media' => true,
                'preview' => false,
                'title' => esc_html__('Background Image', 'reuss'),
                'default' => [
                    'background-repeat' => 'repeat',
                    'background-size' => 'cover',
                    'background-attachment' => 'scroll',
                    'background-position' => 'center center',
                ],
                'required' => [
                    ['footer_switch', '=', '1'],
                    ['footer_content_type', '=', 'widgets'],
                ],
            ],
            [
                'id' => 'footer_align',
                'type' => 'button_set',
                'title' => esc_html__('Content Align', 'reuss'),
                'options' => [
                    'left' => 'Left',
                    'center' => 'Center',
                    'right' => 'Right'
                ],
                'default' => 'center',
                'required' => [
                    ['footer_switch', '=', '1'],
                    ['footer_content_type', '=', 'widgets'],
                ],
            ],
            [
                'id' => 'footer_bg_color',
                'type' => 'color',
                'title' => esc_html__('Background Color', 'reuss'),
                'default' => '#1f242c',
                'transparent' => false,
                'required' => [
                    ['footer_switch', '=', '1'],
                    ['footer_content_type', '=', 'widgets'],
                ],
            ],
            [
                'id' => 'footer_heading_color',
                'type' => 'color',
                'title' => esc_html__('Headings color', 'reuss'),
                'transparent' => false,
                'default' => '#ffffff',
                'required' => [
                    ['footer_switch', '=', '1'],
                    ['footer_content_type', '=', 'widgets'],
                ],
            ],
            [
                'id' => 'footer_text_color',
                'type' => 'color',
                'title' => esc_html__('Content color', 'reuss'),
                'transparent' => false,
                'default' => '#ffffff',
                'required' => [
                    ['footer_switch', '=', '1'],
                    ['footer_content_type', '=', 'widgets'],
                ],
            ],
            [
                'id' => 'footer_add_border',
                'type' => 'switch',
                'title' => esc_html__('Add Border Top', 'reuss'),
                'default' => false,
                'required' => [
                    ['footer_switch', '=', '1'],
                    ['footer_content_type', '=', 'widgets'],
                ],
            ],
            [
                'id' => 'footer_border_color',
                'type' => 'color',
                'title' => esc_html__('Border color', 'reuss'),
                'default' => '#e5e5e5',
                'transparent' => false,
                'required' => ['footer_add_border', '=', '1'],
            ],
            [
                'id' => 'footer-end-styles',
                'type' => 'section',
                'indent' => false,
            ],
        ]
    ]
);

//* START Copyright Options
Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Copyright', 'reuss'),
        'id' => 'copyright',
    ]
);

Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Settings', 'reuss'),
        'id' => 'copyright-settings',
        'subsection' => true,
        'fields' => [
            [
                'id' => 'copyright_switch',
                'type' => 'switch',
                'title' => esc_html__('Copyright', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Disable', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'copyright-start',
                'type' => 'section',
                'title' => esc_html__('Copyright Settings', 'reuss'),
                'indent' => true,
                'required' => ['copyright_switch', '=', '1'],
            ],
            [
                'id' => 'copyright_editor',
                'type' => 'editor',
                'title' => esc_html__('Editor', 'reuss'),
                'default' => '<p>Copyright © 2020 Reuss by WebGeniusLab. All Rights Reserved</p>',
                'args' => [
                    'wpautop' => false,
                    'media_buttons' => false,
                    'textarea_rows' => 2,
                    'teeny' => false,
                    'quicktags' => true,
                ],
                'required' => ['copyright_switch', '=', '1'],
            ],
            [
                'id' => 'copyright_text_color',
                'type' => 'color',
                'title' => esc_html__('Text Color', 'reuss'),
                'default' => '#9f9f9f',
                'transparent' => false,
                'required' => ['copyright_switch', '=', '1'],
            ],
            [
                'id' => 'copyright_bg_color',
                'type' => 'color',
                'title' => esc_html__('Background Color', 'reuss'),
                'default' => '#1f242c',
                'transparent' => false,
                'required' => ['copyright_switch', '=', '1'],
            ],
            [
                'id' => 'copyright_spacing',
                'type' => 'spacing',
                'title' => esc_html__('Paddings', 'reuss'),
                'mode' => 'padding',
                'left' => false,
                'right' => false,
                'all' => false,
                'default' => [
                    'padding-top' => '20',
                    'padding-bottom' => '20',
                ],
                'required' => ['copyright_switch', '=', '1'],
            ],
            [
                'id' => 'copyright-end',
                'type' => 'section',
                'indent' => false,
                'required' => ['footer_switch', '=', '1'],
            ],
        ]
    ]
);

//* START Blog Options
Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Blog', 'reuss'),
        'id' => 'blog-option',
        'icon' => 'el-icon-th',
    ]
);

Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Archive', 'reuss'),
        'id' => 'blog-list-option',
        'subsection' => true,
        'fields' => [
            [
                'id' => 'blog_list_page_title-start',
                'type' => 'section',
                'title' => esc_html__('Page Title', 'reuss'),
                'indent' => true,
            ],
            [
                'id' => 'post_archive_page_title_bg_image',
                'type' => 'background',
                'background-color' => false,
                'preview_media' => true,
                'preview' => false,
                'title' => esc_html__('Background Image', 'reuss'),
                'default' => [
                    'background-repeat' => 'repeat',
                    'background-size' => 'cover',
                    'background-attachment' => 'scroll',
                    'background-position' => 'center center',
                    'background-color' => '',
                ],
            ],
            [
                'id' => 'blog_list_page_title-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'blog_list_sidebar-start',
                'type' => 'section',
                'title' => esc_html__('Sidebar', 'reuss'),
                'indent' => true,
            ],
            [
                'id' => 'blog_list_sidebar_layout',
                'type' => 'image_select',
                'title' => esc_html__('Sidebar Layout', 'reuss'),
                'options' => [
                    'none' => [
                        'alt' => 'None',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/1col.png'
                    ],
                    'left' => [
                        'alt' => 'Left',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/2cl.png'
                    ],
                    'right' => [
                        'alt' => 'Right',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/2cr.png'
                    ]
                ],
                'default' => 'none'
            ],
            [
                'id' => 'blog_list_sidebar_def',
                'type' => 'select',
                'title' => esc_html__('Sidebar Template', 'reuss'),
                'data' => 'sidebars',
                'required' => ['blog_list_sidebar_layout', '!=', 'none'],
            ],
            [
                'id' => 'blog_list_sidebar_def_width',
                'type' => 'button_set',
                'title' => esc_html__('Sidebar Width', 'reuss'),
                'options' => [
                    '9' => '25%',
                    '8' => '33%',
                ],
                'default' => '9',
                'required' => ['blog_list_sidebar_layout', '!=', 'none'],
            ],
            [
                'id' => 'blog_list_sidebar_sticky',
                'type' => 'switch',
                'title' => esc_html__('Sticky Sidebar', 'reuss'),
                'default' => false,
                'required' => ['blog_list_sidebar_layout', '!=', 'none'],
            ],
            [
                'id' => 'blog_list_sidebar_gap',
                'type' => 'select',
                'title' => esc_html__('Sidebar Side Gap', 'reuss'),
                'options' => [
                    'def' => esc_html__('Default', 'reuss'),
                    '0' => '0',
                    '15' => '15',
                    '20' => '20',
                    '25' => '25',
                    '30' => '30',
                    '35' => '35',
                    '40' => '40',
                    '45' => '45',
                    '50' => '50',
                ],
                'default' => 'def',
                'required' => ['blog_list_sidebar_layout', '!=', 'none'],
            ],
            [
                'id' => 'blog_list_sidebar-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'blog_list_appearance-start',
                'type' => 'section',
                'title' => esc_html__('Appearance', 'reuss'),
                'indent' => true,
            ],
            [
                'id' => 'blog_list_columns',
                'type' => 'button_set',
                'title' => esc_html__('Columns in Archive', 'reuss'),
                'options' => [
                    '12' => 'One',
                    '6' => 'Two',
                    '4' => 'Three',
                    '3' => 'Four'
                ],
                'default' => '12'
            ],
            [
                'id' => 'blog_list_likes',
                'type' => 'switch',
                'title' => esc_html__('Likes', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'blog_list_share',
                'type' => 'switch',
                'title' => esc_html__('Shares', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'blog_list_hide_media',
                'type' => 'switch',
                'title' => esc_html__('Hide Media?', 'reuss'),
                'on' => esc_html__('Yes', 'reuss'),
                'off' => esc_html__('No', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'blog_list_hide_title',
                'type' => 'switch',
                'title' => esc_html__('Hide Title?', 'reuss'),
                'on' => esc_html__('Yes', 'reuss'),
                'off' => esc_html__('No', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'blog_list_hide_content',
                'type' => 'switch',
                'title' => esc_html__('Hide Content?', 'reuss'),
                'on' => esc_html__('Yes', 'reuss'),
                'off' => esc_html__('No', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'blog_post_listing_content',
                'type' => 'switch',
                'title' => esc_html__('Cut Off Text in Blog Listing', 'reuss'),
                'on' => esc_html__('Yes', 'reuss'),
                'off' => esc_html__('No', 'reuss'),
                'default' => false,
                'required' => ['blog_list_hide_content', '=', false],
            ],
            [
                'id' => 'blog_list_letter_count',
                'type' => 'text',
                'title' => esc_html__('Limit amount of characters to be displayed.', 'reuss'),
                'default' => '85',
                'required' => ['blog_post_listing_content', '=', true],
            ],
            [
                'id' => 'blog_list_read_more',
                'type' => 'switch',
                'title' => esc_html__('Hide Read More Button?', 'reuss'),
                'on' => esc_html__('Yes', 'reuss'),
                'off' => esc_html__('No', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'blog_list_meta',
                'type' => 'switch',
                'title' => esc_html__('Hide all post-meta?', 'reuss'),
                'on' => esc_html__('Yes', 'reuss'),
                'off' => esc_html__('No', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'blog_list_meta_author',
                'type' => 'switch',
                'title' => esc_html__('Hide post-meta author?', 'reuss'),
                'on' => esc_html__('Yes', 'reuss'),
                'off' => esc_html__('No', 'reuss'),
                'default' => true,
                'required' => ['blog_list_meta', '=', false],
            ],
            [
                'id' => 'blog_list_meta_comments',
                'type' => 'switch',
                'title' => esc_html__('Hide post-meta comments?', 'reuss'),
                'on' => esc_html__('Yes', 'reuss'),
                'off' => esc_html__('No', 'reuss'),
                'default' => true,
                'required' => ['blog_list_meta', '=', false],
            ],
            [
                'id' => 'blog_list_meta_categories',
                'type' => 'switch',
                'title' => esc_html__('Hide post-meta categories?', 'reuss'),
                'on' => esc_html__('Yes', 'reuss'),
                'off' => esc_html__('No', 'reuss'),
                'default' => false,
                'required' => ['blog_list_meta', '=', false],
            ],
            [
                'id' => 'blog_list_meta_date',
                'type' => 'switch',
                'title' => esc_html__('Hide post-meta date?', 'reuss'),
                'on' => esc_html__('Yes', 'reuss'),
                'off' => esc_html__('No', 'reuss'),
                'default' => false,
                'required' => ['blog_list_meta', '=', false],
            ],
            [
                'id' => 'blog_list_appearance-end',
                'type' => 'section',
                'indent' => false,
            ],
        ]
    ]
);

Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Single', 'reuss'),
        'id' => 'blog-single-option',
        'subsection' => true,
        'fields' => [
            [
                'id' => 'single_type_layout',
                'type' => 'button_set',
                'title' => esc_html__('Default Post Layout', 'reuss'),
                'desc' => esc_html__('Note: each Post can be additionally customized within its Meta boxes section.', 'reuss'),
                'options' => [
                    '1' => esc_html__('Title First', 'reuss'),
                    '2' => esc_html__('Image First', 'reuss'),
                    '3' => esc_html__('Overlay Image', 'reuss')
                ],
                'default' => '3'
            ],
            [
                'id' => 'blog_single_page_title-start',
                'type' => 'section',
                'title' => esc_html__('Page Title', 'reuss'),
                'indent' => true,
            ],
            [
                'id' => 'blog_title_conditional',
                'type' => 'switch',
                'title' => esc_html__('Page Title Text', 'reuss'),
                'on' => esc_html__('Custom', 'reuss'),
                'off' => esc_html__('Default', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'blog_single_page_title_breadcrumbs_switch',
                'type' => 'switch',
                'title' => esc_html__('Breadcrumbs', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'post_single_page_title_bg_image',
                'type' => 'background',
                'title' => esc_html__('Background Image', 'reuss'),
                'preview' => false,
                'preview_media' => true,
                'background-color' => false,
                'default' => [
                    'background-repeat' => 'repeat',
                    'background-size' => 'cover',
                    'background-attachment' => 'scroll',
                    'background-position' => 'center center',
                    'background-color' => '#202020',
                ],
            ],
            [
                'id' => 'single_padding_layout_3',
                'type' => 'spacing',
                'mode' => 'padding',
                'all' => false,
                'bottom' => true,
                'top' => true,
                'left' => false,
                'right' => false,
                'title' => esc_html__('Padding Top/Bottom', 'reuss'),
                'desc' => esc_html__('Note: this setting affects only the "Overlay Image" post layout.', 'reuss'),
                'default' => [
                    'padding-top' => '340px',
                    'padding-bottom' => '90px',
                ],
            ],
            [
                'id' => 'blog_single_page_title-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'blog_single_sidebar-start',
                'type' => 'section',
                'title' => esc_html__('Sidebar', 'reuss'),
                'indent' => true,
            ],
            [
                'id' => 'single_sidebar_layout',
                'type' => 'image_select',
                'title' => esc_html__('Blog Single Sidebar Layout', 'reuss'),
                'options' => [
                    'none' => [
                        'alt' => 'None',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/1col.png'
                    ],
                    'left' => [
                        'alt' => 'Left',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/2cl.png'
                    ],
                    'right' => [
                        'alt' => 'Right',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/2cr.png'
                    ]
                ],
                'default' => 'right'
            ],
            [
                'id' => 'single_sidebar_def',
                'type' => 'select',
                'title' => esc_html__('Blog Single Sidebar', 'reuss'),
                'data' => 'sidebars',
                'default' => 'sidebar_main-sidebar',
                'required' => ['single_sidebar_layout', '!=', 'none'],
            ],
            [
                'id' => 'single_sidebar_def_width',
                'type' => 'button_set',
                'title' => esc_html__('Blog Single Sidebar Width', 'reuss'),
                'options' => [
                    '9' => '25%',
                    '8' => '33%',
                ],
                'default' => '9',
                'required' => ['single_sidebar_layout', '!=', 'none'],
            ],
            [
                'id' => 'single_sidebar_sticky',
                'type' => 'switch',
                'title' => esc_html__('Blog Single Sticky Sidebar On?', 'reuss'),
                'default' => true,
                'required' => ['single_sidebar_layout', '!=', 'none'],
            ],
            [
                'id' => 'single_sidebar_gap',
                'type' => 'select',
                'title' => esc_html__('Sidebar Side Gap', 'reuss'),
                'options' => [
                    'def' => esc_html__('Default', 'reuss'),
                    '0' => '0',
                    '15' => '15',
                    '20' => '20',
                    '25' => '25',
                    '30' => '30',
                    '35' => '35',
                    '40' => '40',
                    '45' => '45',
                    '50' => '50',
                ],
                'default' => 'def',
                'required' => ['single_sidebar_layout', '!=', 'none'],
            ],
            [
                'id' => 'blog_single_sidebar-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'blog_single_appearance-start',
                'type' => 'section',
                'title' => esc_html__('Appearance', 'reuss'),
                'indent' => true,
            ],
            [
                'id' => 'featured_image_type',
                'type' => 'button_set',
                'title' => esc_html__('Featured Image', 'reuss'),
                'options' => [
                    'default' => esc_html__('Default', 'reuss'),
                    'off' => esc_html__('Off', 'reuss'),
                    'replace' => esc_html__('Replace', 'reuss')
                ],
                'default' => 'default'
            ],
            [
                'id' => 'featured_image_replace',
                'type' => 'media',
                'title' => esc_html__('Image To Replace On', 'reuss'),
                'required' => ['featured_image_type', '=', 'replace'],
            ],
            [
                'id' => 'single_apply_animation',
                'type' => 'switch',
                'title' => esc_html__('Apply Animation?', 'reuss'),
                'on' => esc_html__('Yes', 'reuss'),
                'off' => esc_html__('No', 'reuss'),
                'default' => true,
                'required' => ['single_type_layout', '=', '3'],
            ],
            [
                'id' => 'single_likes',
                'type' => 'switch',
                'title' => esc_html__('Likes', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'single_views',
                'type' => 'switch',
                'title' => esc_html__('Views', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'single_share',
                'type' => 'switch',
                'title' => esc_html__('Shares', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'single_author_info',
                'type' => 'switch',
                'title' => esc_html__('Author Info', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'single_meta',
                'type' => 'switch',
                'title' => esc_html__('Hide all post-meta?', 'reuss'),
                'on' => esc_html__('Yes', 'reuss'),
                'off' => esc_html__('No', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'single_meta_author',
                'type' => 'switch',
                'title' => esc_html__('Hide post-meta author?', 'reuss'),
                'on' => esc_html__('Yes', 'reuss'),
                'off' => esc_html__('No', 'reuss'),
                'default' => true,
                'required' => ['single_meta', '=', false],
            ],
            [
                'id' => 'single_meta_comments',
                'type' => 'switch',
                'title' => esc_html__('Hide post-meta comments?', 'reuss'),
                'on' => esc_html__('Yes', 'reuss'),
                'off' => esc_html__('No', 'reuss'),
                'default' => true,
                'required' => ['single_meta', '=', false],
            ],
            [
                'id' => 'single_meta_categories',
                'type' => 'switch',
                'title' => esc_html__('Hide post-meta categories?', 'reuss'),
                'on' => esc_html__('Yes', 'reuss'),
                'off' => esc_html__('No', 'reuss'),
                'default' => false,
                'required' => ['single_meta', '=', false],
            ],
            [
                'id' => 'single_meta_date',
                'type' => 'switch',
                'title' => esc_html__('Hide post-meta date?', 'reuss'),
                'on' => esc_html__('Yes', 'reuss'),
                'off' => esc_html__('No', 'reuss'),
                'default' => false,
                'required' => ['single_meta', '=', false],
            ],
            [
                'id' => 'single_meta_tags',
                'type' => 'switch',
                'title' => esc_html__('Hide tags?', 'reuss'),
                'on' => esc_html__('Yes', 'reuss'),
                'off' => esc_html__('No', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'blog_single_appearance-end',
                'type' => 'section',
                'indent' => false,
            ],
        ]
    ]
);

Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Related', 'reuss'),
        'id' => 'blog-single-related-option',
        'subsection' => true,
        'fields' => [
            [
                'id' => 'single_related_posts',
                'type' => 'switch',
                'title' => esc_html__('Related Posts', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'blog_cat_r',
                'type' => 'select',
                'multi' => true,
                'title' => esc_html__('Select Categories', 'reuss'),
                'data' => 'categories',
                'width' => '20%',
                'required' => ['single_related_posts', '=', '1'],
            ],
            [
                'id' => 'blog_column_r',
                'type' => 'button_set',
                'title' => esc_html__('Columns', 'reuss'),
                'options' => [
                    '12' => '1',
                    '6' => '2',
                    '4' => '3',
                    '3' => '4'
                ],
                'default' => '6',
                'required' => ['single_related_posts', '=', '1'],
            ],
            [
                'id' => 'blog_number_r',
                'type' => 'text',
                'title' => esc_html__('Number of Related Items', 'reuss'),
                'default' => '2',
                'required' => ['single_related_posts', '=', '1'],
            ],
            [
                'id' => 'blog_carousel_r',
                'type' => 'switch',
                'title' => esc_html__('Display items in the carousel', 'reuss'),
                'default' => true,
                'required' => ['single_related_posts', '=', '1'],
            ],
        ]
    ]
);

//* START Portfolio Options
Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Portfolio', 'reuss'),
        'id' => 'portfolio-option',
        'icon' => 'el-icon-th',
    ]
);

Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Archive', 'reuss'),
        'id' => 'portfolio-list-option',
        'subsection' => true,
        'fields' => [
            [
                'id' => 'portfolio_slug',
                'type' => 'text',
                'title' => esc_html__('Portfolio Slug', 'reuss'),
                'default' => 'portfolio',
            ],
            [
                'id' => 'portfolio_archive_page_title_bg_image',
                'type' => 'background',
                'background-color' => false,
                'preview_media' => true,
                'preview' => false,
                'title' => esc_html__('Archive Page Title Background Image', 'reuss'),
                'default' => [
                    'background-repeat' => 'repeat',
                    'background-size' => 'cover',
                    'background-attachment' => 'scroll',
                    'background-position' => 'center center',
                    'background-color' => '',
                ],
            ],
            [
                'id' => 'portfolio_list_sidebar-start',
                'type' => 'section',
                'title' => esc_html__('Sidebar', 'reuss'),
                'indent' => true,
            ],
            [
                'id' => 'portfolio_list_sidebar_layout',
                'type' => 'image_select',
                'title' => esc_html__('Sidebar Layout', 'reuss'),
                'options' => [
                    'none' => [
                        'alt' => 'None',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/1col.png'
                    ],
                    'left' => [
                        'alt' => 'Left',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/2cl.png'
                    ],
                    'right' => [
                        'alt' => 'Right',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/2cr.png'
                    ]
                ],
                'default' => 'none'
            ],
            [
                'id' => 'portfolio_list_sidebar_def',
                'type' => 'select',
                'title' => esc_html__('Sidebar Template', 'reuss'),
                'data' => 'sidebars',
                'required' => ['portfolio_list_sidebar_layout', '!=', 'none'],
            ],
            [
                'id' => 'portfolio_list_sidebar_def_width',
                'type' => 'button_set',
                'title' => esc_html__('Sidebar Width', 'reuss'),
                'options' => [
                    '9' => '25%',
                    '8' => '33%',
                ],
                'default' => '8',
                'required' => ['portfolio_list_sidebar_layout', '!=', 'none'],
            ],
            [
                'id' => 'portfolio_list_sidebar_sticky',
                'type' => 'switch',
                'title' => esc_html__('Sticky Sidebar', 'reuss'),
                'default' => false,
                'required' => ['portfolio_list_sidebar_layout', '!=', 'none'],
            ],
            [
                'id' => 'portfolio_list_sidebar_gap',
                'type' => 'select',
                'title' => esc_html__('Sidebar Side Gap', 'reuss'),
                'options' => [
                    'def' => esc_html__('Default', 'reuss'),
                    '0' => '0',
                    '15' => '15',
                    '20' => '20',
                    '25' => '25',
                    '30' => '30',
                    '35' => '35',
                    '40' => '40',
                    '45' => '45',
                    '50' => '50',
                ],
                'default' => 'def',
                'required' => ['portfolio_list_sidebar_layout', '!=', 'none'],
            ],
            [
                'id' => 'portfolio_list_sidebar-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'portfolio_list_appearance-start',
                'type' => 'section',
                'title' => esc_html__('Appearance', 'reuss'),
                'indent' => true,
            ],
            [
                'id' => 'portfolio_list_columns',
                'type' => 'button_set',
                'title' => esc_html__('Columns in Archive', 'reuss'),
                'options' => [
                    '1' => 'One',
                    '2' => 'Two',
                    '3' => 'Three',
                    '4' => 'Four'
                ],
                'default' => '3'
            ],
            [
                'id' => 'portfolio_list_show_filter',
                'type' => 'switch',
                'title' => esc_html__('Filter', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'portfolio_list_filter_cats',
                'type' => 'select',
                'multi' => true,
                'title' => esc_html__('Select Categories', 'reuss'),
                'data' => 'terms',
                'args' => ['taxonomies' => 'portfolio-category'],
                'required' => ['portfolio_list_show_filter', '=', '1'],
            ],
            [
                'id' => 'portfolio_list_show_title',
                'type' => 'switch',
                'title' => esc_html__('Title', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'portfolio_list_show_content',
                'type' => 'switch',
                'title' => esc_html__('Content', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'portfolio_list_show_cat',
                'type' => 'switch',
                'title' => esc_html__('Categories', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'portfolio_list_appearance-end',
                'type' => 'section',
                'indent' => false,
            ],
        ]
    ]
);

Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Single', 'reuss'),
        'id' => 'portfolio-single-option',
        'subsection' => true,
        'fields' => [
            [
                'id' => 'portfolio_single_layout-start',
                'type' => 'section',
                'title' => esc_html__('Layout', 'reuss'),
                'indent' => true,
            ],
            [
                'id' => 'portfolio_single_type_layout',
                'type' => 'button_set',
                'title' => esc_html__('Portfolio Single Layout', 'reuss'),
                'options' => [
                    '1' => esc_html__('Title First', 'reuss'),
                    '2' => esc_html__('Image First', 'reuss'),
                ],
                'default' => '2',
            ],
            [
                'id' => 'portfolio_single_layout-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'portfolio_single_post_title-start',
                'type' => 'section',
                'title' => esc_html__('Post Title Settings', 'reuss'),
                'indent' => true,
            ],
            [
                'id' => 'portfolio_title_conditional',
                'type' => 'switch',
                'title' => esc_html__('Post Title Text', 'reuss'),
                'on' => esc_html__('Custom', 'reuss'),
                'off' => esc_html__('Default', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'portfolio_single_title_align',
                'type' => 'button_set',
                'title' => esc_html__('Title Alignment', 'reuss'),
                'options' => [
                    'left' => esc_html__('Left', 'reuss'),
                    'center' => esc_html__('Center', 'reuss'),
                    'right' => esc_html__('Right', 'reuss'),
                ],
                'default' => 'center',
            ],
            [
                'id' => 'portfolio_single_breadcrumbs_align',
                'type' => 'button_set',
                'title' => esc_html__('Breadcrumbs Alignment', 'reuss'),
                'options' => [
                    'left' => esc_html__('Left', 'reuss'),
                    'center' => esc_html__('Center', 'reuss'),
                    'right' => esc_html__('Right', 'reuss'),
                ],
                'default' => 'center',
            ],
            [
                'id' => 'portfolio_single_breadcrumbs_block_switch',
                'type' => 'switch',
                'title' => esc_html__('Breadcrumbs Full Width', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'portfolio_single_title_bg_switch',
                'type' => 'switch',
                'title' => esc_html__('Use Background Image/Color?', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'portfolio_single_page_title_bg_image',
                'type' => 'background',
                'title' => esc_html__('Background Image/Color', 'reuss'),
                'preview' => false,
                'preview_media' => true,
                'background-color' => true,
                'transparent' => false,
                'default' => [
                    'background-repeat' => 'repeat',
                    'background-size' => 'cover',
                    'background-attachment' => 'scroll',
                    'background-position' => 'center center',
                    'background-color' => '',
                ],
                'required' => ['portfolio_single_title_bg_switch', '=', true],
            ],
            [
                'id' => 'portfolio_single_page_title_padding',
                'type' => 'spacing',
                'title' => esc_html__('Paddings Top/Bottom', 'reuss'),
                'mode' => 'padding',
                'all' => false,
                'bottom' => true,
                'top' => true,
                'left' => false,
                'right' => false,
            ],
            [
                'id' => 'portfolio_single_page_title_margin',
                'type' => 'spacing',
                'title' => esc_html__('Margin Bottom', 'reuss'),
                'mode' => 'margin',
                'all' => false,
                'bottom' => true,
                'top' => false,
                'left' => false,
                'right' => false,
                'default' => ['margin-bottom' => '32'],
            ],
            [
                'id' => 'portfolio_single_post_title-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'portfolio_single_sidebar-start',
                'type' => 'section',
                'title' => esc_html__('Sidebar', 'reuss'),
                'indent' => true,
            ],
            [
                'id' => 'portfolio_single_sidebar_layout',
                'type' => 'image_select',
                'title' => esc_html__('Sidebar Layout', 'reuss'),
                'options' => [
                    'none' => [
                        'alt' => 'None',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/1col.png'
                    ],
                    'left' => [
                        'alt' => 'Left',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/2cl.png'
                    ],
                    'right' => [
                        'alt' => 'Right',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/2cr.png'
                    ]
                ],
                'default' => 'none'
            ],
            [
                'id' => 'portfolio_single_sidebar_def',
                'type' => 'select',
                'title' => esc_html__('Sidebar Template', 'reuss'),
                'data' => 'sidebars',
                'required' => ['portfolio_single_sidebar_layout', '!=', 'none'],
            ],
            [
                'id' => 'portfolio_single_sidebar_def_width',
                'type' => 'button_set',
                'title' => esc_html__('Sidebar Width', 'reuss'),
                'options' => [
                    '9' => '25%',
                    '8' => '33%',
                ],
                'default' => '8',
                'required' => ['portfolio_single_sidebar_layout', '!=', 'none'],
            ],
            [
                'id' => 'portfolio_single_sidebar_sticky',
                'type' => 'switch',
                'title' => esc_html__('Sticky Sidebar', 'reuss'),
                'default' => false,
                'required' => ['portfolio_single_sidebar_layout', '!=', 'none'],
            ],
            [
                'id' => 'portfolio_single_sidebar_gap',
                'type' => 'select',
                'title' => esc_html__('Sidebar Side Gap', 'reuss'),
                'options' => [
                    'def' => esc_html__('Default', 'reuss'),
                    '0' => '0',
                    '15' => '15',
                    '20' => '20',
                    '25' => '25',
                    '30' => '30',
                    '35' => '35',
                    '40' => '40',
                    '45' => '45',
                    '50' => '50',
                ],
                'default' => 'def',
                'required' => ['portfolio_single_sidebar_layout', '!=', 'none'],
            ],
            [
                'id' => 'portfolio_single_sidebar-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'portfolio_single_appearance-start',
                'type' => 'section',
                'title' => esc_html__('Appearance', 'reuss'),
                'indent' => true,
            ],
            [
                'id' => 'portfolio_single_align',
                'type' => 'button_set',
                'title' => esc_html__('Content Alignment', 'reuss'),
                'options' => [
                    'left' => esc_html__('Left', 'reuss'),
                    'center' => esc_html__('Center', 'reuss'),
                    'right' => esc_html__('Right', 'reuss'),
                ],
                'default' => 'left',
            ],
            [
                'id' => 'portfolio_above_content_cats',
                'type' => 'switch',
                'title' => esc_html__('Tags', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'portfolio_above_content_share',
                'type' => 'switch',
                'title' => esc_html__('Shares', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'portfolio_single_meta_likes',
                'type' => 'switch',
                'title' => esc_html__('Likes', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'portfolio_single_meta',
                'type' => 'switch',
                'title' => esc_html__('Hide all post-meta?', 'reuss'),
                'on' => esc_html__('Yes', 'reuss'),
                'off' => esc_html__('No', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'portfolio_single_meta_author',
                'type' => 'switch',
                'title' => esc_html__('Post-meta author', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => false,
                'required' => ['portfolio_single_meta', '=', false],
            ],
            [
                'id' => 'portfolio_single_meta_comments',
                'type' => 'switch',
                'title' => esc_html__('Post-meta comments', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => false,
                'required' => ['portfolio_single_meta', '=', false],
            ],
            [
                'id' => 'portfolio_single_meta_categories',
                'type' => 'switch',
                'title' => esc_html__('Post-meta categories', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => false,
                'required' => ['portfolio_single_meta', '=', false],
            ],
            [
                'id' => 'portfolio_single_meta_date',
                'type' => 'switch',
                'title' => esc_html__('Post-meta date', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => false,
                'required' => ['portfolio_single_meta', '=', false],
            ],
            [
                'id' => 'portfolio_single_appearance-end',
                'type' => 'section',
                'indent' => false,
            ],
        ]
    ]
);

Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Related Posts', 'reuss'),
        'id' => 'portfolio-related-option',
        'subsection' => true,
        'fields' => [
            [
                'id' => 'portfolio_related_switch',
                'type' => 'switch',
                'title' => esc_html__('Related Posts', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'pf_title_r',
                'type' => 'text',
                'title' => esc_html__('Title', 'reuss'),
                'default' => esc_html__('Related Projects', 'reuss'),
                'required' => ['portfolio_related_switch', '=', '1'],
            ],
            [
                'id' => 'pf_carousel_r',
                'type' => 'switch',
                'title' => esc_html__('Display items carousel for this portfolio post', 'reuss'),
                'default' => true,
                'required' => ['portfolio_related_switch', '=', '1'],
            ],
            [
                'id' => 'pf_column_r',
                'type' => 'button_set',
                'title' => esc_html__('Related Columns', 'reuss'),
                'options' => [
                    '2' => 'Two',
                    '3' => 'Three',
                    '4' => 'Four'
                ],
                'default' => '3',
                'required' => ['portfolio_related_switch', '=', '1'],
            ],
            [
                'id' => 'pf_number_r',
                'type' => 'text',
                'title' => esc_html__('Number of Related Items', 'reuss'),
                'default' => '3',
                'required' => ['portfolio_related_switch', '=', '1'],
            ],
        ]
    ]
);

//* START Team Options
Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Team', 'reuss'),
        'id' => 'team-option',
        'icon' => 'el-icon-th',
        'fields' => [
            [
                'id' => 'team_slug',
                'title' => esc_html__('Team Slug', 'reuss'),
                'type' => 'text',
                'default' => 'team',
            ],
        ]
    ]
);

Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Single', 'reuss'),
        'id' => 'team-single-option',
        'subsection' => true,
        'fields' => [
            [
                'id' => 'team_title_conditional',
                'title' => esc_html__('Page Title Text', 'reuss'),
                'type' => 'switch',
                'on' => esc_html__('Custom', 'reuss'),
                'off' => esc_html__('Default', 'reuss'),
                'default' => true,
            ],
            [
                'id' => 'team_single_page_title_bg_image',
                'title' => esc_html__('Single Page Title Background Image', 'reuss'),
                'type' => 'background',
                'preview' => false,
                'preview_media' => true,
                'background-color' => false,
                'default' => [
                    'background-repeat' => 'repeat',
                    'background-size' => 'cover',
                    'background-attachment' => 'scroll',
                    'background-position' => 'center center',
                    'background-color' => '',
                ],
            ],
        ]
    ]
);

//* START Page 404 Options
Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Page 404', 'reuss'),
        'id' => '404-option',
        'icon' => 'fas fa-newspaper',
        'fields' => [
            [
                'id' => '404_page_type',
                'type' => 'select',
                'title' => esc_html__('Layout 404 Tool', 'reuss'),
                'desc' => esc_html__('Custom Template allows create templates within Elementor environment.', 'reuss'),
                'options' => [
                    'default' => esc_html__('Default', 'reuss'),
                    'custom' => esc_html__('Custom Template(Elementor Saved Template)', 'reuss')
                ],
                'default' => 'default',
            ],
            [
                'id' => '404_template_select',
                'type' => 'select',
                'title' => esc_html__('404 Template', 'reuss'),
                'data' => 'posts',
                'desc' => sprintf(
                    '%s <a href="%s" target="_blank">%s</a> %s',
                    esc_html__('Selected Template will be used for 404 page by default. You can edit/create Template in the', 'reuss'),
                    admin_url('edit.php?post_type=elementor_library&tabs_group=library'),
                    esc_html__('Saved Templates', 'reuss'),
                    esc_html__('dashboard tab.', 'reuss')
                ),
                'args' => [
                    'post_type' => 'elementor_library',
                    'posts_per_page' => -1,
                    'orderby' => 'title',
                    'order' => 'ASC',
                ],
                'required' => ['404_page_type', '=', 'custom'],
            ],
            [
                'id' => '404_show_header',
                'type' => 'switch',
                'title' => esc_html__('Header Section', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => true,
                'required' => ['404_page_type', '=', 'default']
            ],
            [
                'id' => '404_page_title_switcher',
                'title' => esc_html__('Page Title Section', 'reuss'),
                'type' => 'switch',
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => true,
                'required' => ['404_page_type', '=', 'default']
            ],
            [
                'id' => '404_post_title-start',
                'type' => 'section',
                'indent' => true,
                'required' => ['404_page_title_switcher', '=', true],
            ],
            [
                'id' => '404_custom_title_switch',
                'title' => esc_html__('Page Title Text', 'reuss'),
                'type' => 'switch',
                'on' => esc_html__('Custom', 'reuss'),
                'off' => esc_html__('Default', 'reuss'),
                'default' => false,
                'required' => [
                    ['404_page_title_switcher', '=', true],
                ],
            ],
            [
                'id' => '404_page_title_text',
                'title' => esc_html__('Custom Page Title Text', 'reuss'),
                'type' => 'text',
                'default' => esc_html__('', 'reuss'),
                'required' => ['404_custom_title_switch', '=', true],
            ],
            [
                'id' => '404_title_bg_switch',
                'type' => 'switch',
                'title' => esc_html__('Use Background Image/Color?', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => true,
                'required' => ['404_page_title_switcher', '=', true],
            ],
            [
                'id' => '404_page_title_bg_image',
                'title' => esc_html__('Background Image/Color', 'reuss'),
                'type' => 'background',
                'required' => ['404_title_bg_switch', '=', true],
                'preview' => false,
                'preview_media' => true,
                'background-color' => true,
                'transparent' => false,
                'default' => [
                    'background-repeat' => 'repeat',
                    'background-size' => 'cover',
                    'background-attachment' => 'scroll',
                    'background-position' => 'center center',
                    'background-color' => '',
                ],
            ],
            [
                'id' => '404_page_title_padding',
                'title' => esc_html__('Paddings Top/Bottom', 'reuss'),
                'type' => 'spacing',
                'mode' => 'padding',
                'all' => false,
                'bottom' => true,
                'top' => true,
                'left' => false,
                'right' => false,
                'required' => ['404_title_bg_switch', '=', true],
            ],
            [
                'id' => '404_page_title_margin',
                'title' => esc_html__('Margin Bottom', 'reuss'),
                'type' => 'spacing',
                'mode' => 'margin',
                'all' => false,
                'bottom' => true,
                'top' => false,
                'left' => false,
                'right' => false,
                'required' => ['404_title_bg_switch', '=', true],
            ],
            [
                'id' => '404_page_title-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => '404_content-start',
                'type' => 'section',
                'title' => esc_html__('Content Section', 'reuss'),
                'indent' => true,
                'required' => [ '404_page_type', '=', 'default'],
            ],
            [
                'id' => '404_page_main_bg_image',
                'title' => esc_html__('Content Section Background', 'reuss'),
                'type' => 'background',
                'preview' => false,
                'preview_media' => true,
                'background-color' => true,
                'transparent' => false,
                'default' => [
                    'background-repeat' => 'no-repeat',
                    'background-size' => 'cover',
                    'background-attachment' => 'scroll',
                    'background-position' => 'right top',
                    'background-color' => '#ffffff',
                ],
            ],
            [
                'id' => '404_particles',
                'type' => 'switch',
                'title' => esc_html__('Content Section Particles Animation', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => false,
            ],
            [
                'id' => '404_content-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => '404_show_footer',
                'type' => 'switch',
                'title' => esc_html__('Footer Section', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Hide', 'reuss'),
                'default' => true,
                'required' => [ '404_page_type', '=', 'default'],
            ],
        ]
    ]
);

//* START Side Panel Options
Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Side Panel', 'reuss'),
        'id' => 'side_panel',
        'icon' => 'dashicons dashicons-menu-alt3',
        'fields' => [
            [
                'id' => 'side_panel_enable',
                'type' => 'switch',
                'title' => esc_html__('Side Panel', 'reuss'),
                'on' => esc_html__('Use', 'reuss'),
                'off' => esc_html__('Disable', 'reuss'),
                'default' => false,
            ],
            [
                'id' => 'side_panel-start',
                'type' => 'section',
                'title' => esc_html__('Side Panel Settings', 'reuss'),
                'indent' => true,
                'required' => ['side_panel_enable', '=', '1'],
            ],
            [
                'id' => 'side_panel_content_type',
                'type' => 'select',
                'title' => esc_html__('Content Type', 'reuss'),
                'options' => [
                    'widgets' => esc_html__('Get Widgets', 'reuss'),
                    'pages' => esc_html__('Get Pages', 'reuss')
                ],
                'default' => 'pages',
            ],
            [
                'id' => 'side_panel_page_select',
                'type' => 'select',
                'title' => esc_html__('Page Select', 'reuss'),
                'data' => 'posts',
                'args' => [
                    'post_type' => 'side_panel',
                    'posts_per_page' => -1,
                    'orderby' => 'title',
                    'order' => 'ASC',
                ],
                'required' => ['side_panel_content_type', '=', 'pages']
            ],
            [
                'id' => 'side_panel_spacing',
                'type' => 'spacing',
                'title' => esc_html__('Paddings', 'reuss'),
                'output' => ['#side-panel .side-panel_sidebar'],
                'mode' => 'padding',
                'units' => 'px',
                'all' => false,
                'default' => [
                    'padding-top' => '110px',
                    'padding-right' => '50px',
                    'padding-bottom' => '40px',
                    'padding-left' => '50px',
                ],
            ],
            [
                'id' => 'side_panel_title_color',
                'type' => 'color_rgba',
                'title' => esc_html__('Title Color', 'reuss'),
                'default' => [
                    'color' => '#232323',
                    'alpha' => '1',
                    'rgba' => 'rgba(35,35,35,1)'
                ],
                'mode' => 'background',
                'required' => ['side_panel_content_type', '=', 'widgets'],
            ],
            [
                'id' => 'side_panel_text_color',
                'type' => 'color_rgba',
                'title' => esc_html__('Text Color', 'reuss'),
                'default' => [
                    'color' => '#cccccc',
                    'alpha' => '1',
                    'rgba' => 'rgba(204,204,204,1)'
                ],
                'mode' => 'background',
                'required' => ['side_panel_content_type', '=', 'widgets'],
            ],
            [
                'id' => 'side_panel_bg',
                'type' => 'color_rgba',
                'title' => esc_html__('Background', 'reuss'),
                'default' => [
                    'color' => '#ffffff',
                    'alpha' => '1',
                    'rgba' => 'rgba(255,255,255,1)'
                ],
                'mode' => 'background',
            ],
            [
                'id' => 'side_panel_text_alignment',
                'type' => 'button_set',
                'title' => esc_html__('Text Align', 'reuss'),
                'options' => [
                    'left' => esc_html__('Left', 'reuss'),
                    'center' => esc_html__('Center', 'reuss'),
                    'right' => esc_html__('Right', 'reuss'),
                ],
                'default' => 'left'
            ],
            [
                'id' => 'side_panel_width',
                'type' => 'dimensions',
                'title' => esc_html__('Width', 'reuss'),
                'units' => 'px',
                'units_extended' => false,
                'height' => false,
                'width' => true,
                'default' => ['width' => 375],
            ],
            [
                'id' => 'side_panel_position',
                'type' => 'button_set',
                'title' => esc_html__('Position', 'reuss'),
                'options' => [
                    'left' => esc_html__('Left', 'reuss'),
                    'right' => esc_html__('Right', 'reuss'),
                ],
                'default' => 'right'
            ],
            [
                'id' => 'side_panel-end',
                'type' => 'section',
                'indent' => false,
                'required' => ['side_panel_enable', '=', '1'],
            ],
        ]
    ]
);

//* START Layout Options
Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Sidebars', 'reuss'),
        'id' => 'layout_options',
        'icon' => 'fas fa-columns',
        'fields' => [
            [
                'id' => 'sidebars',
                'type' => 'multi_text',
                'validate' => 'no_html',
                'add_text' => esc_html__('Add Sidebar', 'reuss'),
                'title' => esc_html__('Register Sidebars', 'reuss'),
                'default' => ['Main Sidebar'],
            ],
            [
                'id' => 'sidebars-start',
                'type' => 'section',
                'title' => esc_html__('Sidebar Page Settings', 'reuss'),
                'indent' => true,
            ],
            [
                'id' => 'page_sidebar_layout',
                'type' => 'image_select',
                'title' => esc_html__('Page Sidebar Layout', 'reuss'),
                'options' => [
                    'none' => [
                        'alt' => 'None',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/1col.png'
                    ],
                    'left' => [
                        'alt' => 'Left',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/2cl.png'
                    ],
                    'right' => [
                        'alt' => 'Right',
                        'img' => get_template_directory_uri() . '/core/admin/img/options/2cr.png'
                    ]
                ],
                'default' => 'none'
            ],
            [
                'id' => 'page_sidebar_def',
                'type' => 'select',
                'title' => esc_html__('Page Sidebar', 'reuss'),
                'data' => 'sidebars',
                'required' => ['page_sidebar_layout', '!=', 'none'],
            ],
            [
                'id' => 'page_sidebar_def_width',
                'type' => 'button_set',
                'title' => esc_html__('Page Sidebar Width', 'reuss'),
                'options' => [
                    '9' => '25%',
                    '8' => '33%',
                ],
                'default' => '9',
                'required' => ['page_sidebar_layout', '!=', 'none'],
            ],
            [
                'id' => 'page_sidebar_sticky',
                'type' => 'switch',
                'title' => esc_html__('Sticky Sidebar On?', 'reuss'),
                'default' => false,
                'required' => ['page_sidebar_layout', '!=', 'none'],
            ],
            [
                'id' => 'page_sidebar_gap',
                'type' => 'select',
                'title' => esc_html__('Sidebar Side Gap', 'reuss'),
                'options' => [
                    'def' => esc_html__('Default', 'reuss'),
                    '0' => '0',
                    '15' => '15',
                    '20' => '20',
                    '25' => '25',
                    '30' => '30',
                    '35' => '35',
                    '40' => '40',
                    '45' => '45',
                    '50' => '50',
                ],
                'default' => 'def',
                'required' => ['page_sidebar_layout', '!=', 'none'],
            ],
            [
                'id' => 'sidebars-end',
                'type' => 'section',
                'indent' => false,
            ],
        ]
    ]
);

//* START Social Share Options
Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Social Shares', 'reuss'),
        'id' => 'soc_shares',
        'icon' => 'el el-share-alt',
        'fields' => [
            [
                'id'       => 'post_shares',
                'type'     => 'checkbox',
                'title'    => esc_html__( 'Share List', 'reuss' ),
                'options'  => [
                    'telegram' => 'Telegram',
                    'reddit' => 'Reddit',
                    'whatsapp' => 'WhatsApp',
                    'twitter' => 'Twitter',
                    'facebook' => 'Facebook',
                    'pinterest' => 'Pinterest',
                    'linkedin' => 'Linkedin',
                ],
                'desc' => esc_html__( 'This share list used only on Portfolio Single, Blog Single, Blog List', 'reuss' ),
                'default' => [
                    'telegram' => '0',
                    'reddit' => '0',
                    'whatsapp' => '0',
                    'twitter' => '1',
                    'facebook' => '1',
                    'pinterest' => '1',
                    'linkedin' => '1',
                ]
            ],
        ]
    ]
);

//* START Styling Options
Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Color Options', 'reuss'),
        'id' => 'color_options_color',
        'icon' => 'el-icon-tint',
        'fields' => [
            [
                'id' => 'color-start',
                'type' => 'section',
                'title' => esc_html__('Color', 'reuss'),
                'indent' => true,
            ],
            [
                'id' => 'theme-primary-color',
                'type' => 'color',
                'title' => esc_html__('Primary Theme Color', 'reuss'),
                'transparent' => false,
                'validate' => 'color',
                'default' => '#ff7268',
            ],
            [
                'id' => 'theme-secondary-color',
                'type' => 'color',
                'title' => esc_html__('Secondary Theme Color', 'reuss'),
                'transparent' => false,
                'validate' => 'color',
                'default' => '#8e6de2',
            ],
            [
                'id' => 'theme-tertiary-color',
                'type' => 'color',
                'title' => esc_html__('Tertiary Theme Color', 'reuss'),
                'transparent' => false,
                'validate' => 'color',
                'default' => '#1fe8f5',
            ],
            [
                'id' => 'color-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'gradient-start',
                'type' => 'section',
                'title' => esc_html__('Gradient', 'reuss'),
                'indent' => true,
            ],
            [
                'id'       => 'use-gradient',
                'type'     => 'switch',
                'title'    => esc_html__( 'Use Theme Gradient?', 'reuss' ),
                'default'  => true,
            ],
            [
                'id'       => 'theme-gradient',
                'type'     => 'color_gradient',
                'title'    => esc_html__('Primary Theme Gradient', 'reuss' ),
                'validate' => 'color',
                'default'  => [
                    'from' => '#ff7268',
                    'to'   => '#ffb06c',
                ],
                'required' => [ 'use-gradient', '=', '1' ],
            ],
            [
                'id'       => 'second-gradient',
                'type'     => 'color_gradient',
                'title'    => esc_html__('Secondary Theme Gradient', 'reuss' ),
                'validate' => 'color',
                'default'  => [
                    'from' => '#643cb5',
                    'to'   => '#c670ea',
                ],
                'required' => [ 'use-gradient', '=', '1' ],
            ],
            [
                'id' => 'gradient-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'buttons-color-start',
                'type' => 'section',
                'title' => esc_html__('Buttons Color', 'reuss'),
                'indent' => true,
            ],
            [
                'id'       => 'use-button-gradient',
                'type'     => 'switch',
                'on' => esc_html__('Gradient', 'reuss'),
                'off' => esc_html__('Color', 'reuss'),
                'title'    => esc_html__( 'Use Buttons Color/Gradient?', 'reuss' ),
                'default'  => true,
            ],
            [
                'id' => 'button-color',
                'type' => 'color',
                'title' => esc_html__('Buttons Idle Color', 'reuss'),
                'transparent' => false,
                'validate' => 'color',
                'default' => '#ff7268',
                'required' => [ 'use-button-gradient', '=', '0' ],
            ],
            [
                'id' => 'button-hover-color',
                'type' => 'color',
                'title' => esc_html__('Buttons Hover Color', 'reuss'),
                'transparent' => false,
                'validate' => 'color',
                'default' => '#8e6de2',
                'required' => [ 'use-button-gradient', '=', '0' ],
            ],
            [
                'id' => 'button-secondary-color',
                'type' => 'color',
                'title' => esc_html__('Buttons Idle Color', 'reuss'),
                'transparent' => false,
                'validate' => 'color',
                'default' => '#643cb5',
                'required' => [ 'use-button-gradient', '=', '0' ],
            ],
            [
                'id' => 'button-secondary-hover-color',
                'type' => 'color',
                'title' => esc_html__('Buttons Hover Color', 'reuss'),
                'transparent' => false,
                'validate' => 'color',
                'default' => '#c670ea',
                'required' => [ 'use-button-gradient', '=', '0' ],
            ],
            [
                'id'       => 'button-gradient',
                'type'     => 'color_gradient',
                'title'    => esc_html__('Buttons Gradient', 'reuss' ),
                'validate' => 'color',
                'default'  => [
                    'from' => '#ff7268',
                    'to'   => '#ffb06c',
                ],
                'required' => [ 'use-button-gradient', '=', '1' ],
            ],
            [
                'id'       => 'button-secondary-gradient',
                'type'     => 'color_gradient',
                'title'    => esc_html__('Buttons Secondary Gradient', 'reuss' ),
                'validate' => 'color',
                'default'  => [
                    'from' => '#643cb5',
                    'to'   => '#c670ea',
                ],
                'required' => [ 'use-button-gradient', '=', '1' ],
            ],
            [
                'id' => 'buttons-color-end',
                'type' => 'section',
                'indent' => false,
            ],
            [
                'id' => 'body-background-color',
                'type' => 'color',
                'title' => esc_html__('Body Background Color', 'reuss'),
                'transparent' => false,
                'validate' => 'color',
                'default' => '#ffffff',
            ],
        ]
    ]
);

//* ↓ Typography Config ↓
Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Typography', 'reuss'),
        'id' => 'Typography',
        'icon' => 'el-icon-font',
    ]
);

$typography = [];
$main_typography = [
    [
        'id' => 'main-font',
        'title' => esc_html__('Content Font', 'reuss'),
        'color' => true,
        'line-height' => true,
        'font-size' => true,
        'subsets' => false,
        'all_styles' => true,
        'font-weight-multi' => true,
        'defs' => [
            'font-size' => '16px',
            'line-height' => '30px',
            'color' => '#696970',
            'font-family' => 'Nunito',
            'font-weight' => '400',
            'font-weight-multi' => '500,600,700,800',
        ],
    ],
    [
        'id' => 'header-font',
        'title' => esc_html__('Headings Font', 'reuss'),
        'font-size' => false,
        'line-height' => false,
        'color' => true,
        'subsets' => false,
        'all_styles' => true,
        'font-weight-multi' => true,
        'defs' => [
            'google' => true,
            'color' => '#1c1c25',
            'font-family' => 'Livvic',
            'font-weight' => '700',
            'font-weight-multi' => '400,500,600,900',
        ],
    ],
];
foreach ($main_typography as $key => $value) {
    array_push(
        $typography,
        [
            'id' => $value['id'],
            'type' => 'custom_typography',
            'title' => $value['title'],
            'color' => $value['color'],
            'line-height' => $value['line-height'],
            'font-size' => $value['font-size'],
            'subsets' => $value['subsets'],
            'all_styles' => $value['all_styles'],
            'font-weight-multi' => isset($value['font-weight-multi']) ? $value['font-weight-multi'] : '',
            'subtitle' => isset($value['subtitle']) ? $value['subtitle'] : '',
            'google' => true,
            'font-style' => true,
            'font-backup' => false,
            'text-align' => false,
            'default' => $value['defs'],
        ]
    );
}

Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Main Content', 'reuss'),
        'id' => 'main_typography',
        'subsection' => true,
        'fields' => $typography
    ]
);

//* ↓ Menu Typography ↓
$menu_typography = [
    [
        'id' => 'menu-font',
        'title' => esc_html__('Menu Font', 'reuss'),
        'color' => false,
        'line-height' => true,
        'font-size' => true,
        'subsets' => true,
        'defs' => [
            'google' => true,
            'font-family' => 'Nunito',
            'font-size' => '17px',
            'font-weight' => '800',
            'line-height' => '30px'
        ],
    ],
    [
        'id' => 'sub-menu-font',
        'title' => esc_html__('Submenu Font', 'reuss'),
        'color' => false,
        'line-height' => true,
        'font-size' => true,
        'subsets' => true,
        'defs' => [
            'google' => true,
            'font-family' => 'Nunito',
            'font-size' => '16px',
            'font-weight' => '700',
            'line-height' => '30px'
        ],
    ],
];
$menu_typography_array = [];
foreach ($menu_typography as $key => $value) {
    array_push($menu_typography_array, [
        'id' => $value['id'],
        'type' => 'custom_typography',
        'title' => $value['title'],
        'color' => $value['color'],
        'line-height' => $value['line-height'],
        'font-size' => $value['font-size'],
        'subsets' => $value['subsets'],
        'google' => true,
        'font-style' => true,
        'font-backup' => false,
        'text-align' => false,
        'all_styles' => false,
        'default' => $value['defs'],
    ]);
}

Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Menu', 'reuss'),
        'id' => 'main_menu_typography',
        'subsection' => true,
        'fields' => $menu_typography_array
    ]
);
//* ↑ menu typography ↑

//* ↓ Headings Typography ↓
$headings = [
    [
        'id' => 'header-h1',
        'title' => esc_html__('‹H1› first ‹/H1›', 'reuss'),
        'defs' => [
            'font-family' => 'Livvic',
            'font-size' => '48px',
            'line-height' => '72px',
            'font-weight' => '700',
        ],
    ],
    [
        'id' => 'header-h2',
        'title' => esc_html__('‹H2› second ‹/H2›', 'reuss'),
        'defs' => [
            'font-family' => 'Livvic',
            'font-size' => '40px',
            'line-height' => '60px',
            'font-weight' => '700',
        ],
    ],
    [
        'id' => 'header-h3',
        'title' => esc_html__('‹H3› third ‹/H3›', 'reuss'),
        'defs' => [
            'font-family' => 'Livvic',
            'font-size' => '36px',
            'line-height' => '50px',
            'font-weight' => '700',
        ],
    ],
    [
        'id' => 'header-h4',
        'title' => esc_html__('‹H4› fourth ‹/H4›', 'reuss'),
        'defs' => [
            'font-family' => 'Livvic',
            'font-size' => '30px',
            'line-height' => '40px',
            'font-weight' => '700',
        ],
    ],
    [
        'id' => 'header-h5',
        'title' => esc_html__('‹H5› fifth ‹/H5›', 'reuss'),
        'defs' => [
            'font-family' => 'Livvic',
            'font-size' => '24px',
            'line-height' => '38px',
            'font-weight' => '700'
        ],
    ],
    [
        'id' => 'header-h6',
        'title' => esc_html__('‹H6› sixth ‹/H6›', 'reuss'),
        'defs' => [
            'font-family' => 'Livvic',
            'font-size' => '20px',
            'line-height' => '32px',
            'font-weight' => '700',
        ],
    ],
];
$headings_array = [];
foreach ($headings as $key => $heading) {
    array_push($headings_array, [
        'id' => $heading['id'],
        'type' => 'custom_typography',
        'title' => $heading['title'],
        'google' => true,
        'font-backup' => false,
        'font-size' => true,
        'line-height' => true,
        'color' => false,
        'word-spacing' => false,
        'letter-spacing' => true,
        'text-align' => false,
        'text-transform' => true,
        'default' => $heading['defs'],
    ]);
}

//* ↓ Typogrophy Section ↓
Redux::setSection(
    $theme_slug,
    [
        'title' => esc_html__('Headings', 'reuss'),
        'id' => 'main_headings_typography',
        'subsection' => true,
        'fields' => $headings_array
    ]
);
//* ↑ typography config ↑

if (class_exists('WooCommerce')) {
    Redux::setSection(
        $theme_slug,
        [
            'title' => esc_html__('Shop', 'reuss'),
            'id' => 'shop-option',
            'icon' => 'el-icon-shopping-cart',
            'fields' => []
        ]
    );

    Redux::setSection(
        $theme_slug,
        [
            'title' => esc_html__('Catalog', 'reuss'),
            'id' => 'shop-catalog-option',
            'subsection' => true,
            'fields' => [
                [
                    'id' => 'shop_catalog_page_title_bg_image',
                    'type' => 'background',
                    'preview' => false,
                    'preview_media' => true,
                    'background-color' => false,
                    'title' => esc_html__('Catalog Page Title Background Image', 'reuss'),
                    'default' => [
                        'background-repeat' => 'repeat',
                        'background-size' => 'cover',
                        'background-attachment' => 'scroll',
                        'background-position' => 'center center',
                        'background-color' => '',
                    ]
                ],
                [
                    'id' => 'shop_catalog_sidebar-start',
                    'type' => 'section',
                    'title' => esc_html__('Sidebar Settings', 'reuss'),
                    'indent' => true,
                ],
                [
                    'id' => 'shop_catalog_sidebar_layout',
                    'type' => 'image_select',
                    'title' => esc_html__('Sidebar Layout', 'reuss'),
                    'options' => [
                        'none' => [
                            'alt' => 'None',
                            'img' => get_template_directory_uri() . '/core/admin/img/options/1col.png'
                        ],
                        'left' => [
                            'alt' => 'Left',
                            'img' => get_template_directory_uri() . '/core/admin/img/options/2cl.png'
                        ],
                        'right' => [
                            'alt' => 'Right',
                            'img' => get_template_directory_uri() . '/core/admin/img/options/2cr.png'
                        ],
                    ],
                    'default' => 'left'
                ],
                [
                    'id' => 'shop_catalog_sidebar_def',
                    'type' => 'select',
                    'title' => esc_html__('Shop Catalog Sidebar', 'reuss'),
                    'data' => 'sidebars',
                    'required' => ['shop_catalog_sidebar_layout', '!=', 'none'],
                ],
                [
                    'id' => 'shop_catalog_sidebar_def_width',
                    'type' => 'button_set',
                    'title' => esc_html__('Shop Sidebar Width', 'reuss'),
                    'options' => [
                        '9' => '25%',
                        '8' => '33%',
                    ],
                    'default' => '9',
                    'required' => ['shop_catalog_sidebar_layout', '!=', 'none'],
                ],
                [
                    'id' => 'shop_catalog_sidebar_sticky',
                    'type' => 'switch',
                    'title' => esc_html__('Sticky Sidebar On?', 'reuss'),
                    'default' => false,
                    'required' => ['shop_catalog_sidebar_layout', '!=', 'none'],
                ],
                [
                    'id' => 'shop_catalog_sidebar_gap',
                    'type' => 'select',
                    'title' => esc_html__('Sidebar Side Gap', 'reuss'),
                    'options' => [
                        'def' => esc_html__('Default', 'reuss'),
                        '0' => '0',
                        '15' => '15',
                        '20' => '20',
                        '25' => '25',
                        '30' => '30',
                        '35' => '35',
                        '40' => '40',
                        '45' => '45',
                        '50' => '50',
                    ],
                    'default' => 'def',
                    'required' => ['shop_catalog_sidebar_layout', '!=', 'none'],
                ],
                [
                    'id' => 'shop_catalog_sidebar-end',
                    'type' => 'section',
                    'indent' => false,
                ],
                [
                    'id' => 'shop_column',
                    'type' => 'button_set',
                    'title' => esc_html__('Shop Column', 'reuss'),
                    'options' => [
                        '1' => '1',
                        '2' => '2',
                        '3' => '3',
                        '4' => '4'
                    ],
                    'default' => '3',
                ],
                [
                    'id' => 'shop_products_per_page',
                    'type' => 'spinner',
                    'title' => esc_html__('Products per page', 'reuss'),
                    'default' => '12',
                    'min' => '1',
                    'step' => '1',
                    'max' => '100',
                ],
                [
                    'id' => 'use_animation_shop',
                    'type' => 'switch',
                    'title' => esc_html__('Use Animation Shop?', 'reuss'),
                    'default' => true,
                ],
                [
                    'id' => 'shop_catalog_animation_style',
                    'type' => 'select',
                    'select2' => ['allowClear' => false],
                    'title' => esc_html__('Animation Style', 'reuss'),
                    'options' => [
                        'fade-in' => esc_html__('Fade In', 'reuss'),
                        'slide-top' => esc_html__('Slide Top', 'reuss'),
                        'slide-bottom' => esc_html__('Slide Bottom', 'reuss'),
                        'slide-left' => esc_html__('Slide Left', 'reuss'),
                        'slide-right' => esc_html__('Slide Right', 'reuss'),
                        'zoom' => esc_html__('Zoom', 'reuss'),
                    ],
                    'default' => 'slide-left',
                    'required' => ['use_animation_shop', '=', true],
                ],
            ]
        ]
    );

    Redux::setSection(
        $theme_slug,
        [
            'title' => esc_html__('Single', 'reuss'),
            'id' => 'shop-single-option',
            'subsection' => true,
            'fields' => [
                [
                    'id' => 'shop_single_post_title-start',
                    'type' => 'section',
                    'title' => esc_html__('Post Title Settings', 'reuss'),
                    'indent' => true,
                ],
                [
                    'id' => 'shop_title_conditional',
                    'type' => 'switch',
                    'title' => esc_html__('Post Title Text', 'reuss'),
                    'on' => esc_html__('Custom', 'reuss'),
                    'off' => esc_html__('Default', 'reuss'),
                    'default' => true,
                ],
                [
                    'id' => 'shop_single_title_align',
                    'type' => 'button_set',
                    'title' => esc_html__('Title Alignment', 'reuss'),
                    'options' => [
                        'left' => esc_html__('Left', 'reuss'),
                        'center' => esc_html__('Center', 'reuss'),
                        'right' => esc_html__('Right', 'reuss'),
                    ],
                    'default' => 'center',
                ],
                [
                    'id' => 'shop_single_breadcrumbs_block_switch',
                    'type' => 'switch',
                    'title' => esc_html__('Breadcrumbs Display', 'reuss'),
                    'on' => 'Block',
                    'off' => 'Inline',
                    'default' => true,
                    'required' => ['page_title_breadcrumbs_switch', '=', true],
                ],
                [
                    'id' => 'shop_single_breadcrumbs_align',
                    'type' => 'button_set',
                    'title' => esc_html__('Title Breadcrumbs Alignment', 'reuss'),
                    'options' => [
                        'left' => esc_html__('Left', 'reuss'),
                        'center' => esc_html__('Center', 'reuss'),
                        'right' => esc_html__('Right', 'reuss'),
                    ],
                    'default' => 'center',
                    'required' => [
                        ['page_title_breadcrumbs_switch', '=', true],
                        ['shop_single_breadcrumbs_block_switch', '=', true]
                    ],
                ],
                [
                    'id' => 'shop_single_title_bg_switch',
                    'type' => 'switch',
                    'title' => esc_html__('Use Background Image/Color?', 'reuss'),
                    'on' => esc_html__('Use', 'reuss'),
                    'off' => esc_html__('Hide', 'reuss'),
                    'default' => true,
                ],
                [
                    'id' => 'shop_single_page_title_bg_image',
                    'type' => 'background',
                    'title' => esc_html__('Background Image/Color', 'reuss'),
                    'preview' => false,
                    'preview_media' => true,
                    'background-color' => true,
                    'transparent' => false,
                    'default' => [
                        'background-repeat' => 'repeat',
                        'background-size' => 'cover',
                        'background-attachment' => 'scroll',
                        'background-position' => 'center center',
                        'background-color' => '',
                    ],
                    'required' => ['shop_single_title_bg_switch', '=', true],
                ],
                [
                    'id' => 'shop_single_page_title_padding',
                    'type' => 'spacing',
                    'title' => esc_html__('Paddings Top/Bottom', 'reuss'),
                    'mode' => 'padding',
                    'all' => false,
                    'bottom' => true,
                    'top' => true,
                    'left' => false,
                    'right' => false,
                ],
                [
                    'id' => 'shop_single_page_title_margin',
                    'type' => 'spacing',
                    'title' => esc_html__('Margin Bottom', 'reuss'),
                    'mode' => 'margin',
                    'all' => false,
                    'bottom' => true,
                    'top' => false,
                    'left' => false,
                    'right' => false,
                    'default' => ['margin-bottom' => '47'],
                ],
                [
                    'id' => 'shop_single_page_title_border_switch',
                    'type' => 'switch',
                    'title' => esc_html__('Enable Border Top?', 'reuss'),
                    'default' => false,
                ],
                [
                    'id' => 'shop_single_page_title_border_color',
                    'type' => 'color_rgba',
                    'title' => esc_html__('Border Top Color', 'reuss'),
                    'default' => [
                        'color' => '#e5e5e5',
                        'alpha' => '1',
                        'rgba' => 'rgba(229,229,229,1)'
                    ],
                    'required' => ['shop_single_page_title_border_switch', '=', true],
                ],
                [
                    'id' => 'shop_single_post_title-end',
                    'type' => 'section',
                    'indent' => false,
                ],
                [
                    'id' => 'shop_single_sidebar_layout',
                    'type' => 'image_select',
                    'title' => esc_html__('Shop Single Sidebar Layout', 'reuss'),
                    'options' => [
                        'none' => [
                            'alt' => 'None',
                            'img' => get_template_directory_uri() . '/core/admin/img/options/1col.png'
                        ],
                        'left' => [
                            'alt' => 'Left',
                            'img' => get_template_directory_uri() . '/core/admin/img/options/2cl.png'
                        ],
                        'right' => [
                            'alt' => 'Right',
                            'img' => get_template_directory_uri() . '/core/admin/img/options/2cr.png'
                        ],
                    ],
                    'default' => 'none',
                ],
                [
                    'id' => 'shop_single_sidebar_def',
                    'type' => 'select',
                    'title' => esc_html__('Shop Single Sidebar', 'reuss'),
                    'data' => 'sidebars',
                    'required' => ['shop_single_sidebar_layout', '!=', 'none'],
                ],
                [
                    'id' => 'shop_single_sidebar_def_width',
                    'type' => 'button_set',
                    'title' => esc_html__('Shop Single Sidebar Width', 'reuss'),
                    'options' => [
                        '9' => '25%',
                        '8' => '33%',
                    ],
                    'default' => '9',
                    'required' => ['shop_single_sidebar_layout', '!=', 'none'],
                ],
                [
                    'id' => 'shop_single_sidebar_sticky',
                    'type' => 'switch',
                    'title' => esc_html__('Shop Single Sticky Sidebar On?', 'reuss'),
                    'default' => false,
                    'required' => ['shop_single_sidebar_layout', '!=', 'none'],
                ],
                [
                    'id' => 'shop_single_sidebar_gap',
                    'type' => 'select',
                    'title' => esc_html__('Shop Single Sidebar Side Gap', 'reuss'),
                    'options' => [
                        'def' => esc_html__('Default', 'reuss'),
                        '0' => '0',
                        '15' => '15',
                        '20' => '20',
                        '25' => '25',
                        '30' => '30',
                        '35' => '35',
                        '40' => '40',
                        '45' => '45',
                        '50' => '50',
                    ],
                    'default' => 'def',
                    'required' => ['shop_single_sidebar_layout', '!=', 'none'],
                ],
                [
                    'id' => 'shop_single_share',
                    'type' => 'switch',
                    'title' => esc_html__('Share On/Off', 'reuss'),
                    'default' => false,
                ],
            ]
        ]
    );

    Redux::setSection(
        $theme_slug,
        [
            'title' => esc_html__('Related', 'reuss'),
            'id' => 'shop-related-option',
            'subsection' => true,
            'fields' => [
                [
                    'id' => 'shop_related_columns',
                    'type' => 'button_set',
                    'title' => esc_html__('Related products column', 'reuss'),
                    'options' => [
                        '1' => '1',
                        '2' => '2',
                        '3' => '3',
                        '4' => '4'
                    ],
                    'default' => '4',
                ],
                [
                    'id' => 'shop_r_products_per_page',
                    'type' => 'spinner',
                    'title' => esc_html__('Related products per page', 'reuss'),
                    'default' => '4',
                    'min' => '1',
                    'step' => '1',
                    'max' => '100',
                ],
            ]
        ]
    );

    Redux::setSection(
        $theme_slug,
        [
            'title' => esc_html__('Cart', 'reuss'),
            'id' => 'shop-cart-option',
            'subsection' => true,
            'fields' => [
                [
                    'id' => 'shop_cart_page_title_bg_image',
                    'type' => 'background',
                    'background-color' => false,
                    'preview_media' => true,
                    'preview' => false,
                    'title' => esc_html__('Cart Page Title Background Image', 'reuss'),
                    'default' => [
                        'background-repeat' => 'repeat',
                        'background-size' => 'cover',
                        'background-attachment' => 'scroll',
                        'background-position' => 'center center',
                        'background-color' => '',
                    ],
                ],
            ]
        ]
    );

    Redux::setSection(
        $theme_slug,
        [
            'title' => esc_html__('Checkout', 'reuss'),
            'id' => 'shop-checkout-option',
            'subsection' => true,
            'fields' => [
                [
                    'id' => 'shop_checkout_page_title_bg_image',
                    'type' => 'background',
                    'background-color' => false,
                    'preview_media' => true,
                    'preview' => false,
                    'title' => esc_html__('Checkout Page Title Background Image', 'reuss'),
                    'default' => [
                        'background-repeat' => 'repeat',
                        'background-size' => 'cover',
                        'background-attachment' => 'scroll',
                        'background-position' => 'center center',
                        'background-color' => '',
                    ],
                ],
            ]
        ]
    );
}
